#

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

data1 = {
    "Persecution of LGBT people": "اضطهاد الأشخاص المثليين",
    "Persecution of LGBTQ people": "اضطهاد الأشخاص المثليين",
    "1990s LGBTQ-related sitcoms": "مسلسلات تلفزيونية كوميدية أمريكية متعلقة بإل جي بي تي كيو في عقد 1990",
    "Icelandic LGBTQ-related films": "أفلام آيسلندية متعلقة بإلمثليين والمثليات ومزدوجي التوجه الجنسي والمتحولين جنسيا",
    "Irish LGBTQ-related films": "أفلام أيرلندية متعلقة بإل جي بي تي كيو",
    "LGBTQ-related buddy films": "أفلام متعلقة بإل جي بي تي كيو رفقاء",
    "LGBTQ-related films by genre": "أفلام متعلقة بإل جي بي تي كيو حسب النوع الفني",
    "LGBTQ-related horror films": "أفلام متعلقة بإل جي بي تي كيو رعب",
    "LGBTQ-related mass media by country": "وسائل إعلام حسب البلد مرتبطة بإل جي بي تي كيو",
    "LGBTQ-related mass media in Denmark": "وسائل إعلام في الدنمارك مرتبطة بإل جي بي تي كيو",
    "LGBTQ-related mass media in Europe": "وسائل إعلام في أوروبا مرتبطة بإل جي بي تي كيو",
    "LGBTQ-related mass media in Ireland": "وسائل إعلام في أيرلندا مرتبطة بإل جي بي تي كيو",
    "LGBTQ-related radio stations": "محطات إذاعية مرتبطة بإل جي بي تي كيو",
    "LGBTQ-related sitcoms by decade": "مسلسلات تلفزيونية كوميدية أمريكية متعلقة بإل جي بي تي كيو حسب العقد",
    "LGBTQ-related sitcoms": "مسلسلات تلفزيونية كوميدية متعلقة بإل جي بي تي كيو",
    "LGBTQ-related sports films": "أفلام متعلقة بإل جي بي تي كيو رياضية",
    "Luxembourgian LGBTQ-related films": "أفلام لوكسمبورغية متعلقة بإل جي بي تي كيو",
    "1988 executions of Iranian political prisoners": "إعدامات مسجونون سياسيون إيرانيون 1988",
    "10th century in East Francia": "مملكة الفرنجة الشرقيين في القرن 10",
    "10th century in West Francia": "مملكة الفرنجة الغربيين في القرن 10",
    "10th-century kings of West Francia": "ملوك مملكة الفرنجة الغربيين القرن 10",
    "10th-century people from West Francia": "أشخاص من مملكة الفرنجة الغربيين في القرن 10",
    "13th-century wives of Ottoman sultans": "زوجات سلاطين عثمانيين في القرن 13",
    "14th-century consorts of Ottoman sultans": "زوجات سلاطين عثمانيين في القرن 14",
    "17th-century wives of Ottoman sultans": "زوجات سلاطين عثمانيين في القرن 17",
    "18th-century Native American people": "السكان الأصليين في الولايات المتحدة في القرن 18",
    "18th-century Native Americans": "القرن 18 السكان الأصليين في الولايات المتحدة",
    "18th-century wives of Ottoman sultans": "زوجات سلاطين عثمانيين في القرن 18",
    "1948 Palestinian exodus": "تهجير الفلسطينيين 1948",
    "1948 Palestinian expulsion and flight": "تهجير الفلسطينيين 1948",
    "19th-century wives of Ottoman sultans": "زوجات سلاطين عثمانيين في القرن 19",
    "2009 African Nations Championship": "بطولة أمم إفريقيا للمحليين 2009",
    "2009 African Nations Championship players": "لاعبو بطولة أمم إفريقيا للمحليين 2009",
    "2011 African Nations Championship": "بطولة أمم إفريقيا للمحليين 2011",
    "2011 African Nations Championship players": "لاعبو بطولة أمم إفريقيا للمحليين 2011",
    "2014 African Nations Championship players": "لاعبو كأس الأمم الإفريقية للمحليين 2014",
    "2016 African Nations Championship": "بطولة أمم إفريقيا للمحليين 2016",
    "2016 African Nations Championship players": "لاعبو بطولة أمم إفريقيا للمحليين 2016",
    "2018 African Nations Championship": "بطولة أمم إفريقيا للمحليين 2018",
    "2018 African Nations Championship players": "لاعبو بطولة أمم إفريقيا للمحليين 2018",
    "2020 African Nations Championship": "بطولة أمم إفريقيا للمحليين 2020",
    "2020 African Nations Championship players": "لاعبو بطولة أمم إفريقيا للمحليين 2020",
    "2022 African Nations Championship": "بطولة أمم إفريقيا للمحليين 2022",
    "2022 African Nations Championship players": "لاعبو بطولة أمم إفريقيا للمحليين 2022",
    "2024 African Nations Championship": "بطولة أمم إفريقيا للمحليين 2024",
    "2024 pro-Palestinian protests on university campuses": "احتجاجات مؤيدة للفلسطينيين في الجامعات 2024",
    "20th-century Asian male musicians": "موسيقيون ذكور آسيويين في القرن 20",
    "20th-century assassinated Asian politicians": "سياسيون آسيويين مغتالون في القرن 20",
    "20th-century venerated Christians": "تبجيل المسيحيين في القرن العشرين",
    "20th-century wives of Ottoman sultans": "زوجات سلاطين عثمانيين في القرن 20",
    "2nd millennium assassinated Asian politicians": "سياسيون آسيويين مغتالون في الألفية 2",
    "9th century in East Francia": "مملكة الفرنجة الشرقيين في القرن 9",
    "9th century in West Francia": "مملكة الفرنجة الغربيين في القرن 9",
    "9th-century kings of West Francia": "ملوك مملكة الفرنجة الغربيين القرن 9",
    "9th-century people from East Francia": "أشخاص من مملكة الفرنجة الشرقيين في القرن 9",
    "9th-century people from West Francia": "أشخاص من مملكة الفرنجة الغربيين في القرن 9",
    "Abbasid qahramana": "قهرمانات الخلفاء العباسيين",
    "Aboriginal title": "أراضي السكان الأصليين",
    "Aboriginal title in Canada": "أراضي السكان الأصليين في كندا",
    "Academic staff of the University of al-Qarawiyyin": "أعضاء هيئة تدريس جامعة القرويين",
    "Academy of Canadian Cinema & Television": "أكاديمية السينما والتلفاز الكنديين",
    "Action films about Asian Americans": "أفلام حركة عن أمريكيون آسيويين",
    "Active politicians": "سياسيين نشطين",
    "Activists for Hispanic and Latino American civil rights": "ناشطو حقوق الأمريكيين اللاتينيين والهسبانيين",
    "Advanced Placement": "برنامج التعيين المتقدم",
    "African American-related lists": "قوائم متعلقة بالأمريكيين الأفارقة",
    "African Americans' rights organizations": "منظمات حقوق الأمركيين الأفارقة",
    "African Nations Championship finals": "نهائيات بطولة أمم إفريقيا للمحليين",
    "African Nations Championship navigational boxes": "صناديق تصفح بطولة أمم إفريقيا للمحليين",
    "African Nations Championship players": "لاعبو كأس الأمم الإفريقية للمحليين",
    "African Nations Championship qualification": "تصفيات بطولة أمم إفريقيا للمحليين",
    "African-American films": "أفلام عن الأمريكيين الأفارقة",
    "African-American history by city": "تاريخ الأمريكيين الأفارقة حسب المدينة",
    "African-American history by location": "تاريخ الأمريكيين الأفارقة حسب الموقع",
    "African-American history by state": "تاريخ الأمريكيين الأفارقة حسب الولاية",
    "African-American history by state or territory": "تاريخ الأمريكيين الأفارقة حسب الولاية",
    "African-American history in Baltimore": "تاريخ الأمريكيين الأفارقة في بالتيمور (ماريلند)",
    "African-American history of Maryland": "تاريخ الأمريكيين الأفارقة في ماريلند",
    "Agronomists": "مهندسين زراعيين",
    "Albums by Kuwaiti artists by genre": "ألبومات فنانين كويتيين حسب النوع الفني",
    "Albums by South Korean artists by genre": "ألبومات فنانين كوريين جنوبيين حسب النوع الفني",
    "Algeria men's A' international footballers": "لاعبو منتخب الجزائر لكرة القدم للمحليين",
    "All Progressives Congress": "مؤتمر الجميع التقدميين النيجيري",
    "Alliance of European Conservatives and Reformists": "تحالف المصلحين والمحافظين الأوروبيين",
    "Alliance of Independent Social Democrats politicians": "تحالف السياسيين الاشتراكيين الديمقراطيين المستقلين",
    "Alternative rock albums by Canadian artists": "ألبومات روك بديل لفنانين كنديين",
    "Ambient albums by French artists": "ألبومات أمبينت لفنانين فرنسيين",
    "American Indian reservations": "محميات السكان الأصليين الأمريكية",
    "American Indian reservations by state": "محميات السكان الأصليين الأمريكية حسب الولاية",
    "American Indian reservations in Alaska": "محميات السكان الأصليين الأمريكية في ألاسكا",
    "American Indian reservations in Arizona": "محميات السكان الأصليين الأمريكية في أريزونا",
    "American Indian reservations in Colorado": "محميات السكان الأصليين الأمريكية في كولورادو",
    "American Indian reservations in Massachusetts": "محميات السكان الأصليين الأمريكية في ماساتشوستس",
    "American Indian reservations in Michigan": "محميات السكان الأصليين الأمريكية في ميشيغان",
    "American Indian reservations in Minnesota": "محميات السكان الأصليين الأمريكية في منيسوتا",
    "American Indian reservations in Montana": "محميات السكان الأصليين الأمريكية في مونتانا",
    "American Indian reservations in New Mexico": "محميات السكان الأصليين الأمريكية في نيومكسيكو",
    "American Indian reservations in New York (state)": "محميات السكان الأصليين الأمريكية في ولاية نيويورك",
    "American Indian reservations in North Dakota": "محميات السكان الأصليين الأمريكية في داكوتا الشمالية",
    "American Indian reservations in Oklahoma": "محميات السكان الأصليين الأمريكية في أوكلاهوما",
    "American Indian reservations in South Dakota": "محميات السكان الأصليين الأمريكية في داكوتا الجنوبية",
    "American Indian reservations in Utah": "محميات السكان الأصليين الأمريكية في يوتا",
    "American Indian reservations in Washington (state)": "محميات السكان الأصليين الأمريكية في ولاية واشنطن",
    "American Indian reservations in Wisconsin": "محميات السكان الأصليين الأمريكية في ويسكونسن",
    "American Indian reservations in Wyoming": "محميات السكان الأصليين الأمريكية في وايومنغ",
    "American Institute of Architects": "الجمعية الأمريكية للمعماريين",
    "American Institute of Chemical Engineers": "المعهد الأمريكي للمهندسين الكيميائيين",
    "American Psychiatric Association": "الجمعية الأمريكية للأطباء النفسيين",
    "American Society of Cinematographers": "الجمعية الأمريكية للمصورين السينمائيين",
    "American Society of Civil Engineers": "الجمعية الأمريكية للمهندسين المدنيين",
    "American artist groups and collectives": "مجموعات الفنانين الأمريكيين",
    "American aviators of Asian descent": "طيارون أمريكيون آسيويين",
    "American confidence tricksters": "أكبر المحتالين الأمريكيين",
    "American feminists of Asian descent": "نسويون أمريكيون آسيويين",
    "American film directors of Asian descent": "مخرجو أفلام أمريكيون آسيويين",
    "American players of American football of Asian descent": "لاعبو أمريكيون آسيويين في كرة القدم الأمريكية",
    "American tennis players of Asian descent": "لاعبو كرة مضرب أمريكيون آسيويين",
    "American trade unionists of Asian descent": "نقابيون أمريكيون آسيويين",
    "American victims of anti-LGBT hate crimes": "ضحايا جرائم أمريكيون بسبب الكراهية ضد المثليين",
    "American victims of anti-LGBTQ hate crimes": "ضحايا جرائم أمريكيون بسبب الكراهية ضد المثليين",
    "American writer navigational boxes": "صناديق تصفح كتاب أمريكيين",
    "Amiens SC": "نادي أميين",
    "Amiens SC managers": "مدربو نادي أميين",
    "Amiens SC non-playing staff": "طاقم نادي أميين غير اللاعبين",
    "Amiens SC players": "لاعبو أميين",
    "Ancient Asian people": "آسيويين قدماء",
    "Ancient Asian people by country": "آسيويين قدماء حسب البلد",
    "Ancient Egyptians": "قدماء المصريين",
    "Ancient Greek plays by writer": "مسرحيات يونانيين قدماء حسب الكاتب",
    "Angola men's A' international footballers": "لاعبو منتخب أنغولا لكرة القدم للرجال للمحليين",
    "Animated films about music and musicians": "أفلام رسوم متحركة عن الموسيقى والموسيقيين",
    "Anti-American sentiment by country": "مشاعر معادية للأمريكيين حسب البلد",
    "Anti-American sentiment in Africa": "مشاعر معادية للأمريكيين في إفريقيا",
    "Anti-American sentiment in Asia": "مشاعر معادية للأمريكيين في آسيا",
    "Anti-American sentiment in China": "مشاعر معادية للأمريكيين في الصين",
    "Anti-American sentiment in Europe": "مشاعر معادية للأمريكيين في أوروبا",
    "Anti-American sentiment in Germany": "مشاعر معادية للأمريكيين في ألمانيا",
    "Anti-American sentiment in Iran": "مشاعر معادية للأمريكيين في إيران",
    "Anti-American sentiment in Japan": "مشاعر معادية للأمريكيين في اليابان",
    "Anti-American sentiment in Korea": "مشاعر معادية للأمريكيين في كوريا",
    "Anti-American sentiment in North America": "مشاعر معادية للأمريكيين في أمريكا الشمالية",
    "Anti-American sentiment in North Korea": "مشاعر معادية للأمريكيين في كوريا الشمالية",
    "Anti-American sentiment in Russia": "مشاعر معادية للأمريكيين في روسيا",
    "Anti-American sentiment in South America": "مشاعر معادية للأمريكيين في أمريكا الجنوبية",
    "Anti-American sentiment in South Korea": "مشاعر معادية للأمريكيين في كوريا الجنوبية",
    "Anti-American sentiment in Turkey": "مشاعر معادية للأمريكيين في تركيا",
    "Anti-American sentiment in the Middle East": "مشاعر معادية للأمريكيين في الشرق الأوسط",
    "Anti-American sentiment in the United States": "مشاعر معادية للأمريكيين في الولايات المتحدة",
    "Anti-Americanism": "معاداة الأمريكيين",
    "Anti-Asian sentiment": "مشاعر معادية لآسيويين",
    "Anti-Asian sentiment by continent": "مشاعر معادية للآسيويين حسب القارة",
    "Anti-Asian sentiment in Australia": "مشاعر معادية للآسيويين في أستراليا",
    "Anti-Asian sentiment in Canada": "مشاعر معادية للآسيويين في كندا",
    "Anti-Asian sentiment in Europe": "مشاعر معادية للآسيويين في أوروبا",
    "Anti-Asian sentiment in North America": "مشاعر معادية للآسيويين في أمريكا الشمالية",
    "Anti-Asian sentiment in Oceania": "مشاعر معادية للآسيويين في أوقيانوسيا",
    "Anti-Asian sentiment in Russia": "مشاعر معادية للآسيويين في روسيا",
    "Anti-Asian sentiment in the United States": "مشاعر معادية للآسيويين في الولايات المتحدة",
    "Anti-Australian sentiment": "مشاعر معادية للأستراليين",
    "Anti-Azerbaijanism": "معاداة الأذربيجانيين",
    "Anti-Belarusian sentiment": "مشاعر معادية للبيلاروسيين",
    "Anti-Bulgarian sentiment": "مشاعر معادية للبلغاريين",
    "Anti-Canadian sentiment": "مشاعر معادية للكنديين",
    "Anti-Caucasus sentiment": "مشاعر معادية للقوقازيين",
    "Anti-Caucasus sentiment in Russia": "مشاعر معادية للقوقازيين في روسيا",
    "Anti-Chechen sentiment": "مشاعر معادية للشيشانيين",
    "Anti-Chilean sentiment": "مشاعر معادية للتشيليين",
    "Anti-Chinese sentiment by continent": "مشاعر معادية للصينيين حسب القارة",
    "Anti-Chinese sentiment by country": "مشاعر معادية للصينيين حسب البلد",
    "Anti-Chinese sentiment in Asia": "مشاعر معادية للصينيين في آسيا",
    "Anti-Chinese sentiment in Australia": "مشاعر معادية للصينيين في أستراليا",
    "Anti-Chinese sentiment in Canada": "مشاعر معادية للصينيين في كندا",
    "Anti-Chinese sentiment in China": "مشاعر معادية للصينيين في الصين",
    "Anti-Chinese sentiment in Indonesia": "مشاعر معادية للصينيين في إندونيسيا",
    "Anti-Chinese sentiment in Japan": "مشاعر معادية للصينيين في اليابان",
    "Anti-Chinese sentiment in Korea": "مشاعر معادية للصينيين في كوريا",
    "Anti-Chinese sentiment in Mexico": "مشاعر معادية للصينيين في المكسيك",
    "Anti-Chinese sentiment in North America": "مشاعر معادية للصينيين في أمريكا الشمالية",
    "Anti-Chinese sentiment in Oceania": "مشاعر معادية للصينيين في أوقيانوسيا",
    "Anti-Chinese sentiment in Pakistan": "مشاعر معادية للصينيين في باكستان",
    "Anti-Chinese sentiment in South Korea": "مشاعر معادية للصينيين في كوريا الجنوبية",
    "Anti-Chinese sentiment in the United States": "مشاعر معادية للصينيين في الولايات المتحدة",
    "Anti-Christian sentiment by continent": "مشاعر معادية للمسيحيين حسب القارة",
    "Anti-Christian sentiment in Afghanistan": "مشاعر معادية للمسيحيين في أفغانستان",
    "Anti-Christian sentiment in Africa": "مشاعر معادية للمسيحيين في إفريقيا",
    "Anti-Christian sentiment in Albania": "مشاعر معادية للمسيحيين في ألبانيا",
    "Anti-Christian sentiment in Bulgaria": "مشاعر معادية للمسيحيين في بلغاريا",
    "Anti-Christian sentiment in Cambodia": "مشاعر معادية للمسيحيين في كمبوديا",
    "Anti-Christian sentiment in Canada": "مشاعر معادية للمسيحيين في كندا",
    "Anti-Christian sentiment in China": "مشاعر معادية للمسيحيين في الصين",
    "Anti-Christian sentiment in France": "مشاعر معادية للمسيحيين في فرنسا",
    "Anti-Christian sentiment in Germany": "مشاعر معادية للمسيحيين في ألمانيا",
    "Anti-Christian sentiment in Greece": "مشاعر معادية للمسيحيين في اليونان",
    "Anti-Christian sentiment in India": "مشاعر معادية للمسيحيين في الهند",
    "Anti-Christian sentiment in Indonesia": "مشاعر معادية للمسيحيين في إندونيسيا",
    "Anti-Christian sentiment in Iran": "مشاعر معادية للمسيحيين في إيران",
    "Anti-Christian sentiment in Iraq": "مشاعر معادية للمسيحيين في العراق",
    "Anti-Christian sentiment in Israel": "مشاعر معادية للمسيحيين في إسرائيل",
    "Anti-Christian sentiment in Italy": "مشاعر معادية للمسيحيين في إيطاليا",
    "Anti-Christian sentiment in Japan": "مشاعر معادية للمسيحيين في اليابان",
    "Anti-Christian sentiment in Lebanon": "مشاعر معادية للمسيحيين في لبنان",
    "Anti-Christian sentiment in Malaysia": "مشاعر معادية للمسيحيين في ماليزيا",
    "Anti-Christian sentiment in North America": "مشاعر معادية للمسيحيين في أمريكا الشمالية",
    "Anti-Christian sentiment in Norway": "مشاعر معادية للمسيحيين في النرويج",
    "Anti-Christian sentiment in Oceania": "مشاعر معادية للمسيحيين في أوقيانوسيا",
    "Anti-Christian sentiment in Pakistan": "مشاعر معادية للمسيحيين في باكستان",
    "Anti-Christian sentiment in Poland": "مشاعر معادية للمسيحيين في بولندا",
    "Anti-Christian sentiment in Russia": "مشاعر معادية للمسيحيين في روسيا",
    "Anti-Christian sentiment in Saudi Arabia": "مشاعر معادية للمسيحيين في السعودية",
    "Anti-Christian sentiment in Spain": "مشاعر معادية للمسيحيين في إسبانيا",
    "Anti-Christian sentiment in Sri Lanka": "مشاعر معادية للمسيحيين في سريلانكا",
    "Anti-Christian sentiment in Sweden": "مشاعر معادية للمسيحيين في السويد",
    "Anti-Christian sentiment in Syria": "مشاعر معادية للمسيحيين في سوريا",
    "Anti-Christian sentiment in Turkey": "مشاعر معادية للمسيحيين في تركيا",
    "Anti-Christian sentiment in Ukraine": "مشاعر معادية للمسيحيين في أوكرانيا",
    "Anti-Christian sentiment in the Philippines": "مشاعر معادية للمسيحيين في الفلبين",
    "Anti-Christian sentiment in the United Kingdom": "مشاعر معادية للمسيحيين في المملكة المتحدة",
    "Anti-Czech sentiment": "مشاعر معادية للتشيكيين",
    "Anti-Danish sentiment": "مشاعر معادية للدنماركيين",
    "Anti-Dutch sentiment": "مشاعر معادية للهولنديين",
    "Anti-Estonian sentiment": "مشاعر معادية للإستونيين",
    "Anti-Ethiopian sentiment": "مشاعر معادية للإثيوبيين",
    "Anti-European sentiment": "مشاعر معادية للأوروبيين",
    "Anti-Filipino sentiment": "مشاعر معادية للفلبينيين",
    "Anti-Finnish sentiment": "مشاعر معادية للفنلنديين",
    "Anti-Georgian sentiment": "مشاعر معادية للجورجيين",
    "Anti-Greek sentiment": "مشاعر معادية لليونانيين",
    "Anti-Haitian sentiment": "مشاعر معادية للهايتيين",
    "Anti-Iranian sentiments": "مشاعر معادية للإيرانيين",
    "Anti-Irish sentiment": "مشاعر معادية للأيرلنديين",
    "Anti-Israeli sentiment": "مشاعر معادية للإسرائيليين",
    "Anti-Israeli sentiment by country": "مشاعر معادية للإسرائيليين حسب البلد",
    "Anti-Israeli sentiment in Afghanistan": "مشاعر معادية للإسرائيليين في أفغانستان",
    "Anti-Israeli sentiment in Africa": "مشاعر معادية للإسرائيليين في إفريقيا",
    "Anti-Israeli sentiment in Asia": "مشاعر معادية للإسرائيليين في آسيا",
    "Anti-Israeli sentiment in Egypt": "مشاعر معادية للإسرائيليين في مصر",
    "Anti-Israeli sentiment in Europe": "مشاعر معادية للإسرائيليين في أوروبا",
    "Anti-Israeli sentiment in Iran": "مشاعر معادية للإسرائيليين في إيران",
    "Anti-Israeli sentiment in Iraq": "مشاعر معادية للإسرائيليين في العراق",
    "Anti-Israeli sentiment in Israel": "مشاعر معادية للإسرائيليين في إسرائيل",
    "Anti-Israeli sentiment in Lebanon": "مشاعر معادية للإسرائيليين في لبنان",
    "Anti-Israeli sentiment in Libya": "مشاعر معادية للإسرائيليين في ليبيا",
    "Anti-Israeli sentiment in North America": "مشاعر معادية للإسرائيليين في أمريكا الشمالية",
    "Anti-Israeli sentiment in Palestine": "مشاعر معادية للإسرائيليين في فلسطين",
    "Anti-Israeli sentiment in South America": "مشاعر معادية للإسرائيليين في أمريكا الجنوبية",
    "Anti-Israeli sentiment in Syria": "مشاعر معادية للإسرائيليين في سوريا",
    "Anti-Israeli sentiment in Yemen": "مشاعر معادية للإسرائيليين في اليمن",
    "Anti-Israeli sentiment in the United States": "مشاعر معادية للإسرائيليين في الولايات المتحدة",
    "Anti-Italian sentiment": "مشاعر معادية للإيطاليين",
    "Anti-Japanese sentiment in Korea": "تمييز ضد اليابانيين في كوريا",
    "Anti-Japanese sentiment in North Korea": "مشاعر معادية لليابانيين في كوريا الشمالية",
    "Anti-Japanese sentiment in South Korea": "مشاعر معادية لليابانيين في كوريا الجنوبية",
    "Anti-Japanese sentiment in Taiwan": "مشاعر معادية لليابانيين في تايوان",
    "Anti-Japanese sentiment in the United States": "مشاعر معادية لليابانيين في الولايات المتحدة",
    "Anti-Korean sentiment in Japan": "تمييز ضد الكوريين في اليابان",
    "Anti-Korean sentiment in the United States": "مشاعر معادية للكوريين في الولايات المتحدة",
    "Anti-Latvian sentiment": "مشاعر معادية لللاتفيين",
    "Anti-Mexican sentiment": "مشاعر معادية للمكسيكيين",
    "Anti-Mongolian sentiment": "مشاعر معادية للمنغوليين",
    "Anti-Palestinian sentiment": "مشاعر معادية للفلسطينيين",
    "Anti-Palestinian sentiment by country": "مشاعر معادية للفلسطينيين حسب البلد",
    "Anti-Palestinian sentiment in Asia": "مشاعر معادية للفلسطينيين في آسيا",
    "Anti-Palestinian sentiment in Germany": "مشاعر معادية للفلسطينيين في ألمانيا",
    "Anti-Palestinian sentiment in Israel": "مشاعر معادية للفلسطينيين في إسرائيل",
    "Anti-Palestinian sentiment in the Middle East": "مشاعر معادية للفلسطينيين في الشرق الأوسط",
    "Anti-Palestinian sentiment in the United States": "مشاعر معادية للفلسطينيين في الولايات المتحدة",
    "Anti-Polish sentiment in Europe": "مشاعر معادية للبولنديين في أوروبا",
    "Anti-Portuguese sentiment": "مشاعر معادية للبرتغاليين",
    "Anti-Scottish sentiment": "مشاعر معادية للإسكتلنديين",
    "Anti-Slovene sentiment": "مشاعر معادية للسلوفينيين",
    "Anti-Somali sentiment": "مشاعر معادية للصوماليين",
    "Anti-Swedish sentiment": "مشاعر معادية للسويديين",
    "Anti-Syrian sentiment": "مشاعر معادية للسوريين",
    "Anti-Taiwanese sentiment": "مشاعر معادية للتايوانيين",
    "Anti-Thai sentiment": "مشاعر معادية للتايلنديين",
    "Anti-Ukrainian sentiment": "مشاعر معادية للأوكرانيين",
    "Anti-Ukrainian sentiment in Europe": "مشاعر معادية للأوكرانيين في أوروبا",
    "Anti-Ukrainian sentiment in Russia": "مشاعر معادية للأوكرانيين في روسيا",
    "Anti-Ukrainian sentiment in Ukraine": "مشاعر معادية للأوكرانيين في أوكرانيا",
    "Anti-Vietnamese sentiment": "مشاعر معادية للفيتناميين",
    "Anti-indigenous racism": "تمييز عنصري ضد السكان الأصليين",
    "Anti-same-sex-marriage activists": "ناشطون ضد زواج المثليين",
    "Arab Nationalist Movement breakaway groups": "مجموعات حركة قوميين عرب انفصالية",
    "Archbishops of Vienne": "رؤساء أساقفة من فيين (إقليم فرنسي)",
    "Arteries": "شرايين",
    "Arteries of the abdomen": "شرايين البطن",
    "Arteries of the head and neck": "شرايين الرأس والعنق",
    "Arteries of the lower limb": "شرايين الطرف السفلي",
    "Arteries of the thorax": "شرايين الصدر",
    "Arteries of the torso": "شرايين الجذع",
    "Arteries of the upper limb": "شرايين الطرف العلوي",
    "Asian Australian": "أستراليون آسيويين",
    "Asian Caribbean": "كاريبيون آسيويين",
    "Asian Catholics": "كاثوليك آسيويين",
    "Asian Central American": "أمريكيون أوسطيون آسيويين",
    "Asian Go players": "لاعبو غو آسيويين",
    "Asian Irish": "أيرلنديون آسيويين",
    "Asian New Zealander": "نيوزيلنديون آسيويين",
    "Asian Nigerian": "نيجيريون آسيويين",
    "Asian anti-communists": "آسيويين مناهضون للشيوعية",
    "Asian aviators": "طيارون آسيويين",
    "Asian baseball coaches": "مدربو كرة قاعدة آسيويين",
    "Asian biblical scholars": "علماء الكتاب المقدس آسيويين",
    "Asian child actors": "ممثلون أطفال آسيويين",
    "Asian diaspora in Ireland": "أيرلنديون آسيويين",
    "Asian diaspora in New Zealand": "نيوزيلنديون آسيويين",
    "Asian diaspora in Nigeria": "نيجيريون آسيويين",
    "Asian diaspora in the Caribbean": "كاريبيون آسيويين",
    "Asian diaspora in the United Kingdom": "آسيويين بريطانيون",
    "Asian fascists": "فاشيون آسيويين",
    "Asian film director navigational boxes": "صناديق تصفح مخرجي أفلام آسيويين",
    "Asian football champions": "أبطال كرة القدم آسيويين",
    "Asian liberal politicians": "ليبراليون كلاسيكيون آسيويين",
    "Asian musician navigational boxes": "قوالب موسيقيون آسيويين",
    "Asian musicians templates": "قوالب موسيقيون آسيويين",
    "Asian newspaper editors": "محررو صحف آسيويين",
    "Asian pacifists": "دعاة سلام آسيويين",
    "Asian people by ethnicity": "أعلام آسيويين حسب المجموعة العرقية",
    "Asian people by nationality and occupation": "أعلام آسيويين حسب الجنسية والمهنة",
    "Asian people of African-American descent": "آسيويين من أصل إفريقي أمريكي",
    "Asian people of Albanian descent": "آسيويين من أصل ألباني",
    "Asian people of American descent": "آسيويين من أصل أمريكي",
    "Asian people of Angolan descent": "آسيويين من أصل أنغولي",
    "Asian people of Argentine descent": "آسيويين من أصل أرجنتيني",
    "Asian people of Austrian descent": "آسيويين من أصل نمساوي",
    "Asian people of Barbadian descent": "آسيويين من أصل بربادوسي",
    "Asian people of Belarusian descent": "آسيويين من أصل بيلاروسي",
    "Asian people of Belgian descent": "آسيويين من أصل بلجيكي",
    "Asian people of Beninese descent": "آسيويين من أصل بنيني",
    "Asian people of Bolivian descent": "آسيويين من أصل بوليفي",
    "Asian people of Bosnia and Herzegovina descent": "آسيويين من أصل بوسني",
    "Asian people of Brazilian descent": "آسيويين من أصل برازيلي",
    "Asian people of Cameroonian descent": "آسيويين من أصل كاميروني",
    "Asian people of Canadian descent": "آسيويين من أصل كندي",
    "Asian people of Chilean descent": "آسيويين من أصل تشيلي",
    "Asian people of Colombian descent": "آسيويين من أصل كولومبي",
    "Asian people of Croatian descent": "آسيويين من أصل كرواتي",
    "Asian people of Danish descent": "آسيويين من أصل دنماركي",
    "Asian people of Ecuadorian descent": "أعلام آسيويين من أصل إكوادوري",
    "Asian people of English descent": "آسيويين من أصل إنجليزي",
    "Asian people of Estonian descent": "آسيويين من أصل إستوني",
    "Asian people of Ethiopian descent": "آسيويين من أصل إثيوبي",
    "Asian people of European-Jewish descent": "آسيويين من أصل يهودي أوروبي",
    "Asian people of Finnish descent": "آسيويين من أصل فنلندي",
    "Asian people of Ghanaian descent": "آسيويين من أصل غاني",
    "Asian people of Greek descent": "آسيويين من أصل يوناني",
    "Asian people of Guinean descent": "آسيويين من أصل غيني",
    "Asian people of Hungarian descent": "آسيويين من أصل مجري",
    "Asian people of Icelandic descent": "آسيويين من أصل آيسلندي",
    "Asian people of Kazakhstani descent": "آسيويين من أصل كازاخستاني",
    "Asian people of Kenyan descent": "آسيويين من أصل كيني",
    "Asian people of Liberian descent": "آسيويين من أصل ليبيري",
    "Asian people of Lithuanian descent": "آسيويين من أصل ليتواني",
    "Asian people of Macedonian descent": "أعلام آسيويين من أصل مقدوني",
    "Asian people of Malian descent": "آسيويين من أصل مالي",
    "Asian people of Moldovan descent": "أعلام آسيويين من أصل مولدوفي",
    "Asian people of Montenegrin descent": "آسيويين من أصل مونتينيغري",
    "Asian people of Nigerian descent": "آسيويين من أصل نيجيري",
    "Asian people of Norwegian descent": "آسيويين من أصل نرويجي",
    "Asian people of Peruvian descent": "أعلام آسيويين من أصل بيروي",
    "Asian people of Polish descent": "آسيويين من أصل بولندي",
    "Asian people of Romanian descent": "آسيويين من أصل روماني",
    "Asian people of Scottish descent": "آسيويين من أصل إسكتلندي",
    "Asian people of Slovenian descent": "آسيويين من أصل سلوفيني",
    "Asian people of Sri Lankan descent": "آسيويين من أصل سريلانكي",
    "Asian people of Surinamese descent": "آسيويين من أصل سورينامي",
    "Asian people of Swedish descent": "آسيويين من أصل سويدي",
    "Asian people of Swiss descent": "آسيويين من أصل سويسري",
    "Asian people of Tanzanian descent": "آسيويين من أصل تنزاني",
    "Asian people of Tongan descent": "آسيويين من أصل تونغاني",
    "Asian people of Ukrainian descent": "آسيويين من أصل أوكراني",
    "Asian people of Uruguayan descent": "آسيويين من أصل أوروغوياني",
    "Asian people of Venezuelan descent": "أعلام آسيويين من أصل فنزويلي",
    "Asian people of Welsh descent": "آسيويين من أصل ويلزي",
    "Asian people of Yugoslav descent": "آسيويين من أصل يوغسلافي",
    "Asian physicists": "فيزيائيون آسيويين",
    "Asian political people": "ساسة آسيويين",
    "Asian pop singer navigational boxes": "قوالب مغنو بوب آسيويين",
    "Asian pop singers templates": "قوالب مغنو بوب آسيويين",
    "Asian revolutionaries": "ثوار آسيويين",
    "Asian rugby union players": "لاعبو اتحاد رجبي آسيويين",
    "Asian scientists": "علماء آسيويين",
    "Asian scientists by nationality": "علماء آسيويين حسب الجنسية",
    "Asian sociologists": "علماء اجتماع آسيويين",
    "Asian sports coaches": "مدربو رياضة آسيويين",
    "Asian swimmers": "سباحون آسيويين",
    "Asian tennis players": "لاعبو كرة مضرب آسيويين",
    "Asian-American feminists": "نسويون أمريكيون آسيويين",
    "Asian-American films by genre": "أفلام أمريكيون آسيويين حسب النوع الفني",
    "Asian-American members of the Cabinet of the United States": "أمريكيون آسيويين أعضاء في مجلس وزراء الولايات المتحدة",
    "Asian-American members of the United States House of Representatives": "أمريكيون آسيويين أعضاء في مجلس النواب الأمريكي",
    "Asian-American people in Alaska politics": "أمريكيون آسيويين في سياسة ألاسكا",
    "Asian-American people in California politics": "أمريكيون آسيويين في سياسة كاليفورنيا",
    "Asian-American people in Connecticut politics": "أمريكيون آسيويين في سياسة كونيتيكت",
    "Asian-American people in Florida politics": "أمريكيون آسيويين في سياسة فلوريدا",
    "Asian-American people in Georgia (U.S. state) politics": "أمريكيون آسيويين في سياسة ولاية جورجيا",
    "Asian-American people in Hawaii politics": "أمريكيون آسيويين في سياسة هاواي",
    "Asian-American people in Illinois politics": "أمريكيون آسيويين في سياسة إلينوي",
    "Asian-American people in Louisiana politics": "أمريكيون آسيويين في سياسة لويزيانا",
    "Asian-American people in Massachusetts politics": "أمريكيون آسيويين في سياسة ماساتشوستس",
    "Asian-American people in Michigan politics": "أمريكيون آسيويين في سياسة ميشيغان",
    "Asian-American people in Missouri politics": "أمريكيون آسيويين في سياسة ميزوري",
    "Asian-American people in Nebraska politics": "أمريكيون آسيويين في سياسة نبراسكا",
    "Asian-American people in New Jersey politics": "أمريكيون آسيويين في سياسة نيوجيرسي",
    "Asian-American people in New York (state) politics": "أمريكيون آسيويين في سياسة ولاية نيويورك",
    "Asian-American people in Ohio politics": "أمريكيون آسيويين في سياسة أوهايو",
    "Asian-American people in Oklahoma politics": "أمريكيون آسيويين في سياسة أوكلاهوما",
    "Asian-American people in Oregon politics": "أمريكيون آسيويين في سياسة أوريغن",
    "Asian-American people in Pennsylvania politics": "أمريكيون آسيويين في سياسة بنسلفانيا",
    "Asian-American people in South Carolina politics": "أمريكيون آسيويين في سياسة كارولاينا الجنوبية",
    "Asian-American people in Texas politics": "أمريكيون آسيويين في سياسة تكساس",
    "Asian-American people in Utah politics": "أمريكيون آسيويين في سياسة يوتا",
    "Asian-American people in Virginia politics": "أمريكيون آسيويين في سياسة فرجينيا",
    "Asian-American people in Washington (state) politics": "أمريكيون آسيويين في سياسة ولاية واشنطن",
    "Asian-American tennis players": "لاعبو كرة مضرب أمريكيون آسيويين",
    "Asian-American trade unionists": "نقابيون أمريكيون آسيويين",
    "Asian-Jewish culture in Israel": "ثقافة يهود آسيويين في إسرائيل",
    "Assassinated Asian politicians": "سياسيون آسيويين مغتالون",
    "Assassinated Turkish Kurdish politicians": "سياسيين أكراد أتراك مغتالون",
    "Assassinated politicians in Asia": "سياسيون آسيويين مغتالون",
    "Association football players by men's A' national team": "لاعبو كرة قدم حسب منتخب المحليين",
    "Australian Aboriginal culture": "ثقافة السكان الأصليين في أستراليا",
    "Australian Aboriginal mythology": "أساطير سكان أستراليا الأصليين",
    "Australian film director navigational boxes": "صناديق تصفح مخرجي أفلام أستراليين",
    "Australian military memorials": "نصب تذكارية ومقابر عسكريين أستراليين",
    "Austrian automotive pioneers": "رواد السيارات النمساويين",
    "Awards of the American Society of Civil Engineers": "جوائز في الجمعية الأمريكية للمهندسين المدنيين",
    "Ayyubid emirs": "أمراء أيوبيين",
    "Ayyubid emirs of Yemen": "أمراء أيوبيين في اليمن",
    "Bahraini religious leaders": "زعماء دينيين بحرينيين",
    "Bahá'í gardens": "حدائق البهائيين",
    "Baiyin": "بايين",
    "Battles involving Babylonia": "معارك البابليين",
    "Battles involving East Francia": "معارك تشمل مملكة الفرنجة الشرقيين",
    "Battles involving Native American people": "معارك تشمل السكان الأصليين في الولايات المتحدة",
    "Battles involving Native Americans": "معارك تشمل السكان الأصليين في الولايات المتحدة",
    "Battles involving Phoenicia": "معارك تشمل فينيقيين",
    "Battles involving Safavid Iran": "معارك الصفويين",
    "Battles involving the Anglo-Saxons": "معارك الأنجلوساكسونيين",
    "Battles involving the Ayyubids": "معارك الأيوبيين",
    "Battles involving the Canaanites": "معارك الكنعانيين",
    "Battles involving the Ghurid dynasty": "معارك الغوريين",
    "Battles involving the Ghurids": "معارك الغوريين",
    "Battles involving the Hittite Empire": "معارك الحيثيين",
    "Battles involving the Medes": "معارك الميديين",
    "Battles involving the Median kingdom": "معارك الميديين",
    "Battles involving the Visigoths": "معارك القوط الغربيين",
    "Belarusian collaborators with Nazi Germany": "تعاون البيلاروسيين مع ألمانيا النازية",
    "Belarusian partisans": "الثوار البيلاروسيين",
    "Bengali Muslim scholars of Islam": "علماء المسلمين البنغاليين في الإسلام",
    "Biographical films about journalists": "أفلام سير ذاتية عن صحفيين",
    "Biographical films about mass media people": "أفلام سير ذاتية عن الإعلاميين",
    "Biographical films about mathematicians": "أفلام سير ذاتية عن رياضياتيين",
    "Biographical films about military leaders": "أفلام سير ذاتية عن قادة عسكريين",
    "Biographical films about military personnel": "أفلام سير ذاتية عن عسكريين",
    "Biographical films about musicians": "أفلام سير ذاتية عن موسيقيين",
    "Biographical films about politicians": "أفلام سير ذاتية عن سياسيين",
    "Biographical films about religious leaders": "أفلام سير ذاتية عن قادة دينيين",
    "Biographical films about revolutionaries": "أفلام سير ذاتية عن ثوريين",
    "Biographical films about sports-people": "أفلام سير ذاتية عن رياضيين",
    "Biographical films about war correspondents": "أفلام سير ذاتية عن مراسلين حربيين",
    "Biographical plays about politicians": "مسرحيات سير ذاتية عن سياسيين",
    "Biographies about African-American people": "سير ذاتية عن أمريكيين أفارقة",
    "Biographies about American Jews": "سير عن يهود أمريكيين",
    "Biographies about musicians": "سير عن موسيقيين",
    "Biographies about politicians": "سير عن سياسيين",
    "Bishops of Vienne": "أساقفة من فيين (إقليم فرنسي)",
    "Black metal albums by Swedish artists": "ألبومات بلاك ميتال لفنانين سويديين",
    "Blues albums by British artists": "ألبومات بلوز لفنانين بريطانيين",
    "Blues albums by Egyptian artists": "ألبومات بلوز لفنانين مصريين",
    "Book of Leviticus": "سفر اللاويين",
    "Books about American politicians": "كتب عن سياسيين أمريكيين",
    "Books about British politicians": "كتب عن سياسيين بريطانيين",
    "Books about Native American history": "كتب عن تاريخ الأمريكيين الأصليين",
    "Books about Palestinians": "كتب عن فلسطينيين",
    "Books about Russian politicians": "كتب عن سياسيين روس",
    "Books about entertainers": "كتب عن فنانين ترفيهيين",
    "Books about musicians": "كتب عن موسيقيين",
    "Books about politicians": "كتب عن سياسيين",
    "Books about sports-people": "كتب عن رياضيين",
    "Boucles de la Mayenne": "بوكل دو لا مايين",
    "Boxing Olympic champions navigational boxes": "قوالب تصفح الأبطال الأولمبيين في الملاكمة",
    "British Asian footballers": "لاعبو آسيويين بريطانيون",
    "British Indian history": "تاريخ الهنود البريطانيين",
    "British forensic pathologists": "أطباء شرعيين بريطانيون",
    "British geophysicists": "جيوفيزيائيين بريطانيون",
    "British military memorials and cemeteries": "نصب تذكارية ومقابر عسكريين بريطانيين",
    "British writer navigational boxes": "قوالب تصفح كتاب بريطانيين",
    "Buddhist terrorism": "إرهاب منسوب للبوذيين",
    "Buildings and structures by British architects": "مبان ومنشآت حسب معماريين بريطانيين",
    "Buildings and structures by English architects": "مبان ومنشآت حسب معماريين إنجليز",
    "Buildings and structures in Haute-Vienne": "مبان ومنشآت في فيين العليا (إقليم فرنسي)",
    "Buildings and structures in Payne County, Oklahoma": "مبان ومنشآت في مقاطعة بايين (أوكلاهوما)",
    "Buildings and structures in Vienne": "مبان ومنشآت في فيين (إقليم فرنسي)",
    "Buildings and structures in Vienne (department)": "مبان ومنشآت في فيين (إقليم فرنسي)",
    "Burkina Faso men's A' international footballers": "لاعبو منتخب بوركينا فاسو لكرة القدم للرجال للمحليين",
    "Burundi men's A' international footballers": "لاعبو منتخب بوروندي لكرة القدم للرجال للمحليين",
    "Caffeine": "كافيين",
    "Cameroon men's A' international footballers": "لاعبو منتخب الكاميرون لكرة القدم للرجال للمحليين",
    "Camiguin": "كاميغويين",
    "Canadian filmographies": "قوائم أعمال لممثلين كنديين",
    "Canadian geophysicists": "جيوفيزيائيين كنديون",
    "Canadian military memorials and cemeteries": "نصب تذكارية ومقابر عسكريين كنديين",
    "Canadian rock musician navigational boxes": "قوالب مغنو روك كنديين",
    "Canadian rock musician templates": "قوالب مغنو روك كنديين",
    "Career achievements of sports-people": "إنجازات الرياضيين المهنية",
    "Castles of the Nizari Ismaili state": "قلاع إسماعيليين",
    "Cayenne": "كايين",
    "Censorship of LGBT issues": "الرقابة في قضايا المثليين",
    "Censorship of LGBTQ issues": "الرقابة في قضايا المثليين",
    "Central Asian American": "أمريكيون آسيويين أوسطيون",
    "Central Asian Jews": "يهود آسيويين أوسطيون",
    "Central Asian Muslims": "مسلمون آسيويين أوسطيون",
    "Central Asian diaspora in the United States": "أمريكيون آسيويين أوسطيون",
    "Central Asian people by religion": "أعلام آسيويين أوسطيون حسب الدين",
    "Centre of Social Democrats politicians": "سياسيو وسط الديمقراطيين الاشتراكيين",
    "Ceremonial officers in the United Kingdom": "ضباط مقلدين بريطانيين",
    "Chaldean kings": "ملوك كلدانيين",
    "Chennaiyin FC": "نادي تشينايين",
    "Chennaiyin FC managers": "مدربو نادي تشينايين",
    "Chennaiyin FC players": "لاعبو نادي تشينايين",
    "Chennaiyin FC templates": "قوالب نادي تشينايين",
    "Child murder in Asia": "أطفال آسيويين قتلوا",
    "Children of presidents of France": "أبناء قادة وطنيين في فرنسا",
    "Chinese diaspora in Thailand": "تايلانديين صينيين",
    "Christian holy places": "أماكن مقدسة للمسيحيين",
    "Christian music albums by American artists": "ألبومات موسيقى مسيحية لفنانين أمريكيين",
    "Christian music albums by South Korean artists": "ألبومات موسيقى مسيحية لفنانين كوريين جنوبيين",
    "Christian socialist theologians": "اللاهوتيين الاشتراكيين المسيحيين",
    "Christian terrorism": "إرهاب منسوب للمسيحيين",
    "Christian terrorism by continent": "إرهاب منسوب للمسيحيين حسب القارة",
    "Christian terrorism in Africa": "إرهاب منسوب للمسيحيين في إفريقيا",
    "Christian terrorism in Asia": "إرهاب منسوب للمسيحيين في آسيا",
    "Christian terrorism in Europe": "إرهاب منسوب للمسيحيين في أوروبا",
    "Christian terrorism in North America": "إرهاب منسوب للمسيحيين في أمريكا الشمالية",
    "Christian terrorism in the United States": "إرهاب منسوب للمسيحيين في الولايات المتحدة",
    "Christmas albums by South Korean artists": "ألبومات عيد الميلاد لفنانين كوريين جنوبيين",
    "Cities in Payne County, Oklahoma": "مدن في مقاطعة بايين (أوكلاهوما)",
    "Cocaine": "كوكايين",
    "Cocaine in the United States": "كوكايين في الولايات المتحدة",
    "Colombian serial killers": "قتلة متسلسلون كولومبيين",
    "Colombian victims of crime": "ضحايا جرائم كولومبيين",
    "Comedy-drama films about Asian Americans": "أفلام كوميدية درامية عن أمريكيون آسيويين",
    "Commanders in chief": "القادة العسكريين",
    "Communes of Haute-Vienne": "بلديات فيين العليا",
    "Communes of Vienne": "بلديات فيين (إقليم فرنسي)",
    "Communes of Vienne (department)": "بلديات فيين (إقليم فرنسي)",
    "Compiègne": "كومبيين",
    "Concubines of the Abbasid caliphs": "محظيات الخلفاء العباسيين",
    "Constituencies for French residents overseas": "النواب الممثلون للفرنسيين المقيمين في الخارج",
    "Contemporary R&B albums by American artists": "ألبومات آر إن بي لفنانين أمريكيين",
    "Contemporary R&B albums by British artists": "ألبومات آر إن بي لفنانين بريطانيين",
    "Contemporary R&B albums by Canadian artists": "ألبومات آر أند بي معاصر لفنانين كنديين",
    "Coronations of British monarchs": "تتويج الملوك البريطانيين",
    "Countries at the African Nations Championship": "بلدان في بطولة أمم إفريقيا للمحليين",
    "Crimean Karaites": "قريميين",
    "Crimes of the communist regime in Ukraine against Ukrainians": "جرائم النظام الشيوعي في أوكرانيا ضد الأوكرانيين",
    "Croatian geophysicists": "جيوفيزيائيين كروات",
    "Culture of Camiguin": "ثقافة كاميغويين",
    "Dance music albums by American artists": "ألبومات موسيقى الرقص لفنانين أمريكيين",
    "Dance music albums by Australian artists": "ألبومات موسيقى الرقص لفنانين أستراليين",
    "Dance music albums by British artists": "ألبومات موسيقى الرقص لفنانين بريطانيين",
    "Dance music albums by Canadian artists": "ألبومات موسيقى الرقص لفنانين كنديين",
    "Dance music albums by Mexican artists": "ألبومات موسيقى الرقص لفنانين مكسيكيين",
    "Dance music albums by Romanian artists": "ألبومات موسيقى الرقص لفنانين رومانيين",
    "Dance music albums by Swedish artists": "ألبومات موسيقى الرقص لفنانين سويديين",
    "Dance-pop albums by American artists": "ألبومات بوب الرقص لفنانين أمريكيين",
    "Dance-pop albums by Australian artists": "ألبومات بوب الرقص لفنانين أستراليين",
    "Dance-pop albums by British artists": "ألبومات بوب الرقص لفنانين بريطانيين",
    "Dance-pop albums by Canadian artists": "ألبومات بوب الرقص لفنانين كنديين",
    "Dance-pop albums by Mexican artists": "ألبومات بوب الرقص لفنانين مكسيكيين",
    "Danish geophysicists": "جيوفيزيائيين دنماركيون",
    "Deaths from arteriosclerosis": "وفيات بسبب تصلب الشرايين",
    "Democratic republic of congo men's A' international footballers": "لاعبو منتخب جمهورية الكونغو الديمقراطية لكرة القدم للرجال للمحليين",
    "Directors Guild of America": "نقابة المخرجين الأمريكيين",
    "Discalced Carmelite Order": "رهبنة الكرمليين الحفاة",
    "Disco albums by American artists": "ألبومات ديسكو لفنانين أمريكيين",
    "Disco albums by Australian artists": "ألبومات ديسكو لفنانين أستراليين",
    "Disco albums by British artists": "ألبومات ديسكو فنانين بريطانيين",
    "Discographies of American artists": "ديسكوغرافيات الفنانين الأمريكيين",
    "Discographies of Japanese artists": "ديسكوغرافيا فنانين يابانيين",
    "Discoveries by astronomer": "اكتشافات فلكيين",
    "Diseases of arteries, arterioles and capillaries": "أمراض الشرايين والشرينات والشعيرات الدموية",
    "Documentary films about African Americans": "أفلام وثائقية عن أمريكيين أفارقة",
    "Documentary films about American politicians": "أفلام وثائقية عن سياسيين أمريكيين",
    "Documentary films about classical music and musicians": "أفلام وثائقية عن الموسيقيين والموسيقى الكلاسيكية",
    "Documentary films about comedy and comedians": "أفلام وثائقية عن كوميدية وكوميديين",
    "Documentary films about indigenous rights": "أفلام وثائقية عن حقوق السكان الأصليين",
    "Documentary films about journalists": "أفلام وثائقية عن صحفيين",
    "Documentary films about mass media people": "أفلام وثائقية عن الإعلاميين",
    "Documentary films about music and musicians": "أفلام وثائقية عن الموسيقى والموسيقيين",
    "Documentary films about playwrights": "أفلام وثائقية عن كتاب مسرحيين",
    "Documentary films about politicians": "أفلام وثائقية عن سياسيين",
    "Documentary films about sports-people": "أفلام وثائقية عن رياضيين",
    "Documentary films about visual artists": "أفلام وثائقية عن فنانين بصريين",
    "Documentary films about war correspondents": "أفلام وثائقية عن مراسلين حربيين",
    "Domestic workers in films": "أفلام عن عمال منزليين",
    "Dong Phaya Yen Mountains": "مجمع دونغ فايايين كاو ياي الحرجي",
    "Dutch child singers": "مطربين هولنديين أطفال",
    "East Francia": "مملكة الفرنجة الشرقيين",
    "Education in Payne County, Oklahoma": "التعليم في مقاطعة بايين (أوكلاهوما)",
    "Egyptian writer navigational boxes": "قوالب تصفح كتاب مصريين",
    "Electronic albums by American artists": "ألبومات إليكترونيك لفنانين أمريكيين",
    "Electronic albums by Australian artists": "ألبومات إليكترونيك لفنانين أستراليين",
    "Electronic albums by British artists": "ألبومات إليكترونيك لفنانين بريطانيين",
    "Electronic albums by French artists": "ألبومات إليكترونيك لفنانين فرنسيين",
    "Electronic albums by Greek artists": "ألبومات إليكترونيك لفنانين يونانيين",
    "Electronic albums by Swedish artists": "ألبومات إليكترونيك لفنانين سويديين",
    "Electronic dance music albums by American artists": "ألبومات موسيقى الرقص الإلكترونية لفنانين أمريكيين",
    "Electronic dance music albums by Swedish artists": "ألبومات موسيقى الرقص الإلكترونية لفنانين سويديين",
    "English agronomists": "مهندسون زراعيين إنجليز",
    "Epistle to the Hebrews": "الرسالة إلى العبرانيين",
    "Equatorial Guinea men's A' international footballers": "لاعبو منتخب غينيا الاستوائية لكرة القدم للرجال للمحليين",
    "Establishments in East Francia": "تأسيسات في مملكة الفرنجة الشرقيين",
    "Ethiopia men's A' international footballers": "لاعبو منتخب إثيوبيا لكرة القدم للرجال للمحليين",
    "European Commissioners by country navigational boxes": "صناديق تصفح مفوضين أوروبيين حسب البلد",
    "European Conservatives and Reformists Party": "تحالف المصلحين والمحافظين الأوروبيين",
    "European artist groups and collectives": "مجموعات وجماعيات فنانين أوروبيين",
    "European commissioners by country navigational boxes": "صناديق تصفح مفوضين أوروبيين حسب البلد",
    "Experimental music albums by American artists": "ألبومات موسيقى تجريبية لفنانين أمريكيين",
    "FBI Most Wanted Terrorists": "أكثر الإرهابيين مطلوبية لمكتب التحقيقات الفيدرالي",
    "FC Biel-Bienne": "نادي بيل-بيين",
    "FC Biel-Bienne managers": "مدربو نادي بيل-بيين",
    "FC Biel-Bienne players": "لاعبو نادي بيل-بيين",
    "Fallschirmjäger divisions": "فرق المظليين",
    "Fellows of the American Institute of Architects": "زملاء الجمعية الأمريكية للمعماريين",
    "Fellows of the American Institute of Chemical Engineers": "زملاء المعهد الأمريكي للمهندسين الكيميائيين",
    "Fellows of the American Society of Civil Engineers": "زملاء الجمعية الأمريكية للمهندسين المدنيين",
    "Fellows of the American Society of Mechanical Engineers": "زملاء الجمعية الأمريكية للمهندسين الميكانيكيين",
    "Fellows of the Biomedical Engineering Society": "زملاء مجتمع المهندسين الطبيين",
    "Fellows of the Institution of Civil Engineers": "زملاء معهد المهندسين المدنيين",
    "Fellows of the Royal College of Psychiatrists": "زملاء الكلية الملكية للأطباء النفسيين",
    "Fellows of the Royal Institute of British Architects": "زملاء المعهد الملكي للمعماريين البريطانيين",
    "Fiction about same-sex marriage": "زواج المثليين في الأعمال الخيالية",
    "Films about American military personnel": "أفلام عن عسكريين أمريكيين",
    "Films about American politicians": "أفلام عن سياسيين أمريكيين",
    "Films about Native Americans": "أفلام عن السكان الأصليين في الولايات المتحدة",
    "Films about Nazi hunters": "أفلام عن صيادي النازيين",
    "Films about Nazis": "أفلام عن نازيين",
    "Films about North Korean defectors": "أفلام عن كوريين شماليين منشقين",
    "Films about bodyguards": "أفلام عن حراس شخصيين",
    "Films about classical music and musicians": "أفلام عن الموسيقيين والموسيقى الكلاسيكية",
    "Films about cocaine": "أفلام عن كوكايين",
    "Films about comedians": "أفلام عن كوميديين",
    "Films about fictional painters": "أفلام عن رسامين خياليين",
    "Films about journalists": "أفلام عن صحفيين",
    "Films about mass media people": "أفلام عن الإعلاميين",
    "Films about military personnel": "أفلام عن عسكريين",
    "Films about music and musicians": "أفلام عن الموسيقى والموسيقيين",
    "Films about playwrights": "أفلام عن كتاب مسرحيين",
    "Films about politicians": "أفلام عن سياسيين",
    "Films about psychopaths and sociopaths": "أفلام عن السيكوباثيين",
    "Films about revolutionaries": "أفلام عن ثوريين",
    "Films about socialites": "أفلام عن اجتماعيين",
    "Films about sports-people": "أفلام عن رياضيين",
    "Films about the 1948 Palestinian exodus": "أفلام عن تهجير الفلسطينيين عام 1948",
    "Films about war correspondents": "أفلام عن مراسلين حربيين",
    "Films based on Brewster's Millions": "أفلام مبنية على ملايين بروستر",
    "Films by African-American directors": "أفلام مخرجين أفارقة أمريكيين",
    "Films by Algerian directors": "أفلام حسب المخرجين الجزائريين",
    "Films by American directors": "أفلام حسب المخرجين الأمريكيين",
    "Films by Argentine directors": "أفلام مخرجين أرجنتينيين",
    "Films by Australian directors": "أفلام حسب المخرجين الأستراليين",
    "Films by Australian producers": "أفلام منتجين أستراليين",
    "Films by Austrian directors": "أفلام حسب المخرجين النمساويين",
    "Films by Belgian directors": "أفلام مخرجين بلجيكيين",
    "Films by Bosnia and Herzegovina directors": "أفلام مخرجين بوسنيين",
    "Films by Brazilian directors": "أفلام مخرجين برازيليين",
    "Films by British directors": "أفلام مخرجين بريطانيين",
    "Films by British producers": "أفلام منتجين بريطانيين",
    "Films by Burkinabe directors": "أفلام مخرجين بوركينابيين",
    "Films by Cambodian directors": "أفلام مخرجين كمبوديين",
    "Films by Canadian directors": "أفلام حسب المخرجين الكنديين",
    "Films by Chadian directors": "أفلام مخرجين تشاديين",
    "Films by Chilean directors": "أفلام مخرجين تشيليين",
    "Films by Chinese directors": "أفلام مخرجين صينيين",
    "Films by Colombian directors": "أفلام مخرجين كولومبيين",
    "Films by Cuban directors": "أفلام لمخرجين كوبيين",
    "Films by Czech directors": "أفلام حسب المخرجين التشيكيين",
    "Films by Czechoslovak directors": "أفلام مخرجين تشيكوسلوفاكيين",
    "Films by Danish directors": "أفلام لمخرجين دنماركيين",
    "Films by Dutch directors": "أفلام مخرجين هولنديين",
    "Films by Egyptian directors": "أفلام حسب المخرجين المصريين",
    "Films by English directors": "أفلام حسب المخرجين الإنجليزيين",
    "Films by Filipino directors": "أفلام مخرجين فلبينيين",
    "Films by French directors": "أفلام حسب المخرجين الفرنسيين",
    "Films by French producers": "أفلام منتجين فرنسيين",
    "Films by Greek directors": "أفلام مخرجين يونانيين",
    "Films by Haitian directors": "أفلام مخرجين هايتيين",
    "Films by Hong Kong producers": "أفلام منتجين هونغ كونغيين",
    "Films by Hungarian directors": "أفلام مخرجين مجريين",
    "Films by Hungarian producers": "أفلام منتجين مجريين",
    "Films by Icelandic directors": "أفلام مخرجين آيسلنديين",
    "Films by Indonesian directors": "أفلام مخرجين إندونيسيين",
    "Films by Iranian directors": "أفلام من إخراج مخرجين إيرانيين",
    "Films by Iraqi directors": "أفلام مخرجين عراقيين",
    "Films by Irish directors": "أفلام مخرجين أيرلنديين",
    "Films by Israeli directors": "أفلام مخرجين إسرائيليين",
    "Films by Israeli producers": "أفلام منتجين إسرائيليين",
    "Films by Italian directors": "أفلام المخرجين الإيطاليين",
    "Films by Italian producers": "أفلام منتجين إيطاليين",
    "Films by Japanese directors": "أفلام حسب المخرجين اليابانيين",
    "Films by Japanese producers": "أفلام منتجين يابانيين",
    "Films by Kazakhstani directors": "أفلام مخرجين كازاخستانيين",
    "Films by Korean directors": "أفلام مخرجين كوريين",
    "Films by Lebanese directors": "أفلام مخرجين لبنانيين",
    "Films by Lebanese producers": "أفلام منتجين لبنانيين",
    "Films by Malaysian directors": "أفلام مخرجين ماليزيين",
    "Films by Malian directors": "أفلام مخرجين ماليين",
    "Films by Mauritanian directors": "أفلام مخرجين موريتانيين",
    "Films by Mexican directors": "أفلام حسب المخرجين المكسيكيين",
    "Films by Mexican producers": "أفلام منتجين مكسيكيين",
    "Films by New Zealand directors": "أفلام حسب المخرجين النيوزيلنديين",
    "Films by New Zealand producers": "أفلام منتجين نيوزيلنديين",
    "Films by Nigerian directors": "أفلام مخرجين نيجيريين",
    "Films by Nigerian producers": "أفلام منتجين نيجيريين",
    "Films by Norwegian directors": "أفلام مخرجين نرويجيين",
    "Films by Pakistani directors": "أفلام مخرجين باكستانيين",
    "Films by Palestinian directors": "أفلام مخرجين فلسطينيين",
    "Films by Peruvian directors": "أفلام مخرجين بيرويين",
    "Films by Polish directors": "أفلام مخرجين بولنديين",
    "Films by Polish producers": "أفلام منتجين بولنديين",
    "Films by Portuguese directors": "أفلام مخرجين برتغاليين",
    "Films by Portuguese producers": "أفلام منتجين برتغاليين",
    "Films by Puerto Rican directors": "أفلام مخرجين بورتوريكيين",
    "Films by Romanian directors": "أفلام مخرجين رومانيين",
    "Films by Scottish directors": "أفلام مخرجين إسكتلنديين",
    "Films by Senegalese directors": "أفلام لمخرجين سنغاليين",
    "Films by Slovak directors": "أفلام مخرجين سلوفاكيين",
    "Films by Slovak producers": "أفلام منتجين سلوفاكيين",
    "Films by South Korean directors": "أفلام مخرجين كوريين جنوبيين",
    "Films by South Korean producers": "أفلام منتجين كوريين جنوبيين",
    "Films by Swedish directors": "أفلام مخرجين سويديين",
    "Films by Swiss directors": "أفلام مخرجين سويسريين",
    "Films by Swiss producers": "أفلام منتجين سويسريين",
    "Films by Syrian directors": "أفلام مخرجين سوريين",
    "Films by Taiwanese directors": "أفلام مخرجين تايوانيين",
    "Films by Taiwanese producers": "أفلام منتجين تايوانيين",
    "Films by Tunisian directors": "أفلام مخرجين تونسيين",
    "Films by Ukrainian directors": "أفلام مخرجين أوكرانيين",
    "Films by Welsh directors": "أفلام مخرجين ويلزيين",
    "Films by Yugoslav directors": "أفلام مخرجين يوغسلافيين",
    "Floristry": "تزيين بالزهور",
    "Folk albums by American artists": "ألبومات تراث شعبي لفنانين أمريكيين",
    "Folk albums by British artists": "ألبومات تراث شعبي لفنانين بريطانيين",
    "Folk albums by Canadian artists": "ألبومات تراث شعبي لفنانين كنديين",
    "Folk albums by Egyptian artists": "ألبومات تراث شعبي لفنانين مصريين",
    "Folk albums by Emirati artists": "ألبومات تراث شعبي لفنانين إماراتيين",
    "Folk albums by Iranian artists": "ألبومات تراث شعبي لفنانين إيرانيين",
    "Folk albums by Irish artists": "ألبومات تراث شعبي لفنانين أيرلنديين",
    "Folk albums by Lebanese artists": "ألبومات تراث شعبي لفنانين لبنانيين",
    "Folk albums by Tunisian artists": "ألبومات تراث شعبي لفنانين تونسيين",
    "Folk rock albums by American artists": "ألبومات روك شعبي لفنانين أمريكيين",
    "Folk rock albums by British artists": "ألبومات روك شعبي لفنانين بريطانيين",
    "Folk rock albums by Canadian artists": "ألبومات روك شعبي لفنانين كنديين",
    "Footballers from Cayenne": "لاعبو كرة قدم من كايين",
    "Forced migrations of Native Americans in the United States": "ترحيل قسري للسكان الأصليين في الولايات المتحدة",
    "Forensic pathologists": "أطباء شرعيين",
    "Free Egyptians Party politicians": "سياسيو حزب المصريين الأحرار",
    "French film director navigational boxes": "صناديق تصفح مخرجي أفلام فرنسيين",
    "Funk albums by American artists": "ألبومات فانك لفنانين أمريكيين",
    "Gabon men's A' international footballers": "لاعبو منتخب الغابون لكرة القدم للرجال للمحليين",
    "Gangsta rap albums by American artists": "ألبومات راب عصابات لفنانين أمريكيين",
    "Gay male literature": "أدب المثليين جنسياً",
    "Gay villages": "قرى مثليين",
    "Gay villages in Brazil": "قرى مثليين في البرازيل",
    "Gay villages in California": "قرى مثليين في كاليفورنيا",
    "Gay villages in New York (state)": "قرى مثليين في ولاية نيويورك",
    "Gay villages in the United States": "قرى مثليين في الولايات المتحدة",
    "Geography of Camiguin": "جغرافيا كاميغويين",
    "Geography of Haute-Vienne": "جغرافيا فيين العليا",
    "Geography of Payne County, Oklahoma": "جغرافيا مقاطعة بايين (أوكلاهوما)",
    "Geography of Vienne": "جغرافيا فيين (إقليم فرنسي)",
    "Geography of Vienne (department)": "جغرافيا فيين (إقليم فرنسي)",
    "German military governors of Paris": "الحكام العسكريين الألمان لباريس",
    "German naval architects": "المهندسين المعماريين البحريين الألمان",
    "Gesta Hungarorum": "أعمال المجريين (مخطوطة)",
    "Ghana men's A' international footballers": "لاعبو منتخب غانا لكرة القدم للرجال للمحليين",
    "Glider pilots": "مزلق الطياريين",
    "Governors of Camiguin": "حكام من كاميغويين",
    "Grand Duchy of Tuscany people": "الدوقية العظمى للتوسكانيين",
    "Great Officers of State": "أكابر موظفي الدولة البريطانيين",
    "Greek genocide": "مذابح اليونانيين البونتيك",
    "Guinea men's A' international footballers": "لاعبو منتخب غينيا لكرة القدم للرجال للمحليين",
    "Gutian dynasty of Sumer": "سلالة الجوتيين في سومر",
    "Halloween food": "مأكولات ترتبط بالهالويين",
    "Hard rock albums by American artists": "ألبومات هارد روك لفنانين أمريكيين",
    "Hard rock albums by British artists": "ألبومات هارد روك لفنانين بريطانيين",
    "Haute-Vienne": "فيين العليا (إقليم فرنسي)",
    "Heavy metal albums by American artists": "ألبومات هيفي ميتال لفنانين أمريكيين",
    "Hetmans of the Zaporozhian Cossacks": "هيتمان القوزاق الزاباروجيين",
    "Hinduism-motivated violence in India": "إرهاب منسوب للهندوسيين",
    "Hip hop albums by American artists": "ألبومات هيب هوب من قبل فنانين أميركيين",
    "Hip-hop albums by American artists": "ألبومات هيب هوب من قبل فنانين أميركيين",
    "Hip-hop albums by British artists": "ألبومات هيب هوب لفنانين بريطانيين",
    "Hip-hop albums by Canadian artists": "ألبومات هيب هوب لفنانين كنديين",
    "Hispanic and Latino American sitcoms": "لاتينيين كوميدية الموقف",
    "Historians of African Americans": "مؤرخو الأمريكيين الأفارقة",
    "Historians of Native Americans": "مؤرخو السكان الأصليين في الولايات المتحدة",
    "Historians of the Hazaraspids": "مؤرخو الهزارسبيين",
    "Historians under the Buyid dynasty": "مؤرخون عاصروا البويهيين",
    "History of Assyria": "تاريخ الآشوريين",
    "History of Haute-Vienne": "تاريخ فيين العليا",
    "History of Indigenous Australians": "تاريخ سكان أستراليا الأصليين",
    "History of Indigenous peoples of North America": "تاريخ السكان الأمريكيين الأصليين الشماليين",
    "History of Vienne": "تاريخ فيين (إقليم فرنسي)",
    "History of Vienne (department)": "تاريخ فيين (إقليم فرنسي)",
    "History of indigenous peoples of North America": "تاريخ السكان الأمريكيين الأصليين الشماليين",
    "History of the Palestinian refugees": "تاريخ اللاجئين الفلسطينيين",
    "Hittite kings": "ملوك الحيثيين",
    "House of Brienne": "أسرة بريين",
    "Houthi insurgency in Yemen": "تمرد الحوثيين في اليمن",
    "Huayin": "هوايين",
    "Huguenot history in France": "تاريخ الهوغونوتيين في فرنسا",
    "Hurrian kings": "ملوك الحوريين",
    "Hussite Wars": "حروب الهوسيين",
    "Illegitimate children of Portuguese monarchs": "أطفال غير شرعيين من ملوك البرتغال",
    "Illegitimate children of monarchs": "أبناء شخصيات ملكية غير شرعيين",
    "Immigration and LGBT topics": "الهجرة ومواضيع المثليين",
    "Immigration and LGBTQ topics": "الهجرة ومواضيع المثليين",
    "Independent Republicans politicians": "سياسيو حزب الجمهوريين المستقلين",
    "Indian military memorials and cemeteries": "نصب تذكارية ومقابر عسكريين هنود",
    "Indian reserves": "محميات سكان أصليين",
    "Indian reserves by province or territory": "محميات سكان أصليين حسب المحافظة أو الإقليم",
    "Indian reserves in Saskatchewan": "محميات سكان أصليين في ساسكاتشوان",
    "Indie folk albums by American artists": "ألبومات إندي فولك لفنانين أمريكيين",
    "Indie rock albums by American artists": "ألبومات إيندي روك لفنانين أمريكيين",
    "Indigenous Christianity": "مسيحية السكان الأصليين",
    "Indigenous affairs ministries": "وزارات شؤون سكان أصليين",
    "Indigenous cinema": "سينما تتعلق بالسكان الأصليين",
    "Indigenous culture in Canada": "حضارة السكان الأصليين في كندا",
    "Indigenous culture of Asia": "ثقافة السكان الأصليين في آسيا",
    "Indigenous land rights": "حقوق أراضي السكان الأصليين",
    "Indigenous law": "قوانين السكان الأصليين",
    "Indigenous literature": "أدب السكان الأصليين",
    "Indigenous mass media": "وسائل إعلام السكان الأصليين",
    "Indigenous nationalism": "قومية السكان الأصليين",
    "Indigenous peoples of the Caribbean": "سكان الكاريبي الأصليين",
    "Indigenous politics": "سياسة السكان الأصليين",
    "Indigenous politics in Brazil": "سياسة السكان الأصليين في البرازيل",
    "Indigenous politics in Canada": "سياسة السكان الأصليين في كندا",
    "Indigenous politics in Europe": "سياسة السكان الأصليين في أوروبا",
    "Indigenous politics in Mexico": "سياسة السكان الأصليين في المكسيك",
    "Indigenous politics in North America": "سياسة السكان الأصليين في أمريكا الشمالية",
    "Indigenous politics in Oceania": "سياسة السكان الأصليين في أوقيانوسيا",
    "Indigenous politics in South America": "سياسة السكان الأصليين في أمريكا الجنوبية",
    "Indigenous politics in the Americas": "سياسة السكان الأصليين في الأمريكتين",
    "Indigenous rights": "حقوق السكان الأصليين",
    "Indigenous rights in Canada": "حقوق السكان الأصليين في كندا",
    "Individuals designated as terrorists by the United States government": "أفراد وصفتهم حكومة الولايات المتحدة بالإرهابيين",
    "Industrial Workers of the World": "العمال الصناعيين في العالم",
    "Institution of Chemical Engineers": "معهد المهندسين الكيميائيين",
    "Institution of Civil Engineers": "معهد المهندسين المدنيين",
    "Institution of Mechanical Engineers": "معهد المهندسين الميكانيكيين",
    "Institution of Structural Engineers": "معهد المهندسين الإنشائيين",
    "International Federation of Journalists": "الاتحاد الدولي للصحفيين",
    "Internment camps for Japanese Americans": "معسكرات اعتقال الأمريكيين اليابانيين",
    "Internment of Japanese Americans": "اعتقال الأمريكيين اليابانيين",
    "Intra-Palestinian peace efforts": "جهود السلام بين الفلسطينيين",
    "Invasions by the Umayyad Caliphate": "غزوات الأمويين",
    "Iranian writer navigational boxes": "صناديق تصفح كتاب إيرانيين",
    "Iranian writer templates": "قوالب كتاب إيرانيين",
    "Israeli casualties in the Second Intifada": "ضحايا إسرائيليين في الانتفاضة الفلسطينية الثانية",
    "Israeli colonels": "عقداء إسرائيليين",
    "Israeli settler violence": "عنف المستوطنين الإسرائيليين",
    "Italian expatriates in Austria": "مغتربين إيطاليين في النمسا",
    "Ivory Coast men's A' international footballers": "لاعبو منتخب ساحل العاج لكرة القدم للرجال للمحليين",
    "Japanese film director navigational boxes": "صناديق تصفح مخرجي أفلام يابانيين",
    "Japanese writer navigational boxes": "قوالب تصفح كتاب يابانيين",
    "Jazz albums by American artists": "ألبومات جاز لفنانين أمريكيين",
    "Jazz albums by British artists": "ألبومات جاز لفنانين بريطانيين",
    "Jazz albums by Canadian artists": "ألبومات جاز لفنانين كنديين",
    "Jazz albums by Egyptian artists": "ألبومات جاز لفنانين مصريين",
    "Jazz fusion albums by American artists": "ألبومات جاز فيوشن لفنانين أمريكيين",
    "Jesuit publications": "إصدارات يسوعيين",
    "Joint suicides by Nazis": "حالات انتحار مشتركة بين النازيين",
    "Karaite Jews": "قريميين",
    "Kassite kings": "ملوك كاشيين",
    "Kayin State": "ولاية كايين",
    "Kingdom of the Suebi": "مملكة السويبيين",
    "Kings of East Francia": "ملوك مملكة الفرنجة الشرقيين",
    "Kinin–kallikrein system": "نظام كاينين-كاليكريين",
    "Korean Catholics": "كاثوليكيون كوريين",
    "LGBT adoption": "تبني المثليين للأطفال",
    "LGBT adoption in Europe": "تبني المثليين للأطفال في أوروبا",
    "LGBT adoption in the United States": "تبني المثليين للأطفال في الولايات المتحدة",
    "LGBT beauty pageants": "مسابقات الجمال للمثليين",
    "LGBT culture": "ثقافة المثليين",
    "LGBT culture by city": "ثقافة المثليين حسب المدينة",
    "LGBT culture by continent": "ثقافة المثليين حسب القارة",
    "LGBT culture by country": "ثقافة المثليين حسب البلد",
    "LGBT culture by location": "ثقافة المثليين حسب الموقع",
    "LGBT culture by region": "ثقافة المثليين حسب المنطفة",
    "LGBT culture in Asia": "ثقافة المثليين في آسيا",
    "LGBT culture in Australia": "ثقافة المثليين في أستراليا",
    "LGBT culture in Australia by city": "ثقافة المثليين في أستراليا حسب المدينة",
    "LGBT culture in Brazil": "ثقافة المثليين في البرازيل",
    "LGBT culture in Canada": "ثقافة المثليين في كندا",
    "LGBT culture in Denmark": "ثقافة المثليين في الدنمارك",
    "LGBT culture in England": "ثقافة المثليين في إنجلترا",
    "LGBT culture in Europe": "ثقافة المثليين في أوروبا",
    "LGBT culture in Europe by country": "ثقافة المثليين في أوروبا حسب البلد",
    "LGBT culture in France": "ثقافة المثليين في فرنسا",
    "LGBT culture in Germany": "ثقافة المثليين في ألمانيا",
    "LGBT culture in Greenland": "ثقافة المثليين في جرينلاند",
    "LGBT culture in India": "ثقافة المثليين في الهند",
    "LGBT culture in Ireland": "ثقافة المثليين في أيرلندا",
    "LGBT culture in Italy": "ثقافة المثليين في إيطاليا",
    "LGBT culture in Japan": "ثقافة المثليين في اليابان",
    "LGBT culture in Liverpool": "ثقافة المثليين في ليفربول",
    "LGBT culture in London": "ثقافة المثليين في لندن",
    "LGBT culture in Mexico": "ثقافة المثليين في المكسيك",
    "LGBT culture in North America": "ثقافة المثليين في أمريكا الشمالية",
    "LGBT culture in Norway": "ثقافة المثليين في النرويج",
    "LGBT culture in Scotland": "ثقافة المثليين في إسكتلندا",
    "LGBT culture in South America": "ثقافة المثليين في أمريكا الجنوبية",
    "LGBT culture in Spain": "ثقافة المثليين في إسبانيا",
    "LGBT culture in Sydney": "ثقافة المثليين في سيدني",
    "LGBT culture in the Netherlands": "ثقافة المثليين في هولندا",
    "LGBT culture in the United Kingdom": "ثقافة المثليين في المملكة المتحدة",
    "LGBT culture in the United Kingdom by city": "ثقافة المثليين في المملكة المتحدة حسب المدينة",
    "LGBT culture in the United States by region": "ثقافة المثليين في الولايات المتحدة حسب المنطقة",
    "LGBT drinking establishments": "مؤسسات الشرب للمثليين",
    "LGBT events": "أحداث المثليين",
    "LGBT events by country": "أحداث متعلقة بالمثليين حسب البلد",
    "LGBT events in Brazil": "أحداث المثليين في البرازيل",
    "LGBT events in Denmark": "أحداث متعلقة بالمثليين في الدنمارك",
    "LGBT events in Ireland": "أحداث متعلقة بالمثليين في أيرلندا",
    "LGBT festivals": "مهرجانات المثليين",
    "LGBT film festivals": "مهرجانات أفلام المثليين",
    "LGBT health organizations": "منظمات الصحة المعنية بالمثليين",
    "LGBT health organizations in the United States": "منظمات الصحة المعنية بالمثليين في الولايات المتحدة",
    "LGBT history by country": "تاريخ المثليين حسب البلد",
    "LGBT history in Denmark": "تاريخ المثليين في الدنمارك",
    "LGBT history in Germany": "تاريخ المثليين في ألمانيا",
    "LGBT history in Ireland": "تاريخ المثليين في أيرلندا",
    "LGBT history in Italy": "تاريخ المثليين في إيطاليا",
    "LGBT history in Peru": "تاريخ المثليين في بيرو",
    "LGBT history in the United Kingdom": "تاريخ المثليين في المملكة المتحدة",
    "LGBT in the Arab world": "حقوق المثليين في الوطن العربي",
    "LGBT in the Middle East": "حقوق المثليين في الشرق الأوسط",
    "LGBT in the People's Republic of China": "معاملة المثليين في جمهورية الصين الشعبية",
    "LGBT nightclubs": "نوادي ليلية للمثليين",
    "LGBT organizations in Iceland": "منظمات المثليين في آيسلندا",
    "LGBT parenting": "الأبوة والأمومة عند المثليين",
    "LGBT parenting in North America": "الأبوة والأمومة عند المثليين في أمريكا الشمالية",
    "LGBT parenting in the United States": "الأبوة والأمومة عند المثليين في الولايات المتحدة",
    "LGBT poetry": "شعر المثليين",
    "LGBT political advocacy groups by country": "جمعيات تأييد سياسي للمثليين حسب البلد",
    "LGBT political advocacy groups in Brazil": "جمعيات تأييد سياسي للمثليين في البرازيل",
    "LGBT political advocacy groups in Denmark": "جمعيات تأييد سياسي للمثليين في الدنمارك",
    "LGBT political advocacy groups in Iceland": "جمعيات تأييد سياسي للمثليين في آيسلندا",
    "LGBT political advocacy groups in Morocco": "جمعيات تأييد سياسي للمثليين في المغرب",
    "LGBT political advocacy groups in the Netherlands": "جمعيات تأييد سياسي للمثليين في هولندا",
    "LGBT political advocacy groups in republic of Ireland": "جمعيات تأييد سياسي للمثليين في جمهورية أيرلندا",
    "LGBT politics": "سياسة المثليين جنسيا",
    "LGBT rights": "حقوق المثليين جنسيا",
    "LGBT rights by continent": "حقوق المثليين حسب القارة",
    "LGBT rights by country": "حقوق المثليين حسب البلد",
    "LGBT rights by country subdivision": "حقوق المثليين حسب المستوى دون الوطني للبلد",
    "LGBT rights by former country": "حقوق المثليين حسب البلد السابق",
    "LGBT rights by issue": "حقوق المثليين حسب القضية",
    "LGBT rights by region": "حقوق المثليين حسب المنطقة",
    "LGBT rights case law": "قضايا محاكم حول حقوق المثليين",
    "LGBT rights in Africa": "حقوق المثليين في إفريقيا",
    "LGBT rights in Africa by country": "حقوق المثليين في إفريقيا حسب البلد",
    "LGBT rights in Akrotiri and Dhekelia": "حقوق المثليين في أكروتيري ودكليا",
    "LGBT rights in Albania": "حقوق المثليين في ألبانيا",
    "LGBT rights in Andorra": "حقوق المثليين في أندورا",
    "LGBT rights in Argentina": "حقوق المثليين في الأرجنتين",
    "LGBT rights in Armenia": "حقوق المثليين في أرمينيا",
    "LGBT rights in Aruba": "حقوق المثليين في أروبا",
    "LGBT rights in Asia": "حقوق المثليين في آسيا",
    "LGBT rights in Asia by country": "حقوق المثليين في آسيا حسب البلد",
    "LGBT rights in Australia": "حقوق المثليين في أستراليا",
    "LGBT rights in Australia by state or territory": "حقوق المثليين في أستراليا حسب الولاية أو الإقليم",
    "LGBT rights in Austria": "حقوق المثليين في النمسا",
    "LGBT rights in Azerbaijan": "حقوق المثليين في أذربيجان",
    "LGBT rights in Azerbaijan by region": "حقوق المثليين في أذربيجان حسب المنطقة",
    "LGBT rights in Barbados": "حقوق المثليين في باربادوس",
    "LGBT rights in Belarus": "حقوق المثليين في روسيا البيضاء",
    "LGBT rights in Belgium": "حقوق المثليين في بلجيكا",
    "LGBT rights in Belize": "حقوق المثليين في بليز",
    "LGBT rights in Bermuda": "حقوق المثليين في برمودا",
    "LGBT rights in Bolivia": "حقوق المثليين في بوليفيا",
    "LGBT rights in Bonaire": "حقوق المثليين في بونير",
    "LGBT rights in Bosnia and Herzegovina by region": "حقوق المثليين في البوسنة والهرسك حسب المنطقة",
    "LGBT rights in Brazil": "حقوق المثليين في البرازيل",
    "LGBT rights in British Overseas Territories": "حقوق المثليين في أقاليم ما وراء البحار البريطانية",
    "LGBT rights in Bulgaria": "حقوق المثليين في بلغاريا",
    "LGBT rights in Cambodia": "حقوق المثليين في كمبوديا",
    "LGBT rights in Cameroon": "حقوق المثليين في الكاميرون",
    "LGBT rights in Canada": "حقوق المثليين في كندا",
    "LGBT rights in Central America": "حقوق المثليين في أمريكا الوسطى",
    "LGBT rights in Chile": "حقوق المثليين في تشيلي",
    "LGBT rights in China": "حقوق المثليين في الصين",
    "LGBT rights in Colombia": "حقوق المثليين في كولومبيا",
    "LGBT rights in Costa Rica": "حقوق المثليين في كوستاريكا",
    "LGBT rights in Croatia": "حقوق المثليين في كرواتيا",
    "LGBT rights in Cuba": "حقوق المثليين في كوبا",
    "LGBT rights in Curaçao": "حقوق المثليين في كوراساو",
    "LGBT rights in Cyprus": "حقوق المثليين في قبرص",
    "LGBT rights in Denmark": "حقوق المثليين في الدنمارك",
    "LGBT rights in Ecuador": "حقوق المثليين في الإكوادور",
    "LGBT rights in Egypt": "حقوق المثليين في مصر",
    "LGBT rights in El Salvador": "حقوق المثليين في السلفادور",
    "LGBT rights in England": "حقوق المثليين في إنجلترا",
    "LGBT rights in Estonia": "حقوق المثليين في إستونيا",
    "LGBT rights in Eswatini": "حقوق المثليين في إسواتيني",
    "LGBT rights in Europe": "حقوق المثليين في أوروبا",
    "LGBT rights in Europe by country": "حقوق المثليين في أوروبا حسب البلد",
    "LGBT rights in Fiji by region": "حقوق المثليين في فيجي حسب المنطقة",
    "LGBT rights in Finland": "حقوق المثليين في فنلندا",
    "LGBT rights in France": "حقوق المثليين في فرنسا",
    "LGBT rights in France by region": "حقوق المثليين في فرنسا حسب المنطقة",
    "LGBT rights in Germany": "حقوق المثليين في ألمانيا",
    "LGBT rights in Gibraltar": "حقوق المثليين في جبل طارق",
    "LGBT rights in Greece": "حقوق المثليين في اليونان",
    "LGBT rights in Greenland": "حقوق المثليين في جرينلاند",
    "LGBT rights in Guatemala": "حقوق المثليين في غواتيمالا",
    "LGBT rights in Guernsey": "حقوق المثليين في غيرنزي",
    "LGBT rights in Guyana": "حقوق المثليين في غيانا",
    "LGBT rights in Hawaii": "حقوق المثليين في هاواي",
    "LGBT rights in Honduras": "حقوق المثليين في هندوراس",
    "LGBT rights in Hong Kong": "حقوق المثليين في هونغ كونغ",
    "LGBT rights in Hungary": "حقوق المثليين في المجر",
    "LGBT rights in Iceland": "حقوق المثليين في آيسلندا",
    "LGBT rights in India": "حقوق المثليين في الهند",
    "LGBT rights in India by state": "حقوق المثليين في الهند حسب الولاية",
    "LGBT rights in Indiana": "حقوق المثليين في إنديانا",
    "LGBT rights in Indonesia": "حقوق المثليين في إندونيسيا",
    "LGBT rights in Indonesia by province": "حقوق المثليين في إندونيسيا حسب المقاطعة",
    "LGBT rights in Iran": "حقوق المثليين في إيران",
    "LGBT rights in Iraq": "حقوق المثليين في العراق",
    "LGBT rights in Iraq by region": "حقوق المثليين في العراق حسب المنطقة",
    "LGBT rights in Israel": "حقوق المثليين في إسرائيل",
    "LGBT rights in Italy": "حقوق المثليين في إيطاليا",
    "LGBT rights in Ivory Coast": "حقوق المثليين في ساحل العاج",
    "LGBT rights in Jamaica": "حقوق المثليين في جامايكا",
    "LGBT rights in Japan": "حقوق المثليين في اليابان",
    "LGBT rights in Jersey": "حقوق المثليين في جيرزي",
    "LGBT rights in Kurdistan": "حقوق المثليين في كردستان",
    "LGBT rights in Kyrgyzstan": "حقوق المثليين في قيرغيزستان",
    "LGBT rights in Latvia": "حقوق المثليين في لاتفيا",
    "LGBT rights in Lebanon": "حقوق المثليين في لبنان",
    "LGBT rights in Liechtenstein": "حقوق المثليين في ليختنشتاين",
    "LGBT rights in Lithuania": "حقوق المثليين في ليتوانيا",
    "LGBT rights in Luxembourg": "حقوق المثليين في لوكسمبورغ",
    "LGBT rights in Maine": "حقوق المثليين في مين",
    "LGBT rights in Malaysia": "حقوق المثليين في ماليزيا",
    "LGBT rights in Malta": "حقوق المثليين في مالطا",
    "LGBT rights in Massachusetts": "حقوق المثليين في ماساتشوستس",
    "LGBT rights in Mexico": "حقوق المثليين في المكسيك",
    "LGBT rights in Moldova": "حقوق المثليين في مولدوفا",
    "LGBT rights in Monaco": "حقوق المثليين في موناكو",
    "LGBT rights in Montenegro": "حقوق المثليين في الجبل الأسود",
    "LGBT rights in Morocco": "حقوق المثليين في المغرب",
    "LGBT rights in Myanmar": "حقوق المثليين في ميانمار",
    "LGBT rights in Nepal": "حقوق المثليين في نيبال",
    "LGBT rights in New Zealand": "حقوق المثليين في نيوزيلندا",
    "LGBT rights in Nicaragua": "حقوق المثليين في نيكاراغوا",
    "LGBT rights in Nigeria": "حقوق المثليين في نيجيريا",
    "LGBT rights in Niue": "حقوق المثليين في نييوي",
    "LGBT rights in North America": "حقوق المثليين في أمريكا الشمالية",
    "LGBT rights in North America by country": "حقوق المثليين في أمريكا الشمالية حسب البلد",
    "LGBT rights in North Macedonia": "حقوق المثليين في مقدونيا الشمالية",
    "LGBT rights in Northern Ireland": "حقوق المثليين في أيرلندا الشمالية",
    "LGBT rights in Norway": "حقوق المثليين في النرويج",
    "LGBT rights in Norway by region": "حقوق المثليين في النرويج حسب المنطقة",
    "LGBT rights in Oceania": "حقوق المثليين في أوقيانوسيا",
    "LGBT rights in Oceania by country": "حقوق المثليين في أوقيانوسيا حسب البلد",
    "LGBT rights in Pakistan": "حقوق المثليين في باكستان",
    "LGBT rights in Panama": "حقوق المثليين في بنما",
    "LGBT rights in Papua New Guinea": "حقوق المثليين في بابوا غينيا الجديدة",
    "LGBT rights in Paraguay": "حقوق المثليين في باراغواي",
    "LGBT rights in Peru": "حقوق المثليين في بيرو",
    "LGBT rights in Poland": "حقوق المثليين في بولندا",
    "LGBT rights in Portugal": "حقوق المثليين في البرتغال",
    "LGBT rights in Portugal by region": "حقوق المثليين في البرتغال حسب المنطقة",
    "LGBT rights in Puerto Rico": "حقوق المثليين في بورتوريكو",
    "LGBT rights in Romania": "حقوق المثليين في رومانيا",
    "LGBT rights in Russia": "حقوق المثليين في روسيا",
    "LGBT rights in Russia by region": "حقوق المثليين في روسيا حسب المنطقة",
    "LGBT rights in Saba": "حقوق المثليين في سابا",
    "LGBT rights in Saint Helena, Ascension and Tristan da Cunha": "حقوق المثليين في سانت هيلينا وأسينشين وتريستان دا كونا",
    "LGBT rights in Saint Lucia": "حقوق المثليين في سانت لوسيا",
    "LGBT rights in San Marino": "حقوق المثليين في سان مارينو",
    "LGBT rights in Scotland": "حقوق المثليين في إسكتلندا",
    "LGBT rights in Serbia": "حقوق المثليين في صربيا",
    "LGBT rights in Serbia by region": "حقوق المثليين في صربيا حسب المنطقة",
    "LGBT rights in Sierra Leone": "حقوق المثليين في سيراليون",
    "LGBT rights in Singapore": "حقوق المثليين في سنغافورة",
    "LGBT rights in Sint Eustatius": "حقوق المثليين في سينت أوستاتيوس",
    "LGBT rights in Sint Maarten": "حقوق المثليين في سينت مارتن",
    "LGBT rights in Slovakia": "حقوق المثليين في سلوفاكيا",
    "LGBT rights in Slovenia": "حقوق المثليين في سلوفينيا",
    "LGBT rights in South America": "حقوق المثليين في أمريكا الجنوبية",
    "LGBT rights in South America by country": "حقوق المثليين في أمريكا الجنوبية حسب البلد",
    "LGBT rights in South Korea": "حقوق المثليين في كوريا الجنوبية",
    "LGBT rights in Spain": "حقوق المثليين في إسبانيا",
    "LGBT rights in Sri Lanka": "حقوق المثليين في سريلانكا",
    "LGBT rights in Suriname": "حقوق المثليين في سورينام",
    "LGBT rights in Sweden": "حقوق المثليين في السويد",
    "LGBT rights in Switzerland": "حقوق المثليين في سويسرا",
    "LGBT rights in Syria": "حقوق المثليين في سوريا",
    "LGBT rights in Taiwan": "حقوق المثليين في تايوان",
    "LGBT rights in Thailand": "حقوق المثليين في تايلاند",
    "LGBT rights in Tonga": "حقوق المثليين في تونغا",
    "LGBT rights in Transnistria": "حقوق المثليين في ترانسنيستريا",
    "LGBT rights in Trinidad and Tobago": "حقوق المثليين في ترينيداد وتوباغو",
    "LGBT rights in Turkey": "حقوق المثليين في تركيا",
    "LGBT rights in Uganda": "حقوق المثليين في أوغندا",
    "LGBT rights in Ukraine": "حقوق المثليين في أوكرانيا",
    "LGBT rights in Uruguay": "حقوق المثليين في أوروغواي",
    "LGBT rights in Uzbekistan": "حقوق المثليين في أوزبكستان",
    "LGBT rights in Venezuela": "حقوق المثليين في فنزويلا",
    "LGBT rights in Vietnam": "حقوق المثليين في فيتنام",
    "LGBT rights in Wales": "حقوق المثليين في ويلز",
    "LGBT rights in insular areas of the United States": "حقوق المثليين في المناطق المعزولة في الولايات المتحدة",
    "LGBT rights in the Americas": "حقوق المثليين في الأمريكتين",
    "LGBT rights in the Bahamas": "حقوق المثليين في باهاماس",
    "LGBT rights in the Caribbean": "حقوق المثليين في الكاريبي",
    "LGBT rights in the Cayman Islands": "حقوق المثليين في جزر كايمان",
    "LGBT rights in the Comoros": "حقوق المثليين في جزر القمر",
    "LGBT rights in the Cook Islands": "حقوق المثليين في جزر كوك",
    "LGBT rights in the Crown Dependencies": "حقوق المثليين في تبعيات التاج البريطاني",
    "LGBT rights in the Czech Republic": "حقوق المثليين في جمهورية التشيك",
    "LGBT rights in the Falkland Islands": "حقوق المثليين في جزر فوكلاند",
    "LGBT rights in the Faroe Islands": "حقوق المثليين في جزر فارو",
    "LGBT rights in the Isle of Man": "حقوق المثليين في جزيرة مان",
    "LGBT rights in the Netherlands": "حقوق المثليين في هولندا",
    "LGBT rights in the Nordic countries": "حقوق المثليين في بلدان نوردية",
    "LGBT rights in the People's Republic of China": "حقوق المثليين في جمهورية الصين الشعبية",
    "LGBT rights in the Philippines": "حقوق المثليين في الفلبين",
    "LGBT rights in republic of Ireland": "حقوق المثليين في جمهورية أيرلندا",
    "LGBT rights in republic of congo": "حقوق المثليين في جمهورية الكونغو",
    "LGBT rights in the Solomon Islands": "حقوق المثليين في جزر سليمان",
    "LGBT rights in the Soviet Union": "حقوق المثليين في الاتحاد السوفيتي",
    "LGBT rights in the United Arab Emirates": "حقوق المثليين في الإمارات العربية المتحدة",
    "LGBT rights in the United Kingdom": "حقوق المثليين في المملكة المتحدة",
    "LGBT rights in the United Kingdom by country": "حقوق المثليين في المملكة المتحدة حسب البلد",
    "LGBT rights in the United States": "حقوق المثليين في الولايات المتحدة",
    "LGBT rights in the United States Virgin Islands": "حقوق المثليين في جزر العذراء الأمريكية",
    "LGBT rights in the United States by region": "حقوق المثليين في الولايات المتحدة حسب المنطقة",
    "LGBT rights in the United States by state": "حقوق المثليين في الولايات المتحدة حسب الولاية",
    "LGBT rights movement": "حركة حقوق المثليين",
    "LGBT rights organizations": "منظمات حقوق المثليين",
    "LGBT rights table templates": "قوالب جدول حقوق المثليين",
    "LGBT rights templates": "قوالب حقوق المثليين",
    "LGBT terminology": "مصطلحات المثليين",
    "LGBT theatre": "مسرح المثليين",
    "LGBT timelines": "التسلسلات الزمنية للمثليين",
    "LGBT tourism": "سياحة المثليين",
    "LGBTQ beauty pageants": "مسابقات الجمال للمثليين",
    "LGBTQ culture": "ثقافة المثليين",
    "LGBTQ culture by city": "ثقافة المثليين حسب المدينة",
    "LGBTQ culture by continent": "ثقافة المثليين حسب القارة",
    "LGBTQ culture by country": "ثقافة المثليين حسب البلد",
    "LGBTQ culture by location": "ثقافة المثليين حسب الموقع",
    "LGBTQ culture in Asia": "ثقافة المثليين في آسيا",
    "LGBTQ culture in Australia": "ثقافة المثليين في أستراليا",
    "LGBTQ culture in Australia by city": "ثقافة المثليين في أستراليا حسب المدينة",
    "LGBTQ culture in Brazil": "ثقافة المثليين في البرازيل",
    "LGBTQ culture in Canada": "ثقافة المثليين في كندا",
    "LGBTQ culture in Denmark": "ثقافة المثليين في الدنمارك",
    "LGBTQ culture in England": "ثقافة المثليين في إنجلترا",
    "LGBTQ culture in Europe": "ثقافة المثليين في أوروبا",
    "LGBTQ culture in France": "ثقافة المثليين في فرنسا",
    "LGBTQ culture in Germany": "ثقافة المثليين في ألمانيا",
    "LGBTQ culture in Greenland": "ثقافة المثليين في جرينلاند",
    "LGBTQ culture in India": "ثقافة المثليين في الهند",
    "LGBTQ culture in Ireland": "ثقافة المثليين في أيرلندا",
    "LGBTQ culture in Italy": "ثقافة المثليين في إيطاليا",
    "LGBTQ culture in Japan": "ثقافة المثليين في اليابان",
    "LGBTQ culture in Liverpool": "ثقافة المثليين في ليفربول",
    "LGBTQ culture in London": "ثقافة المثليين في لندن",
    "LGBTQ culture in Mexico": "ثقافة المثليين في المكسيك",
    "LGBTQ culture in North America": "ثقافة المثليين في أمريكا الشمالية",
    "LGBTQ culture in Norway": "ثقافة المثليين في النرويج",
    "LGBTQ culture in Scotland": "ثقافة المثليين في إسكتلندا",
    "LGBTQ culture in South America": "ثقافة المثليين في أمريكا الجنوبية",
    "LGBTQ culture in Spain": "ثقافة المثليين في إسبانيا",
    "LGBTQ culture in Sydney": "ثقافة المثليين في سيدني",
    "LGBTQ culture in the Netherlands": "ثقافة المثليين في هولندا",
    "LGBTQ culture in the United Kingdom": "ثقافة المثليين في المملكة المتحدة",
    "LGBTQ culture in the United Kingdom by city": "ثقافة المثليين في المملكة المتحدة حسب المدينة",
    "LGBTQ drinking establishments": "مؤسسات الشرب للمثليين",
    "LGBTQ events": "أحداث المثليين",
    "LGBTQ events by country": "أحداث متعلقة بالمثليين حسب البلد",
    "LGBTQ events in Brazil": "أحداث المثليين في البرازيل",
    "LGBTQ events in Denmark": "أحداث متعلقة بالمثليين في الدنمارك",
    "LGBTQ events in Ireland": "أحداث متعلقة بالمثليين في أيرلندا",
    "LGBTQ festivals": "مهرجانات المثليين",
    "LGBTQ film festivals": "مهرجانات أفلام المثليين",
    "LGBTQ health organizations": "منظمات الصحة المعنية بالمثليين",
    "LGBTQ health organizations in the United States": "منظمات الصحة المعنية بالمثليين في الولايات المتحدة",
    "LGBTQ history by country": "تاريخ المثليين حسب البلد",
    "LGBTQ history in Denmark": "تاريخ المثليين في الدنمارك",
    "LGBTQ history in Germany": "تاريخ المثليين في ألمانيا",
    "LGBTQ history in Ireland": "تاريخ المثليين في أيرلندا",
    "LGBTQ history in Italy": "تاريخ المثليين في إيطاليا",
    "LGBTQ history in Peru": "تاريخ المثليين في بيرو",
    "LGBTQ history in the United Kingdom": "تاريخ المثليين في المملكة المتحدة",
    "LGBTQ in the Arab world": "معاملة المثليين في الوطن العربي",
    "LGBTQ in the Middle East": "معاملة المثليين في الشرق الأوسط",
    "LGBTQ monuments and memorials": "معالم أثرية ونصب تذكارية متعلقة بمثليين",
    "LGBTQ monuments and memorials in the United States": "معالم ونصب تذكارية لمثليين في الولايات المتحدة",
    "LGBTQ nightclubs": "نوادي ليلية للمثليين",
    "LGBTQ organizations based in Iceland": "منظمات المثليين في آيسلندا",
    "LGBTQ parenting": "الأبوة والأمومة عند المثليين",
    "LGBTQ parenting in North America": "الأبوة والأمومة عند المثليين في أمريكا الشمالية",
    "LGBTQ parenting in the United States": "الأبوة والأمومة عند المثليين في الولايات المتحدة",
    "LGBTQ poetry": "شعر المثليين",
    "LGBTQ political advocacy groups by country": "جمعيات تأييد سياسي للمثليين حسب البلد",
    "LGBTQ political advocacy groups in Brazil": "جمعيات تأييد سياسي للمثليين في البرازيل",
    "LGBTQ political advocacy groups in Denmark": "جمعيات تأييد سياسي للمثليين في الدنمارك",
    "LGBTQ political advocacy groups in Iceland": "جمعيات تأييد سياسي للمثليين في آيسلندا",
    "LGBTQ political advocacy groups in Morocco": "جمعيات تأييد سياسي للمثليين في المغرب",
    "LGBTQ political advocacy groups in Russia": "جمعيات تأييد سياسي للمثليين في روسيا",
    "LGBTQ political advocacy groups in the Netherlands": "جمعيات تأييد سياسي للمثليين في هولندا",
    "LGBTQ political advocacy groups in republic of Ireland": "جمعيات تأييد سياسي للمثليين في جمهورية أيرلندا",
    "LGBTQ politics": "سياسة المثليين جنسيا",
    "LGBTQ rights": "معاملة المثليين جنسيا",
    "LGBTQ rights by continent": "معاملة المثليين حسب القارة",
    "LGBTQ rights by country": "معاملة المثليين حسب البلد",
    "LGBTQ rights by country subdivision": "معاملة المثليين حسب المستوى دون الوطني للبلد",
    "LGBTQ rights by former country": "معاملة المثليين حسب البلد السابق",
    "LGBTQ rights by issue": "معاملة المثليين حسب القضية",
    "LGBTQ rights by location": "معاملة المثليين حسب المنطقة",
    "LGBTQ rights case law": "قضايا محاكم حول معاملة المثليين",
    "LGBTQ rights in Africa": "معاملة المثليين في إفريقيا",
    "LGBTQ rights in Akrotiri and Dhekelia": "معاملة المثليين في أكروتيري ودكليا",
    "LGBTQ rights in Albania": "معاملة المثليين في ألبانيا",
    "LGBTQ rights in Andorra": "معاملة المثليين في أندورا",
    "LGBTQ rights in Argentina": "معاملة المثليين في الأرجنتين",
    "LGBTQ rights in Armenia": "معاملة المثليين في أرمينيا",
    "LGBTQ rights in Aruba": "معاملة المثليين في أروبا",
    "LGBTQ rights in Asia": "معاملة المثليين في آسيا",
    "LGBTQ rights in Australia": "معاملة المثليين في أستراليا",
    "LGBTQ rights in Australia by state or territory": "معاملة المثليين في أستراليا حسب الولاية أو الإقليم",
    "LGBTQ rights in Austria": "معاملة المثليين في النمسا",
    "LGBTQ rights in Azerbaijan": "معاملة المثليين في أذربيجان",
    "LGBTQ rights in Barbados": "معاملة المثليين في بربادوس",
    "LGBTQ rights in Belarus": "معاملة المثليين في روسيا البيضاء",
    "LGBTQ rights in Belgium": "معاملة المثليين في بلجيكا",
    "LGBTQ rights in Belize": "معاملة المثليين في بليز",
    "LGBTQ rights in Bermuda": "معاملة المثليين في برمودا",
    "LGBTQ rights in Bolivia": "معاملة المثليين في بوليفيا",
    "LGBTQ rights in Bonaire": "معاملة المثليين في بونير",
    "LGBTQ rights in Bosnia and Herzegovina by region": "معاملة المثليين في البوسنة والهرسك حسب المنطقة",
    "LGBTQ rights in Brazil": "معاملة المثليين في البرازيل",
    "LGBTQ rights in Bulgaria": "معاملة المثليين في بلغاريا",
    "LGBTQ rights in Cambodia": "معاملة المثليين في كمبوديا",
    "LGBTQ rights in Cameroon": "معاملة المثليين في الكاميرون",
    "LGBTQ rights in Canada": "معاملة المثليين في كندا",
    "LGBTQ rights in Central America": "معاملة المثليين في أمريكا الوسطى",
    "LGBTQ rights in Chile": "معاملة المثليين في تشيلي",
    "LGBTQ rights in China": "معاملة المثليين في الصين",
    "LGBTQ rights in Colombia": "معاملة المثليين في كولومبيا",
    "LGBTQ rights in Costa Rica": "معاملة المثليين في كوستاريكا",
    "LGBTQ rights in Croatia": "معاملة المثليين في كرواتيا",
    "LGBTQ rights in Cuba": "معاملة المثليين في كوبا",
    "LGBTQ rights in Curaçao": "معاملة المثليين في كوراساو",
    "LGBTQ rights in Cyprus": "معاملة المثليين في قبرص",
    "LGBTQ rights in Denmark": "معاملة المثليين في الدنمارك",
    "LGBTQ rights in Ecuador": "معاملة المثليين في الإكوادور",
    "LGBTQ rights in Egypt": "معاملة المثليين في مصر",
    "LGBTQ rights in El Salvador": "معاملة المثليين في السلفادور",
    "LGBTQ rights in England": "معاملة المثليين في إنجلترا",
    "LGBTQ rights in Estonia": "معاملة المثليين في إستونيا",
    "LGBTQ rights in Eswatini": "معاملة المثليين في إسواتيني",
    "LGBTQ rights in Ethiopia": "معاملة المثليين في إثيوبيا",
    "LGBTQ rights in Europe": "معاملة المثليين في أوروبا",
    "LGBTQ rights in Finland": "معاملة المثليين في فنلندا",
    "LGBTQ rights in France": "معاملة المثليين في فرنسا",
    "LGBTQ rights in France by region": "معاملة المثليين في فرنسا حسب المنطقة",
    "LGBTQ rights in Germany": "معاملة المثليين في ألمانيا",
    "LGBTQ rights in Gibraltar": "معاملة المثليين في جبل طارق",
    "LGBTQ rights in Greece": "معاملة المثليين في اليونان",
    "LGBTQ rights in Greenland": "معاملة المثليين في جرينلاند",
    "LGBTQ rights in Guatemala": "معاملة المثليين في غواتيمالا",
    "LGBTQ rights in Guernsey": "معاملة المثليين في غيرنزي",
    "LGBTQ rights in Guyana": "معاملة المثليين في غيانا",
    "LGBTQ rights in Hawaii": "معاملة المثليين في هاواي",
    "LGBTQ rights in Honduras": "معاملة المثليين في هندوراس",
    "LGBTQ rights in Hong Kong": "معاملة المثليين في هونغ كونغ",
    "LGBTQ rights in Hungary": "معاملة المثليين في المجر",
    "LGBTQ rights in Iceland": "معاملة المثليين في آيسلندا",
    "LGBTQ rights in India": "معاملة المثليين في الهند",
    "LGBTQ rights in India by state": "معاملة المثليين في الهند حسب الولاية",
    "LGBTQ rights in Indiana": "معاملة المثليين في إنديانا",
    "LGBTQ rights in Indonesia": "معاملة المثليين في إندونيسيا",
    "LGBTQ rights in Indonesia by province": "معاملة المثليين في إندونيسيا حسب المقاطعة",
    "LGBTQ rights in Iran": "معاملة المثليين في إيران",
    "LGBTQ rights in Iraq": "معاملة المثليين في العراق",
    "LGBTQ rights in Iraq by region": "معاملة المثليين في العراق حسب المنطقة",
    "LGBTQ rights in Israel": "معاملة المثليين في إسرائيل",
    "LGBTQ rights in Italy": "معاملة المثليين في إيطاليا",
    "LGBTQ rights in Ivory Coast": "معاملة المثليين في ساحل العاج",
    "LGBTQ rights in Jamaica": "معاملة المثليين في جامايكا",
    "LGBTQ rights in Japan": "معاملة المثليين في اليابان",
    "LGBTQ rights in Jersey": "معاملة المثليين في جيرزي",
    "LGBTQ rights in Kyrgyzstan": "معاملة المثليين في قيرغيزستان",
    "LGBTQ rights in Latin America": "معاملة المثليين في أمريكا اللاتينية",
    "LGBTQ rights in Latvia": "معاملة المثليين في لاتفيا",
    "LGBTQ rights in Lebanon": "معاملة المثليين في لبنان",
    "LGBTQ rights in Liechtenstein": "معاملة المثليين في ليختنشتاين",
    "LGBTQ rights in Lithuania": "معاملة المثليين في ليتوانيا",
    "LGBTQ rights in Luxembourg": "معاملة المثليين في لوكسمبورغ",
    "LGBTQ rights in Maine": "معاملة المثليين في مين",
    "LGBTQ rights in Malaysia": "معاملة المثليين في ماليزيا",
    "LGBTQ rights in Malta": "معاملة المثليين في مالطا",
    "LGBTQ rights in Massachusetts": "معاملة المثليين في ماساتشوستس",
    "LGBTQ rights in Mexico": "معاملة المثليين في المكسيك",
    "LGBTQ rights in Moldova": "معاملة المثليين في مولدوفا",
    "LGBTQ rights in Monaco": "معاملة المثليين في موناكو",
    "LGBTQ rights in Montenegro": "معاملة المثليين في الجبل الأسود",
    "LGBTQ rights in Morocco": "معاملة المثليين في المغرب",
    "LGBTQ rights in Myanmar": "معاملة المثليين في ميانمار",
    "LGBTQ rights in Nepal": "معاملة المثليين في نيبال",
    "LGBTQ rights in New Zealand": "معاملة المثليين في نيوزيلندا",
    "LGBTQ rights in Nicaragua": "معاملة المثليين في نيكاراغوا",
    "LGBTQ rights in Nigeria": "معاملة المثليين في نيجيريا",
    "LGBTQ rights in Niue": "معاملة المثليين في نييوي",
    "LGBTQ rights in North America": "معاملة المثليين في أمريكا الشمالية",
    "LGBTQ rights in North Macedonia": "معاملة المثليين في مقدونيا الشمالية",
    "LGBTQ rights in Northern Ireland": "معاملة المثليين في أيرلندا الشمالية",
    "LGBTQ rights in Norway": "معاملة المثليين في النرويج",
    "LGBTQ rights in Norway by region": "معاملة المثليين في النرويج حسب المنطقة",
    "LGBTQ rights in Oceania": "معاملة المثليين في أوقيانوسيا",
    "LGBTQ rights in Pakistan": "معاملة المثليين في باكستان",
    "LGBTQ rights in Panama": "معاملة المثليين في بنما",
    "LGBTQ rights in Papua New Guinea": "معاملة المثليين في بابوا غينيا الجديدة",
    "LGBTQ rights in Paraguay": "معاملة المثليين في باراغواي",
    "LGBTQ rights in Peru": "معاملة المثليين في بيرو",
    "LGBTQ rights in Poland": "معاملة المثليين في بولندا",
    "LGBTQ rights in Portugal": "معاملة المثليين في البرتغال",
    "LGBTQ rights in Puerto Rico": "معاملة المثليين في بورتوريكو",
    "LGBTQ rights in Romania": "معاملة المثليين في رومانيا",
    "LGBTQ rights in Russia": "معاملة المثليين في روسيا",
    "LGBTQ rights in Russia by region": "معاملة المثليين في روسيا حسب المنطقة",
    "LGBTQ rights in Saba": "معاملة المثليين في سابا",
    "LGBTQ rights in Saint Helena, Ascension and Tristan da Cunha": "معاملة المثليين في سانت هيلينا وأسينشين وتريستان دا كونا",
    "LGBTQ rights in Saint Lucia": "معاملة المثليين في سانت لوسيا",
    "LGBTQ rights in San Marino": "معاملة المثليين في سان مارينو",
    "LGBTQ rights in Scotland": "معاملة المثليين في إسكتلندا",
    "LGBTQ rights in Serbia": "معاملة المثليين في صربيا",
    "LGBTQ rights in Sierra Leone": "معاملة المثليين في سيراليون",
    "LGBTQ rights in Singapore": "معاملة المثليين في سنغافورة",
    "LGBTQ rights in Sint Eustatius": "معاملة المثليين في سينت أوستاتيوس",
    "LGBTQ rights in Sint Maarten": "معاملة المثليين في سينت مارتن",
    "LGBTQ rights in Slovakia": "معاملة المثليين في سلوفاكيا",
    "LGBTQ rights in Slovenia": "معاملة المثليين في سلوفينيا",
    "LGBTQ rights in South America": "معاملة المثليين في أمريكا الجنوبية",
    "LGBTQ rights in South Korea": "معاملة المثليين في كوريا الجنوبية",
    "LGBTQ rights in Spain": "معاملة المثليين في إسبانيا",
    "LGBTQ rights in Sri Lanka": "معاملة المثليين في سريلانكا",
    "LGBTQ rights in Suriname": "معاملة المثليين في سورينام",
    "LGBTQ rights in Sweden": "معاملة المثليين في السويد",
    "LGBTQ rights in Switzerland": "معاملة المثليين في سويسرا",
    "LGBTQ rights in Syria": "معاملة المثليين في سوريا",
    "LGBTQ rights in Taiwan": "معاملة المثليين في تايوان",
    "LGBTQ rights in Thailand": "معاملة المثليين في تايلاند",
    "LGBTQ rights in Tonga": "معاملة المثليين في تونغا",
    "LGBTQ rights in Transnistria": "معاملة المثليين في ترانسنيستريا",
    "LGBTQ rights in Trinidad and Tobago": "معاملة المثليين في ترينيداد وتوباغو",
    "LGBTQ rights in Turkey": "معاملة المثليين في تركيا",
    "LGBTQ rights in Uganda": "معاملة المثليين في أوغندا",
    "LGBTQ rights in Ukraine": "معاملة المثليين في أوكرانيا",
    "LGBTQ rights in Uruguay": "معاملة المثليين في أوروغواي",
    "LGBTQ rights in Uzbekistan": "معاملة المثليين في أوزبكستان",
    "LGBTQ rights in Venezuela": "معاملة المثليين في فنزويلا",
    "LGBTQ rights in Vietnam": "معاملة المثليين في فيتنام",
    "LGBTQ rights in Wales": "معاملة المثليين في ويلز",
    "LGBTQ rights in dependent territories of the United Kingdom": "معاملة المثليين في تبعيات التاج البريطاني",
    "LGBTQ rights in insular areas of the United States": "معاملة المثليين في المناطق المعزولة في الولايات المتحدة",
    "LGBTQ rights in the Americas": "معاملة المثليين في الأمريكتين",
    "LGBTQ rights in the Arab world": "حقوق المثليين في الوطن العربي",
    "LGBTQ rights in the Bahamas": "معاملة المثليين في باهاماس",
    "LGBTQ rights in the Caribbean": "معاملة المثليين في الكاريبي",
    "LGBTQ rights in the Cayman Islands": "معاملة المثليين في جزر كايمان",
    "LGBTQ rights in the Comoros": "معاملة المثليين في جزر القمر",
    "LGBTQ rights in the Cook Islands": "معاملة المثليين في جزر كوك",
    "LGBTQ rights in the Czech Republic": "معاملة المثليين في جمهورية التشيك",
    "LGBTQ rights in the Falkland Islands": "معاملة المثليين في جزر فوكلاند",
    "LGBTQ rights in the Faroe Islands": "معاملة المثليين في جزر فارو",
    "LGBTQ rights in the Isle of Man": "معاملة المثليين في جزيرة مان",
    "LGBTQ rights in the Middle East": "حقوق المثليين في الشرق الأوسط",
    "LGBTQ rights in the Netherlands": "معاملة المثليين في هولندا",
    "LGBTQ rights in the Philippines": "معاملة المثليين في الفلبين",
    "LGBTQ rights in republic of Ireland": "معاملة المثليين في جمهورية أيرلندا",
    "LGBTQ rights in republic of congo": "معاملة المثليين في جمهورية الكونغو",
    "LGBTQ rights in the Solomon Islands": "معاملة المثليين في جزر سليمان",
    "LGBTQ rights in the United Arab Emirates": "معاملة المثليين في الإمارات العربية المتحدة",
    "LGBTQ rights in the United Kingdom": "معاملة المثليين في المملكة المتحدة",
    "LGBTQ rights in the United Kingdom by country": "معاملة المثليين في المملكة المتحدة حسب البلد",
    "LGBTQ rights in the United States": "معاملة المثليين في الولايات المتحدة",
    "LGBTQ rights in the United States Virgin Islands": "معاملة المثليين في جزر العذراء الأمريكية",
    "LGBTQ rights in the United States by location": "معاملة المثليين في الولايات المتحدة حسب المنطقة",
    "LGBTQ rights in the United States by state": "معاملة المثليين في الولايات المتحدة حسب الولاية",
    "LGBTQ rights movement": "حركات داعمة للمثليين",
    "LGBTQ rights organizations": "منظمات داعمة للمثليين",
    "LGBTQ rights table templates": "قوالب جدول معاملة المثليين",
    "LGBTQ rights templates": "قوالب معاملة المثليين",
    "LGBTQ terminology": "مصطلحات المثليين",
    "LGBTQ theatre": "مسرح المثليين",
    "LGBTQ timelines": "التسلسلات الزمنية للمثليين",
    "LGBTQ tourism": "سياحة المثليين",
    "Labour Friends of Israel": "أصدقاء إسرائيل العماليين",
    "Landforms of Camiguin": "تضاريس كاميغويين",
    "Landforms of Haute-Vienne": "تضاريس فيين العليا (إقليم فرنسي)",
    "Landforms of Vienne": "تضاريس فيين (إقليم فرنسي)",
    "Landforms of Vienne (department)": "تضاريس فيين (إقليم فرنسي)",
    "Languages of Camiguin": "لغات كاميغويين",
    "Latin music albums by American artists": "ألبومات موسيقى لاتينية لفنانين أمريكيين",
    "Latino sitcoms": "لاتينيين كوميديا الموقف",
    "Law enforcement operations against Islamist groups": "غارات الشرطة على الإسلاميين",
    "Leaders of Progressive Democrats": "قادة حزب الديمقراطيين التقدميين",
    "Levitical cities": "مدن اللاويين",
    "Liberal Democrats (UK) MPs": "أعضاء برلمان الديمقراطيين الليبراليين (المملكة المتحدة)",
    "Libya men's A' international footballers": "لاعبو منتخب ليبيا لكرة القدم للرجال للمحليين",
    "Life peers": "نبلاء عمريين",
    "Linguists by language group of study": "لغويين حسب مجموعة لغة الدراسة",
    "Lists of African politicians": "قوائم سياسيين أفارقة",
    "Lists of African-American people": "قوائم الأمريكيين الأفارقة",
    "Lists of Albanian politicians": "قوائم سياسيين ألبان",
    "Lists of Algerian people": "قوائم جزائريين",
    "Lists of Algerian people by occupation": "قوائم جزائريين حسب المهنة",
    "Lists of Algerian politicians": "قوائم سياسيين جزائريين",
    "Lists of Algerian sports-people": "قوائم رياضيين جزائريين",
    "Lists of American people": "قوائم أمريكيين",
    "Lists of American people by educational affiliation": "قوائم أمريكيين حسب الانتماء التعليمي",
    "Lists of American people by educational affiliation by state": "قوائم أمريكيين حسب الانتماء التعليمي حسب الولاية",
    "Lists of American people by ethnic or national origin": "قوائم أمريكيين حسب الأصل العرقي أو الوطني",
    "Lists of American people by ethnicity": "قوائم أمريكيين حسب الأصل العرقي أو الوطني",
    "Lists of American people by occupation": "قوائم أمريكيين حسب المهنة",
    "Lists of American politicians": "قوائم سياسيين أمريكيين",
    "Lists of American politicians by state": "قوائم سياسيين أمريكيين حسب الولاية",
    "Lists of Argentine people": "قوائم أرجنتينيين",
    "Lists of Argentine people by occupation": "قوائم أرجنتينيين حسب المهنة",
    "Lists of Argentine politicians": "قوائم سياسيين أرجنتينيين",
    "Lists of Armenian politicians": "قوائم سياسيين أرمن",
    "Lists of Asian people": "قوائم آسيويين",
    "Lists of Asian politicians": "قوائم سياسيين آسيويين",
    "Lists of Australian award winners": "قوائم حائزي جوائز أستراليين",
    "Lists of Australian people": "قوائم أستراليين",
    "Lists of Australian people by occupation": "قوائم أستراليين حسب المهنة",
    "Lists of Australian politicians": "قوائم سياسيين أستراليين",
    "Lists of Austrian people": "قوائم نمساويين",
    "Lists of Austrian people by occupation": "قوائم نمساويين حسب المهنة",
    "Lists of Austrian politicians": "قوائم سياسيين نمساويين",
    "Lists of Azerbaijani people": "قوائم أذربيجانيين",
    "Lists of Azerbaijani people by occupation": "قوائم أذربيجانيين حسب المهنة",
    "Lists of Azerbaijani politicians": "قوائم سياسيين أذربيجانيين",
    "Lists of Azerbaijani sports-people": "قوائم رياضيين أذربيجانيين",
    "Lists of Bahraini people by occupation": "قوائم بحرينيين حسب المهنة",
    "Lists of Bahraini sports-people": "قوائم رياضيين بحرينيين",
    "Lists of Bangladeshi people": "قوائم بنجلاديشيين",
    "Lists of Bangladeshi people by occupation": "قوائم بنجلاديشيين حسب المهنة",
    "Lists of Bangladeshi politicians": "قوائم سياسيين بنجلاديشيين",
    "Lists of Belgian people": "قوائم بلجيكيين",
    "Lists of Belgian people by occupation": "قوائم بلجيكيين حسب المهنة",
    "Lists of Belgian politicians": "قوائم سياسيين بلجيكيين",
    "Lists of Beninese people": "قوائم بنينيين",
    "Lists of Brazilian people": "قوائم برازيليين",
    "Lists of Brazilian people by occupation": "قوائم برازيليين حسب المهنة",
    "Lists of Brazilian politicians": "قوائم سياسيين برازيليين",
    "Lists of British award winners": "قوائم حائزي جوائز بريطانيين",
    "Lists of British people": "قوائم بريطانيين",
    "Lists of British people by occupation": "قوائم بريطانيين حسب المهنة",
    "Lists of British politicians": "قوائم سياسيين بريطانيين",
    "Lists of British sports-people": "قوائم رياضيين بريطانيين",
    "Lists of Bruneian people": "قوائم برونيين",
    "Lists of Bulgarian people": "قوائم بلغاريين",
    "Lists of Bulgarian people by occupation": "قوائم بلغاريين حسب المهنة",
    "Lists of Bulgarian politicians": "قوائم سياسيين بلغاريين",
    "Lists of Burkinabe people": "قوائم بوركينابيين",
    "Lists of Burkinabé people": "قوائم بوركينابيين",
    "Lists of Burundian people": "قوائم بورونديين",
    "Lists of Burundian people by occupation": "قوائم بورونديين حسب المهنة",
    "Lists of Cameroonian people": "قوائم كاميرونيين",
    "Lists of Cameroonian people by occupation": "قوائم كاميرونيين حسب المهنة",
    "Lists of Canadian people": "قوائم كنديين",
    "Lists of Canadian people by descent": "قوائم كنديين حسب الأصل العرقي أو الوطني",
    "Lists of Canadian people by ethnic or national origin": "قوائم كنديين حسب الأصل العرقي أو الوطني",
    "Lists of Canadian people by occupation": "قوائم كنديين حسب المهنة",
    "Lists of Canadian politicians": "قوائم سياسيين كنديين",
    "Lists of Cape Verdean people": "قوائم أخضريين",
    "Lists of Central American people": "قوائم أمريكيين أوسطيين",
    "Lists of Central American politicians": "قوائم سياسيين أمريكيين أوسطيين",
    "Lists of Chilean people": "قوائم تشيليين",
    "Lists of Chinese people": "قوائم صينيين",
    "Lists of Chinese people by occupation": "قوائم صينيين حسب المهنة",
    "Lists of Chinese politicians": "قوائم سياسيين صينيين",
    "Lists of Christians": "قوائم مسيحيين",
    "Lists of Colombian people": "قوائم كولومبيين",
    "Lists of Colombian people by occupation": "قوائم كولومبيين حسب المهنة",
    "Lists of Colombian politicians": "قوائم السياسيين الكولومبيين",
    "Lists of Costa Rican people": "قوائم كوستاريكيين",
    "Lists of Costa Rican politicians": "قوائم سياسيين كوستاريكيين",
    "Lists of Croatian people": "قوائم كرواتيين",
    "Lists of Croatian people by occupation": "قوائم كرواتيين حسب المهنة",
    "Lists of Croatian politicians": "قوائم سياسيين كرواتيين",
    "Lists of Croatian sports-people": "قوائم رياضيين كرواتيين",
    "Lists of Cypriot politicians": "قوائم سياسيين قبارصة",
    "Lists of Czech people": "قوائم تشيكيين",
    "Lists of Czech people by occupation": "قوائم تشيكيين حسب المهنة",
    "Lists of Czech politicians": "قوائم سياسيين تشيكيين",
    "Lists of Czechoslovak people": "قوائم تشيكوسلوفاكيين",
    "Lists of Czechoslovak people by occupation": "قوائم تشيكوسلوفاكيين حسب المهنة",
    "Lists of Czechoslovak politicians": "قوائم سياسيين تشيكوسلوفاكيين",
    "Lists of Danish people": "قوائم دنماركيين",
    "Lists of Danish people by occupation": "قوائم دنماركيين حسب المهنة",
    "Lists of Danish politicians": "قوائم سياسيين دنماركيين",
    "Lists of Democratic republic of congo people": "قوائم كونغويين ديمقراطيين",
    "Lists of Dutch people": "قوائم هولنديين",
    "Lists of Dutch people by occupation": "قوائم هولنديين حسب المهنة",
    "Lists of Dutch politicians": "قوائم سياسيين هولنديين",
    "Lists of East Timorese people": "قوائم تيموريين شرقيين",
    "Lists of East Timorese politicians": "قوائم سياسيين تيموريين شرقيين",
    "Lists of Egyptian people": "قوائم مصريين",
    "Lists of Egyptian people by occupation": "قوائم مصريين حسب المهنة",
    "Lists of Egyptian politicians": "قوائم سياسيين مصريين",
    "Lists of Emirati people": "قوائم إماراتيين",
    "Lists of English sports-people": "قوائم رياضيين إنجليز",
    "Lists of European people": "قوائم أوروبيين",
    "Lists of European politicians": "قوائم سياسيين أوروبيين",
    "Lists of Fijian people": "قوائم فيجيين",
    "Lists of Finnish people": "قوائم فنلنديين",
    "Lists of Finnish people by occupation": "قوائم فنلنديين حسب المهنة",
    "Lists of Finnish politicians": "قوائم سياسيين فنلنديين",
    "Lists of French military personnel": "قوائم عسكريين فرنسيين",
    "Lists of French people": "قوائم فرنسيين",
    "Lists of French people by occupation": "قوائم فرنسيين حسب المهنة",
    "Lists of French politicians": "قوائم سياسيين فرنسيين",
    "Lists of French sports-people": "قوائم رياضيين فرنسيين",
    "Lists of German military personnel": "قوائم عسكريين ألمان",
    "Lists of German politicians": "قوائم سياسيين ألمان",
    "Lists of Greek people": "قوائم يونانيين",
    "Lists of Greek people by occupation": "قوائم يونانيين حسب المهنة",
    "Lists of Greek politicians": "قوائم سياسيين يونانيين",
    "Lists of Greek sports-people": "قوائم رياضيين يونانيين",
    "Lists of Greenlandic people": "قوائم غرينلانديين",
    "Lists of Guatemalan people": "قوائم غواتيماليين",
    "Lists of Guatemalan people by occupation": "قوائم غواتيماليين حسب المهنة",
    "Lists of Guyanese people": "قوائم غيانيين",
    "Lists of Guyanese people by occupation": "قوائم غيانيين حسب المهنة",
    "Lists of Honduran people": "قوائم هندوراسيين",
    "Lists of Honduran people by occupation": "قوائم هندوراسيين حسب المهنة",
    "Lists of Honduran politicians": "قوائم سياسيين هندوراسيين",
    "Lists of Hungarian people": "قوائم مجريين",
    "Lists of Hungarian people by occupation": "قوائم مجريين حسب المهنة",
    "Lists of Hungarian politicians": "قوائم سياسيين مجريين",
    "Lists of Icelandic people": "قوائم آيسلنديين",
    "Lists of Indian politicians": "قوائم سياسيين هنود",
    "Lists of Indonesian people": "قوائم إندونيسيين",
    "Lists of Indonesian people by occupation": "قوائم إندونيسيين حسب المهنة",
    "Lists of Indonesian politicians": "قوائم سياسيين إندونيسيين",
    "Lists of Iranian military personnel": "قوائم عسكريين إيرانيين",
    "Lists of Iranian people": "قوائم إيرانيين",
    "Lists of Iranian people by occupation": "قوائم إيرانيين حسب المهنة",
    "Lists of Iranian politicians": "قوائم سياسيين إيرانيين",
    "Lists of Iraqi people": "قوائم عراقيين",
    "Lists of Iraqi people by occupation": "قوائم عراقيين حسب المهنة",
    "Lists of Iraqi politicians": "قوائم سياسيين عراقيين",
    "Lists of Irish people": "قوائم أيرلنديين",
    "Lists of Irish people by occupation": "قوائم أيرلنديين حسب المهنة",
    "Lists of Irish politicians": "قوائم سياسيين أيرلنديين",
    "Lists of Islamic religious leaders": "قوائم قادة دينيين مسلمين",
    "Lists of Israeli award winners": "قوائم إسرائيليين حائزي جوائز",
    "Lists of Israeli people": "قوائم أعلام إسرائيليين",
    "Lists of Israeli people by occupation": "قوائم إسرائيليين حسب المهنة",
    "Lists of Israeli politicians": "قوائم سياسيين إسرائيليين",
    "Lists of Italian nobility": "قوائم نبلاء إيطاليين",
    "Lists of Italian people": "قوائم إيطاليين",
    "Lists of Italian people by occupation": "قوائم إيطاليين حسب المهنة",
    "Lists of Italian politicians": "قوائم سياسيين إيطاليين",
    "Lists of Italian sports-people": "قوائم رياضيين إيطاليين",
    "Lists of Ivorian people": "قوائم إيفواريين",
    "Lists of Ivorian people by occupation": "قوائم إيفواريين حسب المهنة",
    "Lists of Japanese people": "قوائم يابانيين",
    "Lists of Japanese people by occupation": "قوائم يابانيين حسب المهنة",
    "Lists of Japanese politicians": "قوائم سياسيين يابانيين",
    "Lists of Jewish religious leaders": "قوائم قادة دينيين يهود",
    "Lists of Jordanian people": "قوائم أردنيين",
    "Lists of Jordanian people by occupation": "قوائم أردنيين حسب المهنة",
    "Lists of Jordanian politicians": "قوائم سياسيين أردنيين",
    "Lists of Kazakhstani people": "قوائم كازاخستانيين",
    "Lists of Kenyan people": "قوائم كينيين",
    "Lists of Kenyan people by occupation": "قوائم كينيين حسب المهنة",
    "Lists of Kenyan politicians": "قوائم سياسيين كينيين",
    "Lists of Korean people": "قوائم كوريين",
    "Lists of Korean people by occupation": "قوائم كوريين حسب المهنة",
    "Lists of Kuwaiti people": "قوائم كويتيين",
    "Lists of Kuwaiti people by occupation": "قوائم كويتيين حسب المهنة",
    "Lists of Kuwaiti politicians": "قوائم سياسيين كويتيين",
    "Lists of Kyrgyzstani people": "قوائم قيرغيزستانيين",
    "Lists of Kyrgyzstani politicians": "قوائم سياسيين قيرغيزستانيين",
    "Lists of Lebanese people": "قوائم لبنانيين",
    "Lists of Lebanese people by occupation": "قوائم لبنانيين حسب المهنة",
    "Lists of Lebanese politicians": "قوائم سياسيين لبنانيين",
    "Lists of Lebanese sports-people": "قوائم رياضيين لبنانيين",
    "Lists of Libyan people": "قوائم ليبيين",
    "Lists of Libyan people by occupation": "قوائم ليبيين حسب المهنة",
    "Lists of Libyan politicians": "قوائم سياسيين ليبيين",
    "Lists of Luxembourgian people": "قوائم لوكسمبورغيين",
    "Lists of Luxembourgian people by occupation": "قوائم لوكسمبورغيين حسب المهنة",
    "Lists of Luxembourgian politicians": "قوائم سياسيين لوكسمبورغيين",
    "Lists of Malaysian people": "قوائم ماليزيين",
    "Lists of Malaysian people by occupation": "قوائم ماليزيين حسب المهنة",
    "Lists of Malaysian politicians": "قوائم سياسيين ماليزيين",
    "Lists of Maltese people by occupation": "قوائم مالطيين حسب المهنة",
    "Lists of Maltese politicians": "قوائم سياسيين مالطيين",
    "Lists of Mauritian people": "قوائم موريشيوسيين",
    "Lists of Mauritian people by occupation": "قوائم موريشيوسيين حسب المهنة",
    "Lists of Mauritian politicians": "قوائم سياسيين موريشيوسيين",
    "Lists of Mexican people": "قوائم مكسيكيين",
    "Lists of Mexican people by occupation": "قوائم مكسيكيين حسب المهنة",
    "Lists of Mexican politicians": "قوائم سياسيين مكسيكيين",
    "Lists of Mongolian people": "قوائم منغوليين",
    "Lists of Mongolian people by occupation": "قوائم منغوليين حسب المهنة",
    "Lists of Montenegrin people": "قوائم مونتينيغريين",
    "Lists of Montenegrin people by occupation": "قوائم مونتينيغريين حسب المهنة",
    "Lists of Moroccan politicians": "قوائم سياسيين مغاربة",
    "Lists of Mozambican people": "قوائم موزمبيقيين",
    "Lists of Nepalese people": "قوائم نيباليين",
    "Lists of Nepalese people by occupation": "قوائم نيباليين حسب المهنة",
    "Lists of Nepalese politicians": "قوائم سياسيين نيباليين",
    "Lists of New Zealand people": "قوائم نيوزيلنديين",
    "Lists of New Zealand people by occupation": "قوائم نيوزيلنديين حسب المهنة",
    "Lists of New Zealand politicians": "قوائم سياسيين نيوزيلنديين",
    "Lists of Nigerian people": "قوائم نيجيريين",
    "Lists of Nigerian people by occupation": "قوائم نيجيريين حسب المهنة",
    "Lists of North American people": "قوائم أمريكيين شماليين",
    "Lists of North American politicians": "قوائم سياسيين أمريكيين شماليين",
    "Lists of North Korean people": "قوائم كوريين شماليين",
    "Lists of Norwegian people": "قوائم نرويجيين",
    "Lists of Norwegian people by occupation": "قوائم نرويجيين حسب المهنة",
    "Lists of Norwegian politicians": "قوائم سياسيين نرويجيين",
    "Lists of Oceanian people": "قوائم أوقيانوسيين",
    "Lists of Oceanian politicians": "قوائم سياسيين أوقيانوسيين",
    "Lists of Olympic competitors": "قوائم منافسين أولمبيين",
    "Lists of Ottoman governors": "قوائم الولاة العثمانيين",
    "Lists of Ottoman military personnel": "قوائم عسكريين عثمانيين",
    "Lists of Pakistani people": "قوائم باكستانيين",
    "Lists of Pakistani people by occupation": "قوائم باكستانيين حسب المهنة",
    "Lists of Pakistani politicians": "قوائم سياسيين باكستانيين",
    "Lists of Palestinian people": "قوائم فلسطينيين",
    "Lists of Panamanian people": "قوائم بنميين",
    "Lists of Panamanian people by occupation": "قوائم بنميين حسب المهنة",
    "Lists of Panamanian politicians": "قوائم سياسيين بنميين",
    "Lists of Polish people": "قوائم بولنديين",
    "Lists of Polish people by occupation": "قوائم بولنديين حسب المهنة",
    "Lists of Polish politicians": "قوائم سياسيين بولنديين",
    "Lists of Portuguese people": "قوائم برتغاليين",
    "Lists of Portuguese people by occupation": "قوائم برتغاليين حسب المهنة",
    "Lists of Portuguese politicians": "قوائم سياسيين برتغاليين",
    "Lists of Protestant bishops and archbishops": "قوائم أساقفة ورؤساء أساقفة بروتستانتيين",
    "Lists of Puerto Rican people by occupation": "قوائم بورتوريكيين حسب المهنة",
    "Lists of Puerto Rican politicians": "قوائم سياسيين بورتوريكيين",
    "Lists of Romanian people": "قوائم رومانيين",
    "Lists of Romanian people by occupation": "قوائم رومانيين حسب المهنة",
    "Lists of Romanian politicians": "قوائم سياسيين رومانيين",
    "Lists of Russian politicians": "قوائم سياسيين روس",
    "Lists of Rwandan people": "قوائم أعلام روانديين",
    "Lists of Saudi Arabian people": "قوائم سعوديين",
    "Lists of Saudi Arabian people by occupation": "قوائم سعوديين حسب المهنة",
    "Lists of Scottish people": "قوائم إسكتلنديين",
    "Lists of Scottish people by occupation": "قوائم إسكتلنديين حسب المهنة",
    "Lists of Senegalese people": "قوائم سنغاليين",
    "Lists of Senegalese people by occupation": "قوائم سنغاليين حسب المهنة",
    "Lists of Senegalese politicians": "قوائم سياسيين سنغاليين",
    "Lists of Serbian politicians": "قوائم سياسيين صرب",
    "Lists of Seychellois people": "قوائم سيشليين",
    "Lists of Seychellois people by occupation": "قوائم سيشليين حسب المهنة",
    "Lists of Seychellois politicians": "قوائم سياسيين سيشليين",
    "Lists of Singaporean people": "قوائم سنغافوريين",
    "Lists of Singaporean people by occupation": "قوائم سنغافوريين حسب المهنة",
    "Lists of Singaporean politicians": "قوائم سياسيين سنغافوريين",
    "Lists of Slovak people": "قوائم سلوفاكيين",
    "Lists of Slovak people by occupation": "قوائم سلوفاكيين حسب المهنة",
    "Lists of Slovak politicians": "قوائم سياسيين سلوفاكيين",
    "Lists of South American people": "قوائم أمريكيين جنوبيين",
    "Lists of South American politicians": "قوائم سياسيين أمريكيين جنوبيين",
    "Lists of South Korean musicians": "قوائم موسيقيين كوريين جنوبيين",
    "Lists of South Korean people": "قوائم كوريين جنوبيين",
    "Lists of South Korean people by occupation": "قوائم كوريين جنوبيين حسب المهنة",
    "Lists of South Korean politicians": "قوائم سياسيين كوريين جنوبيين",
    "Lists of Southeast Asian people": "قوائم آسيويين جنوبيين شرقيين",
    "Lists of Southeast Asian politicians": "قوائم سياسيين آسيويين جنوبيين شرقيين",
    "Lists of Soviet politicians": "قوائم سياسيين سوفيت",
    "Lists of Spanish politicians": "قوائم سياسيين إسبان",
    "Lists of Spanish sports-people": "قوائم رياضيين إسبان",
    "Lists of Sri Lankan people": "قوائم سريلانكيين",
    "Lists of Sri Lankan people by occupation": "قوائم سريلانكيين حسب المهنة",
    "Lists of Sri Lankan politicians": "قوائم سياسيين سريلانكيين",
    "Lists of Sudanese people": "قوائم سودانيين",
    "Lists of Sudanese people by occupation": "قوائم سودانيين حسب المهنة",
    "Lists of Surinamese people": "قوائم سوريناميين",
    "Lists of Surinamese people by occupation": "قوائم سوريناميين حسب المهنة",
    "Lists of Surinamese politicians": "قوائم سياسيين سوريناميين",
    "Lists of Swedish people": "قوائم سويديين",
    "Lists of Swedish people by occupation": "قوائم سويديين حسب المهنة",
    "Lists of Swiss people": "قوائم سويسريين",
    "Lists of Syrian people": "قوائم سوريين",
    "Lists of Syrian people by occupation": "قوائم سوريين حسب المهنة",
    "Lists of Syrian politicians": "قوائم سياسيين سوريين",
    "Lists of Tanzanian people": "قوائم تنزانيين",
    "Lists of Tanzanian people by occupation": "قوائم تنزانيين حسب المهنة",
    "Lists of Tanzanian politicians": "قوائم سياسيين تنزانيين",
    "Lists of Thai people": "قوائم تايلنديين",
    "Lists of Thai people by occupation": "قوائم تايلنديين حسب المهنة",
    "Lists of Thai politicians": "قوائم سياسيين تايلنديين",
    "Lists of Tunisian people": "قوائم تونسيين",
    "Lists of Tunisian people by occupation": "قوائم تونسيين حسب المهنة",
    "Lists of Tunisian politicians": "قوائم سياسيين تونسيين",
    "Lists of Turkish military personnel": "قوائم عسكريين أتراك",
    "Lists of Turkish politicians": "قوائم سياسيين أتراك",
    "Lists of Turkmenistan people": "قوائم تركمانيين",
    "Lists of Turkmenistan politicians": "قوائم سياسيين تركمانيين",
    "Lists of Ugandan people": "قوائم أوغنديين",
    "Lists of Ugandan people by occupation": "قوائم أوغنديين حسب المهنة",
    "Lists of Ugandan politicians": "قوائم سياسيين أوغنديين",
    "Lists of Ukrainian people": "قوائم أوكرانيين",
    "Lists of Ukrainian people by occupation": "قوائم أوكرانيين حسب المهنة",
    "Lists of Ukrainian politicians": "قوائم سياسيين أوكرانيين",
    "Lists of Yemeni people": "قوائم يمنيين",
    "Lists of Yemeni people by occupation": "قوائم اليمنيين حسب المهنة",
    "Lists of Zambian people": "قوائم زامبيين",
    "Lists of Zambian people by occupation": "قوائم زامبيين حسب المهنة",
    "Lists of Zambian politicians": "قوائم سياسيين زامبيين",
    "Lists of Zimbabwean people": "قوائم زيمبابويين",
    "Lists of Zimbabwean people by occupation": "قوائم زيمبابويين حسب المهنة",
    "Lists of Zimbabwean politicians": "قوائم سياسيين زيمبابويين",
    "Lists of diplomats": "قوائم دبلوماسيين",
    "Lists of entertainers": "قوائم فنانين ترفيهيين",
    "Lists of fictional military personnel": "قوائم عسكريين خياليين",
    "Lists of international association football players": "قوائم لاعبي كرة قدم دوليين",
    "Lists of journalists": "قوائم صحفيين",
    "Lists of legislative speakers": "قوائم المتحدثين التشريعيين",
    "Lists of military personnel": "قوائم عسكريين",
    "Lists of military personnel by country": "قوائم عسكريين حسب البلد",
    "Lists of musicians": "قوائم موسيقيين",
    "Lists of musicians by genre": "قوائم موسيقيين حسب النوع الفني",
    "Lists of musicians by nationality": "قوائم موسيقيين حسب الجنسية",
    "Lists of people from Georgia (country)": "قوائم جورجيين",
    "Lists of politicians": "قوائم سياسيين",
    "Lists of politicians by nationality": "قوائم سياسيين حسب الجنسية",
    "Lists of politicians from Georgia (country)": "قوائم سياسيين جورجيين",
    "Lists of politicians from the United Kingdom": "قوائم سياسيين من المملكة المتحدة",
    "Lists of politicians lists": "قوائم بقوائم سياسيين",
    "Lists of religious leaders": "قوائم زعماء روحيين",
    "Lists of rulers in Asia": "قوائم حكام آسيويين",
    "Lists of rulers in Europe": "قوائم حكام أوروبيين",
    "Lists of scholars and academics": "قوائم دارسين وأكاديميين",
    "Lists of social activists": "قوائم نشطاء اجتماعيين",
    "Lists of sports medalists": "قوائم رياضيين فائزين بميداليات",
    "Lists of sportsmen": "قوائم رياضيين رجال",
    "Lists of sports-people": "قوائم رياضيين",
    "Lists of sports-people by nationality": "قوائم رياضيين حسب الجنسية",
    "Lists of sports-people by sport": "قوائم رياضيين حسب الرياضة",
    "Lists of sports-people by sport and nationality": "قوائم رياضيين حسب الرياضة والجنسية",
    "Lists of spouses of heads of state": "قوائم قرينات قادة وطنيين",
    "Lists of things named after mathematicians": "أشياء مسماة نسبة لرياضياتيين",
    "Local politicians in the Netherlands": "أصحاب مناصب سياسيين محليين في هولندا",
    "Malaysian male squash players": "لاعبو سكواش ماليزيين",
    "Mali men's A' international footballers": "لاعبو منتخب مالي لكرة القدم للرجال للمحليين",
    "Massacres of Bengali Hindus": "مذابح الهندوس البنغاليين",
    "Massacres of Bengali Hindus in British India": "مذابح الهندوس البنغاليين في الراج البريطاني",
    "Massacres of Bengali Hindus in East Pakistan": "مذابح الهندوس البنغاليين في باكستان الشرقية",
    "Massacres of Christians": "مجازر ضد المسيحيين",
    "Massacres of Native Americans": "مذابح في السكان الأصليين في الولايات المتحدة",
    "Massacres of Palestinians": "مذابح ضد الفلسطينيين",
    "Massacres of Ukrainians": "مذابح ضد أوكرانيين",
    "Massacres of Ukrainians during World War II": "مذابح ضد أوكرانيين خلال الحرب العالمية الثانية",
    "Mauritania men's A' international footballers": "لاعبو منتخب موريتانيا لكرة القدم للرجال للمحليين",
    "Mawlamyine": "ماولاميين",
    "Mayors of Cayenne": "عمدات كايين",
    "Melkite Christian communities in Lebanon": "تجمعات الروم الملكيين في لبنان",
    "Melkite Greek Catholic Church": "كنيسة الروم الملكيين الكاثوليك",
    "Melkite Greek Catholic Church by country": "كنيسة الروم الملكيين الكاثوليك حسب البلد",
    "Melkite Greek Catholic Church in Brazil": "كنيسة الروم الملكيين الكاثوليك في البرازيل",
    "Melkite Greek Catholic Church in Egypt": "كنيسة الروم الملكيين الكاثوليك في مصر",
    "Melkite Greek Catholic Church in Israel": "كنيسة الروم الملكيين الكاثوليك في إسرائيل",
    "Melkite Greek Catholic Church in Jordan": "كنيسة الروم الملكيين الكاثوليك في الأردن",
    "Melkite Greek Catholic Church in Lebanon": "كنيسة الروم الملكيين الكاثوليك في لبنان",
    "Melkite Greek Catholic Church in North America": "كنيسة الروم الملكيين الكاثوليك في أمريكا الشمالية",
    "Melkite Greek Catholic Church in South America": "كنيسة الروم الملكيين الكاثوليك في أمريكا الجنوبية",
    "Melkite Greek Catholic Church in Syria": "كنيسة الروم الملكيين الكاثوليك في سوريا",
    "Melkite Greek Catholic Church in the United States": "كنيسة الروم الملكيين الكاثوليك في الولايات المتحدة",
    "Melkite Greek Catholic Patriarchs of Antioch": "بطاركة كنيسة الروم الملكيين الكاثوليك",
    "Melkite Greek Catholic churches in Israel": "كنائس الروم الملكيين الكاثوليك في إسرائيل",
    "Members of Parliament for Haute-Vienne": "أعضاء البرلمان عن فيين العليا (إقليم فرنسي)",
    "Members of Parliament for Vienne (department)": "أعضاء البرلمان عن فيين (إقليم فرنسي)",
    "Members of the Academy of Persian Language and Literature": "أعضاء أكاديمية اللغة والأدب الفارسيين",
    "Members of the Cabinet of the United States of Asian descent": "أمريكيون آسيويين أعضاء في مجلس وزراء الولايات المتحدة",
    "Members of the Democratic Socialists of America": "أعضاء الاشتراكيين الديمقراطيين في أمريكا",
    "Members of the Royal College of Veterinary Surgeons": "أعضاء الكلية الملكية للجراحين البيطريين",
    "Members of the United States House of Representatives of Asian descent": "أمريكيون آسيويين أعضاء في مجلس النواب الأمريكي",
    "Military officer training": "تدريب الضباط العسكريين",
    "Ministers of health of Canada": "وزراء الصحة الكنديين",
    "Minnesota Democratic–Farmer–Labor Party": "حزب العمال المزارعين الديمقراطيين في منيسوتا",
    "Monarchs in Southeast Asia": "ملكيون آسيويين جنوبيون شرقيون",
    "Monuments and memorials to musicians": "معالم أثرية ونصب تذكارية لموسيقيين",
    "Monuments and memorials to politicians": "معالم أثرية ونصب تذكارية لسياسيين",
    "Morocco men's A' international footballers": "لاعبو منتخب المغرب لكرة القدم للرجال للمحليين",
    "Mosques destroyed by Christians": "مساجد دمرت على أيدي مسيحيين",
    "Most-wanted Iraqi playing cards": "مجموعة أوراق اللعب لأهم المطلوبين العراقيين",
    "Mothers of Abbasid caliphs": "أمهات الخلفاء العباسيين",
    "Movement for Social Democracy": "حركة الديمقراطيين الاجتماعية",
    "Movement of Socialist Democrats politicians": "سياسيو حركة الديمقراطيين الاشتراكيين",
    "Mozambique men's A' international footballers": "لاعبو منتخب موزمبيق لكرة القدم للرجال للمحليين",
    "Murdered Asian children": "أطفال آسيويين قتلوا",
    "Musicians Institute alumni": "خريجو معهد الموسيقيين",
    "Musicians work group articles": "مقالات فريق عمل الموسيقيين",
    "Mythological kings of Sparta": "ملوك أسبرطة الأسطوريين",
    "Māori culture": "ثقافة الماوريين",
    "Māori weapons": "أسلحة الماوريين",
    "Namibia men's A' international footballers": "لاعبو منتخب ناميبيا لكرة القدم للرجال للمحليين",
    "National A' association football teams": "منتخبات كرة قدم للمحليين",
    "National Liberal Party (Lebanon) politicians": "سياسيو حزب الوطنيين الأحرار",
    "Native American art": "فنون الأمريكيين الأصليين",
    "Native American history": "تاريخ الأمريكيين الأصليين",
    "Native American history by location": "تاريخ الأمريكيين الأصليين حسب الموقع",
    "Native American history of Alabama": "تاريخ الأمريكيين الأصليين في ألاباما",
    "Native American history of Alaska": "تاريخ الأمريكيين الأصليين في ألاسكا",
    "Native American history of Arizona": "تاريخ الأمريكيين الأصليين في أريزونا",
    "Native American history of Arkansas": "تاريخ الأمريكيين الأصليين في أركنساس",
    "Native American history of California": "تاريخ الأمريكيين الأصليين في كاليفورنيا",
    "Native American history of Colorado": "تاريخ الأمريكيين الأصليين في كولورادو",
    "Native American history of Connecticut": "تاريخ الأمريكيين الأصليين في كونيتيكت",
    "Native American history of Florida": "تاريخ الأمريكيين الأصليين في فلوريدا",
    "Native American history of Georgia (U.S. state)": "تاريخ الأمريكيين الأصليين في ولاية جورجيا",
    "Native American history of Idaho": "تاريخ الأمريكيين الأصليين في أيداهو",
    "Native American history of Illinois": "تاريخ الأمريكيين الأصليين في إلينوي",
    "Native American history of Indiana": "تاريخ الأمريكيين الأصليين في إنديانا",
    "Native American history of Iowa": "تاريخ الأمريكيين الأصليين في آيوا",
    "Native American history of Kansas": "تاريخ الأمريكيين الأصليين في كانساس",
    "Native American history of Louisiana": "تاريخ الأمريكيين الأصليين في لويزيانا",
    "Native American history of Maine": "تاريخ الأمريكيين الأصليين في مين",
    "Native American history of Maryland": "تاريخ الأمريكيين الأصليين في ماريلند",
    "Native American history of Massachusetts": "تاريخ الأمريكيين الأصليين في ماساتشوستس",
    "Native American history of Michigan": "تاريخ الأمريكيين الأصليين في ميشيغان",
    "Native American history of Minnesota": "تاريخ الأمريكيين الأصليين في منيسوتا",
    "Native American history of Missouri": "تاريخ الأمريكيين الأصليين في ميزوري",
    "Native American history of Montana": "تاريخ الأمريكيين الأصليين في مونتانا",
    "Native American history of Nebraska": "تاريخ الأمريكيين الأصليين في نبراسكا",
    "Native American history of Nevada": "تاريخ الأمريكيين الأصليين في نيفادا",
    "Native American history of New England": "تاريخ الأمريكيين الأصليين في نيو إنجلاند",
    "Native American history of New Hampshire": "تاريخ الأمريكيين الأصليين في نيوهامشير",
    "Native American history of New Mexico": "تاريخ الأمريكيين الأصليين في نيومكسيكو",
    "Native American history of New York (state)": "تاريخ الأمريكيين الأصليين في ولاية نيويورك",
    "Native American history of North Carolina": "تاريخ الأمريكيين الأصليين في كارولاينا الشمالية",
    "Native American history of North Dakota": "تاريخ الأمريكيين الأصليين في داكوتا الشمالية",
    "Native American history of Ohio": "تاريخ الأمريكيين الأصليين في أوهايو",
    "Native American history of Oklahoma": "تاريخ الأمريكيين الأصليين في أوكلاهوما",
    "Native American history of Oregon": "تاريخ الأمريكيين الأصليين في أوريغن",
    "Native American history of Pennsylvania": "تاريخ الأمريكيين الأصليين في بنسلفانيا",
    "Native American history of Rhode Island": "تاريخ الأمريكيين الأصليين في رود آيلاند",
    "Native American history of South Carolina": "تاريخ الأمريكيين الأصليين في كارولاينا الجنوبية",
    "Native American history of South Dakota": "تاريخ الأمريكيين الأصليين في داكوتا الجنوبية",
    "Native American history of Tennessee": "تاريخ الأمريكيين الأصليين في تينيسي",
    "Native American history of Texas": "تاريخ الأمريكيين الأصليين في تكساس",
    "Native American history of Utah": "تاريخ الأمريكيين الأصليين في يوتا",
    "Native American history of Vermont": "تاريخ الأمريكيين الأصليين في فيرمونت",
    "Native American history of Virginia": "تاريخ الأمريكيين الأصليين في فرجينيا",
    "Native American history of Washington (state)": "تاريخ الأمريكيين الأصليين في ولاية واشنطن",
    "Native American history of West Virginia": "تاريخ الأمريكيين الأصليين في فرجينيا الغربية",
    "Native American history of Wisconsin": "تاريخ الأمريكيين الأصليين في ويسكونسن",
    "Native American history of Wyoming": "تاريخ الأمريكيين الأصليين في وايومنغ",
    "Native American people in the American Revolution": "السكان الأصليين في الولايات المتحدة في الثورة الأمريكية",
    "Native American religion": "ديانات الأمريكيين الأصليين",
    "Native American studies": "دراسات الأمريكيين الأصليين",
    "Native American tribes by state": "قبائل الأمريكيين الأصليين حسب الولاية",
    "Native American tribes in Arizona": "قبائل الأمريكيين الأصليين في أريزونا",
    "Native American tribes in Florida": "قبائل الأمريكيين الأصليين في فلوريدا",
    "Native American tribes in New Mexico": "قبائل الأمريكيين الأصليين في نيو مكسيكو",
    "Native American tribes in North Carolina": "قبائل الأمريكيين الأصليين في كارولينا الشمالية",
    "Native American tribes in Oklahoma": "قبائل الأمريكيين الأصليين في أوكلاهوما",
    "Native Americans in Alaska": "السكان الأصليين في الولايات المتحدة في ألاسكا",
    "Native Americans in Arizona": "السكان الأصليين في الولايات المتحدة في أريزونا",
    "Native Americans in South Dakota": "السكان الأصليين فى الولايات المتحدة في داكوتا الجنوبية",
    "Native Americans in popular culture": "سكان الولايات المتحدة الأصليين في الثقافة الشعبية",
    "Native Americans in the American Revolution": "السكان الأصليين في الولايات المتحدة في الثورة الأمريكية",
    "Native Hawaiian activists": "ناشطون أمريكيون من الهاوائيين الأصليين",
    "Naval battles involving the Ottoman Empire": "معارك العثمانيين البحرية",
    "Naval battles involving the Umayyad Caliphate": "معارك الأمويين البحرية",
    "Naval history of the Ottoman Empire": "تاريخ العثمانيين البحري",
    "Naxalite–Maoist insurgency": "الحرب الشعبية في الهند- تمرد الناكسال الماويين",
    "Neo-Nazi concepts": "معتقدات النازيين الجدد",
    "Neo-Nazi organizations": "منظمات النازيين الجدد",
    "Neo-Nazi political parties": "أحزاب النازيين الجدد السياسية",
    "New Zealand film director navigational boxes": "صناديق تصفح مخرجي أفلام نيوزيلنديين",
    "New Zealand military memorials and cemeteries": "نصب تذكارية ومقابر عسكريين نيوزيلنديين",
    "New-age albums by Greek artists": "ألبومات العصر الحديث لفنانين يونانيين",
    "Niger men's A' international footballers": "لاعبو منتخب النيجر لكرة القدم للرجال للمحليين",
    "Nigeria men's A' international footballers": "لاعبو منتخب نيجيريا لكرة القدم للرجال للمحليين",
    "Non-profit academic publishers": "ناشرون أكاديميون غير ربحيين",
    "Norse colonization of North America": "استعمار الشماليين لأمريكا الشمالية",
    "North Korean abductions of Japanese citizens": "اختطاف كوريا الشمالية مواطنين يابانيين",
    "Novelist navigational boxes": "صناديق تصفح روائيين",
    "Novels about Nazis": "روايات عن نازيين",
    "Novels about architects": "روايات عن معماريين",
    "Novels about journalists": "روايات عن صحفيين",
    "Novels about mass media people": "روايات عن إعلاميين",
    "Novels about politicians": "روايات عن سياسيين",
    "Novels about revolutionaries": "روايات عن الثوريين",
    "Oceanian film director navigational boxes": "صناديق تصفح مخرجي أفلام أوقيانوسيين",
    "Official residences of subnational executives": "المساكن الرسمية للمدراء التنفيذيين دون الوطنيين",
    "Offshoots of the Arab Nationalist Movement": "مجموعات حركة قوميين عرب انفصالية",
    "Olympic champions navigational boxes": "قوالب تصفح الأبطال الأولمبيين",
    "Opposition to same-sex marriage": "معارضة زواج المثليين",
    "Organisations serving Indigenous Australians": "منظمات تخدم السكان الأصليين الأستراليين",
    "Organization of American Historians": "منظمة المؤرخين الأمريكيين",
    "Organization of Ukrainian Nationalists": "تنظيم القوميين الأوكرانيين",
    "Oriental Orthodox monarchs": "ملوك مسيحيون غير خلقيدونيين",
    "Ostrogothic Kingdom": "مملكة القوط الشرقيين",
    "Ostrogothic kings": "ملوك القوط الشرقيين",
    "Ottoman governors of Anatolia": "ولاة الأناضول العثمانيين",
    "Palestine refugee camps": "مخيمات اللاجئين الفلسطينيين",
    "Palestinian Fedayeen insurgency": "تمرد الفدائيين الفلسطينيين",
    "Palestinian casualties in the Second Intifada": "ضحايا فلسطينيين في الانتفاضة الفلسطينية الثانية",
    "Palestinian refugee camps in Jordan": "مخيمات اللاجئين الفلسطينيين في الأردن",
    "Palestinian refugee camps in Lebanon": "مخيمات اللاجئين الفلسطينيين في لبنان",
    "Palestinian refugee camps in Syria": "مخيمات اللاجئين الفلسطينيين في سوريا",
    "Palestinian refugee camps in the Gaza Strip": "مخيمات اللاجئين الفلسطينيين في قطاع غزة",
    "Palestinian refugee camps in the West Bank": "مخيمات اللاجئين الفلسطينيين في الضفة الغربية",
    "Palestinian stone-throwing": "رمي الفلسطينيين للحجارة",
    "Party of Democratic Socialism (Germany) politicians": "حزب الاشتراكيين الديمقراطيين (ألمانيا)",
    "Party of European Socialists": "حزب الاشتراكيين الأوروبيين",
    "Patriots in the American Revolution": "الوطنيين في الثورة الأمريكية",
    "Patriottentijd": "عصر الوطنيين",
    "Payne County, Oklahoma": "مقاطعة بايين (أوكلاهوما)",
    "People educated at Synge Street CBS": "أشخاص متعلمون في مدرسة شارع سينغ للأخوان المسيحيين",
    "People from Camiguin": "أشخاص من كاميغويين",
    "People from Camiguin by occupation": "أشخاص من كاميغويين حسب المهنة",
    "People from Cayenne": "أشخاص من كايين",
    "People from Compiègne": "أشخاص من كومبيين",
    "People from East Francia": "أشخاص من مملكة الفرنجة الشرقيين",
    "People from Haute-Vienne": "أشخاص من فيين العليا (إقليم فرنسي)",
    "People from Kayin State": "أشخاص من ولاية كايين",
    "People from Maringouin, Louisiana": "أشخاص من مارينغويين (لويزيانا)",
    "People from Mawlamyine": "أشخاص من ماولاميين",
    "People from Payne County, Oklahoma": "أشخاص من مقاطعة بايين (أوكلاهوما)",
    "People from Saint-Jean-de-Maurienne": "أشخاص من سان-جان-دي-موريين",
    "People from Vienne": "أشخاص من فيين (إقليم فرنسي)",
    "People from Vienne (department)": "أشخاص من فيين (إقليم فرنسي)",
    "People from Vienne, Isère": "أشخاص من فيين",
    "People from West Francia": "أشخاص من مملكة الفرنجة الغربيين",
    "People from the Ostrogothic Kingdom": "أشخاص من مملكة القوط الشرقيين",
    "People listed in Russia as media foreign agents": "أشخاص مدرجون في روسيا كعملاء إعلاميين أجانب",
    "People of the Hussite Wars": "أشخاص في حروب الهوسيين",
    "People of the Ostrogothic Kingdom": "أشخاص من مملكة القوط الشرقيين",
    "People of the Patriottentijd": "شخصيات من عصر الوطنيين",
    "People under the Salghurids": "أشخاص في عهد السلغوريين",
    "Persecution by Buddhists": "اضطهاد من قبل بوذيين",
    "Persecution by Christians": "اضطهاد من قبل مسيحيين",
    "Persecution of Ahmadis": "اضطهاد الأحمديين",
    "Persecution of Alawites": "اضطهاد العلويين",
    "Persecution of Assyrians": "اضطهاد الآشوريين",
    "Persecution of Assyrians by ISIL": "اضطهاد تنظيم الدولة الإسلامية (داعش) للآشوريين",
    "Persecution of Assyrians in Iraq": "اضطهاد الآشوريين في العراق",
    "Persecution of Assyrians in Turkey": "اضطهاد الآشوريين في تركيا",
    "Persecution of Assyrians in the Ottoman Empire": "اضطهاد الآشوريين في الدولة العثمانية",
    "Persecution of Bahá'ís": "اضطهاد البهائيين",
    "Persecution of Bengali Hindus": "اضطهاد الهندوس البنغاليين",
    "Persecution of Buddhists": "اضطهاد البوذيين",
    "Persecution of Christians": "اضطهاد المسيحيين",
    "Persecution of Christians by ISIL": "اضطهاد تنظيم الدولة الإسلامية (داعش) للمسيحيين",
    "Persecution of Christians by Muslims": "اضطهاد منسوب للمسلمين ضد المسيحيين",
    "Persecution of Christians in Indonesia": "اضطهاد المسيحيين في إندونيسيا",
    "Persecution of Christians in Iran": "اضطهاد المسيحيين في إيران",
    "Persecution of Christians in Iraq": "اضطهاد المسيحيين في العراق",
    "Persecution of Christians in Pakistan": "اضطهاد المسيحيين في باكستان",
    "Persecution of Christians in Turkey": "اضطهاد المسيحيين في تركيا",
    "Persecution of Christians in the Ottoman Empire": "اضطهاد المسيحيين في الدولة العثمانية",
    "Persecution of Eastern Orthodox Christians": "اضطهاد المسيحيين الأرثوذكس الشرقيين",
    "Persecution of Greeks": "اضطهاد اليونانيين",
    "Persecution of Greeks in Turkey": "اضطهاد اليونانيين في تركيا",
    "Persecution of Greeks in the Ottoman Empire": "اضطهاد اليونانيين في الدولة العثمانية",
    "Persecution of Greeks in the Ottoman Empire before the 20th century": "اضطهاد اليونانيين في الدولة العثمانية قبل القرن 20",
    "Persecution of Greeks in the Ottoman Empire in the 20th century": "اضطهاد اليونانيين في الدولة العثمانية بعد القرن 20",
    "Persecution of Iraqi Turkmen": "اضطهاد التركمانيين العراقيين",
    "Persecution of Muslims by Christians": "اضطهاد المسلمين من قبل المسيحيين",
    "Persecution of Oriental Orthodox Christians": "اضطهاد المسيحيين الأرثوذكس المشرقيين",
    "Persecution of Ottoman Muslims": "اضطهاد المسلمين العثمانيين",
    "Persecution of Pagans": "اضطهاد الوثنيين",
    "Persecution of Yazidis": "اضطهاد اليزيديين",
    "Persecution of Yazidis by ISIL": "اضطهاد تنظيم الدولة الإسلامية (داعش) لليزيديين",
    "Persecution of Yazidis in Iraq": "اضطهاد اليزيديين في العراق",
    "Persecution of early Christians": "اضطهاد المسيحيين الأوائل",
    "Persecution of homosexuals in Nazi Germany": "اضطهاد المثليين في ألمانيا النازية والهولوكوست",
    "Persecution of pagans in the late Roman Empire": "اضطهاد الوثنيين في الإمبراطورية الرومانية المتأخرة",
    "Philippine dynasty": "سلالة الفيليبيين",
    "Pinyin": "بينيين",
    "Poets under the Salghurids": "شعراء في عهد السلغوريين",
    "Police raids on Islamists": "غارات الشرطة على الإسلاميين",
    "Polish deportees to Soviet Union": "المهجريين البولنديين إلى الاتحاد السوفيتي",
    "Polish deportees to the Soviet Union": "المهجريين البولنديين إلى الاتحاد السوفيتي",
    "Polish exiles": "المنفيين البولنديين",
    "Polish people imprisoned in Russia": "سجناء بولنديين في روسيا",
    "Political positions of American politicians": "مواقف سياسية للسياسيين الأمريكيين",
    "Political positions of politicians": "مواقف سياسية للسياسيين",
    "Politicians from Camiguin": "سياسيون من كاميغويين",
    "Politics and government work group articles": "مقالات فريق عمل السياسيين وصناع القرار",
    "Polyenes": "بوليين",
    "Pop albums by American artists": "ألبومات بوب لفنانين أمريكيين",
    "Pop albums by Australian artists": "ألبومات بوب لفنانين أستراليين",
    "Pop albums by British artists": "ألبومات بوب لفنانين بريطانيين",
    "Pop albums by Canadian artists": "ألبومات بوب لفنانين كنديين",
    "Pop albums by Egyptian artists": "ألبومات بوب لفنانين مصريين",
    "Pop albums by Emirati artists": "ألبومات بوب لفنانين إماراتيين",
    "Pop albums by Iraqi artists": "ألبومات بوب لفنانين عراقيين",
    "Pop albums by Japanese artists": "ألبومات بوب لفنانين يابانيين",
    "Pop albums by Lebanese artists": "ألبومات بوب لفنانين لبنانيين",
    "Pop albums by Libyan artists": "ألبومات بوب لفنانين ليبيين",
    "Pop albums by Mexican artists": "ألبومات بوب لفنانين مكسيكيين",
    "Pop albums by Romanian artists": "ألبومات بوب لفنانين رومانيين",
    "Pop albums by South Korean artists": "ألبومات بوب لفنانين كوريين جنوبيين",
    "Populated places in Payne County, Oklahoma": "أماكن مأهولة في مقاطعة بايين (أوكلاهوما)",
    "Presidents of the American Association of Geographers": "رؤساء رابطة الجغرافيين الامريكيين",
    "Presidents of the American Institute of Architects": "رؤساء الجمعية الأمريكية للمعماريين",
    "Presidents of the Institution of Civil Engineers": "رؤساء معهد المهندسين المدنيين",
    "Presidents of the Institution of Structural Engineers": "رؤساء معهد المهندسين الإنشائيين",
    "Presidents of the Party of European Socialists": "رؤساء حزب الاشتراكيين الأوروبيين",
    "Presidents of the Royal Institute of British Architects": "رؤساء المعهد الملكي للمعماريين البريطانيين",
    "Progressive Alliance of Socialists and Democrats": "التحالف التقدمي للاشتراكيين والديمقراطيين",
    "Progressive Conservative Party of Ontario MPPs": "أعضاء في برلمان مقاطعة أونتاريو عن حزب المحافظين التقدميين",
    "Progressive Conservative Party of Ontario politicians": "سياسيون في حزب المحافظين التقدميين في أونتاريو",
    "Progressive Democrats": "حزب الديمقراطيين التقدميين",
    "Progressive music albums by Swedish artists": "ألبومات موسيقى تقدمية لفنانين سويديين",
    "Public image of American politicians": "صورة عامة للسياسيين الأميركيين",
    "Public image of politicians": "صورة عامة للسياسيين",
    "Racially motivated violence against African Americans": "العنف بدوافع عنصرية ضد الأمريكيين الأفارقة",
    "Racially motivated violence against Asian Americans": "عنف بدوافع عنصرية ضد الأمريكيين الآسيويين",
    "Rattachism": "راتشيين",
    "Raëlian practices": "معتقدات الرائيليين",
    "Refugee Olympic Team at the 2016 Summer Olympics": "فريق الرياضيين الأولمبيين اللاجئين في الألعاب الأولمبية الصيفية 2016",
    "Reggae albums by American artists": "ألبومات ريغي لفنانين أمريكيين",
    "Reggae albums by Barbadian artists": "ألبومات ريغيه لفنانين بربادوسيين",
    "Reggae albums by Egyptian artists": "ألبومات ريغيه لفنانين مصريين",
    "Religious music albums by American artists": "ألبومات موسيقى دينية لفنانين أمريكيين",
    "Religious music albums by South Korean artists": "ألبومات موسيقى دينية لفنانين كوريين جنوبيين",
    "Religious persecution by communists": "اضطهاد ديني من قبل الشيوعيين",
    "Republic of Ireland LGBT rights case law": "قضايا محاكم أيرلندية حول حقوق المثليين",
    "Republic of Ireland LGBTQ rights case law": "قضايا محاكم أيرلندية حول معاملة المثليين",
    "republic of congo men's A' international footballers": "لاعبو منتخب جمهورية الكونغو لكرة القدم للرجال للمحليين",
    "Rescue of Jews by Poles in occupied Poland in 1939-1945": "انقاذ اليهود على يد البولنديين في بولندا المحتلة في 1939-1945",
    "Rescue of Jews by Poles in occupied Poland in 1939–1945": "انقاذ اليهود على يد البولنديين في بولندا المحتلة في 1939-1945",
    "Rhythm and blues albums by British artists": "ألبومات ريذم أند بلوز لفنانين بريطانيين",
    "Rivers of Haute-Vienne": "أنهار فيين العليا (إقليم فرنسي)",
    "Rivers of Payne County, Oklahoma": "أنهار مقاطعة بايين (أوكلاهوما)",
    "Rivers of Vienne": "أنهار فيين (إقليم فرنسي)",
    "Rivers of Vienne (department)": "أنهار فيين (إقليم فرنسي)",
    "Robot comics": "قصص مصورة عن آليين",
    "Rock albums by British artists": "ألبومات روك لفنانين بريطانيين",
    "Rock albums by Swedish artists": "ألبومات روك لفنانين سويديين",
    "Royal Governors of Venezuela": "الحكام الملكيين لفنزويلا",
    "Royal Institute of British Architects": "المعهد الملكي للمهندسين المعماريين البريطانيين",
    "Royal governors of Venezuela": "الحكام الملكيين لفنزويلا",
    "Rwanda men's A' international footballers": "لاعبو منتخب رواندا لكرة القدم للرجال للمحليين",
    "Sahrawi refugee camps": "مخيمات اللاجئين الصحراويين",
    "Saint-Jean-de-Maurienne": "سان-جان-دي-موريين",
    "Saints from East Francia": "قديسون من مملكة الفرنجة الشرقيين",
    "Samaritan culture and history": "تاريخ وثقافة السامريين",
    "Same-sex adoption": "تبني المثليين للأطفال",
    "Same-sex adoption in Europe": "تبني المثليين للأطفال في أوروبا",
    "Same-sex adoption in the United States": "تبني المثليين للأطفال في الولايات المتحدة",
    "Same-sex marriage by country": "زواج المثليين حسب البلد",
    "Same-sex marriage by country subdivision": "زواج المثليين حسب المستوى دون الوطني للبلد",
    "Same-sex marriage in Australia": "زواج المثليين في أستراليا",
    "Same-sex marriage in Brazil": "زواج المثليين في البرازيل",
    "Same-sex marriage in British Overseas Territories": "زواج المثليين في أقاليم ما وراء البحار البريطانية",
    "Same-sex marriage in Canada": "زواج المثليين في كندا",
    "Same-sex marriage in Canada by province or territory": "زواج المثليين في كندا حسب المقاطعة أو الإقليم",
    "Same-sex marriage in Denmark": "زواج المثليين في الدنمارك",
    "Same-sex marriage in France": "زواج المثليين في فرنسا",
    "Same-sex marriage in Mexico": "زواج المثليين في المكسيك",
    "Same-sex marriage in Mexico by state": "زواج المثليين في المكسيك حسب الولاية",
    "Same-sex marriage in dependent territories of the United Kingdom": "زواج المثليين في تبعيات التاج البريطاني",
    "Same-sex marriage in fiction": "زواج المثليين في الأعمال الخيالية",
    "Same-sex marriage in the Crown Dependencies": "زواج المثليين في تبعيات التاج البريطاني",
    "Same-sex marriage in the Netherlands": "زواج المثليين في هولندا",
    "Same-sex marriage in republic of Ireland": "زواج المثليين في جمهورية أيرلندا",
    "Same-sex marriage in the United Kingdom": "زواج المثليين في المملكة المتحدة",
    "Same-sex marriage in the United States": "زواج المثليين في الولايات المتحدة",
    "Science and academia work group articles": "مقالات فريق عمل الأكاديميين والعلماء",
    "Sculptures of politicians": "منحوتات لسياسيين",
    "Semi-vegetarianism": "شبه نباتيين",
    "Senegal men's A' international footballers": "لاعبو منتخب السنغال لكرة القدم للرجال للمحليين",
    "Senegalese film director navigational boxes": "صناديق تصفح مخرجي أفلام سنغاليين",
    "Sephardi Jewish cuisine": "مطبخ اليهود الشرقيين",
    "Serbian geophysicists": "جيوفيزيائيين صرب",
    "Sikh terrorism": "إرهاب منسوب للسيخيين",
    "Slavery of Native Americans": "العبودية في السكان الأصليين في الولايات المتحدة",
    "Socialist Workers Party (United States)": "حزب العمال الاشتراكيين",
    "Soft rock albums by Irish artists": "ألبومات سوفت روك لفنانين أيرلنديين",
    "Songs about American politicians": "أغان عن سياسيين أمريكيين",
    "Songs about comedians": "أغان عن كوميديين",
    "Songs about fictional male characters": "أغان عن ذكور خياليين",
    "Songs about military officers": "أغان عن ضباط عسكريين",
    "Songs about musicians": "أغان عن موسيقيين",
    "Songs about politicians": "أغان عن سياسيين",
    "Songs about religious leaders": "أغان عن قادة دينيين",
    "Songs about sports-people": "أغان عن رياضيين",
    "Southeast Asian American": "أمريكيون آسيويين جنوبيون شرقيون",
    "Southeast Asian English": "إنجليز آسيويين جنوبيون شرقيون",
    "Southeast Asian Jews": "يهود آسيويين جنوبيون شرقيون",
    "Southeast Asian communists": "شيوعيون آسيويين جنوبيون شرقيون",
    "Southeast Asian diaspora in the United States": "أمريكيون آسيويين جنوبيون شرقيون",
    "Southeast Asian people by occupation": "آسيويين جنوبيون شرقيون حسب المهنة",
    "Southeast Asian people by political orientation": "آسيويين جنوبيون شرقيون حسب التوجه السياسي",
    "Southeast Asian people in sports": "آسيويين جنوبيون شرقيون في ألعاب رياضية",
    "Southeast Asian people of Brazilian descent": "آسيويين جنوبيون شرقيون من أصل برازيلي",
    "Southeast Asian people of Chinese descent": "آسيويين جنوبيون شرقيون من أصل صيني",
    "Southeast Asian political people": "ساسة آسيويين جنوبيون شرقيون",
    "Southeast Asian sports coaches": "مدربو رياضة آسيويين جنوبيون شرقيون",
    "Soviet and Russian space program locations": "مواقع البرنامجين الفضائيين السوفيتي والروسي",
    "Speeches by Nazis": "خطب النازيين",
    "Sport in Haute-Vienne": "الرياضة في فيين العليا (إقليم فرنسي)",
    "Sport in Vienne": "الرياضة في فيين (إقليم فرنسي)",
    "Sport in Vienne (department)": "الرياضة في فيين (إقليم فرنسي)",
    "Sports and games work group articles": "مقالات فريق عمل الرياضيين",
    "sports-people from Camiguin": "رياضيون من كاميغويين",
    "sports-people from Cayenne": "رياضيون من كايين",
    "sports-people from Haute-Vienne": "رياضيون من فيين العليا (إقليم فرنسي)",
    "sports-people from Vienne": "رياضيون من فيين (إقليم فرنسي)",
    "sports-people from Vienne (department)": "رياضيون من فيين (إقليم فرنسي)",
    "Spouses of Iranian politicians": "قرينات سياسيين إيرانيين",
    "Spouses of heads of state by country": "قرينات قادة وطنيين حسب البلد",
    "Spouses of politicians": "أزواج سياسيين",
    "Statues of politicians": "تماثيل سياسيين",
    "Structures by American engineers": "منشآت من تصميم مهندسين أمريكيين",
    "Subgroups of the Han Chinese": "مجموعات فرعية للهان الصينيين",
    "Subnational legislators in South America": "المشرعون دون الوطنيين في أمريكا الجنوبية",
    "Sudan men's A' international footballers": "لاعبو منتخب السودان لكرة القدم للرجال للمحليين",
    "Superhero films about Asian Americans": "أفلام أبطال خارقين عن أمريكيون آسيويين",
    "Synth-pop albums by Australian artists": "ألبومات سينثبوب لفنانين أستراليين",
    "Syrian refugee camps": "مخيمات اللاجئين السوريين",
    "Syrian-American history": "تاريخ السوريين في الولايات المتحدة",
    "Table tennis Olympic champions navigational boxes": "صناديق تصفح أبطال أولمبيين في كرة الطاولة",
    "Taekwondo Olympic champions navigational boxes": "صناديق تصفح أبطال أولمبيين في التايكواندو",
    "Tanzania men's A' international footballers": "لاعبو منتخب تنزانيا لكرة القدم للرجال للمحليين",
    "Tarxien Rainbows F.C. players": "لاعبو تاركسيين راينباوز",
    "Television evangelists": "المبشرين التلفزيونيين",
    "Television series about Nazis": "مسلسلات تلفزيونية عن نازيين",
    "Television series about comedians": "مسلسلات تلفازية عن كوميديين",
    "Television series about fictional musicians": "مسلسلات تلفزيونية عن موسيقيين خياليين",
    "Television series about fictional serial killers": "مسلسلات تلفزيونية عن قتلة متسلسلين خياليين",
    "Television series about serial killers": "مسلسلات تلفزيونية عن قتلة متسلسلين خياليين",
    "Television shows about cocaine": "برامج تلفزيونية عن كوكايين",
    "Timurid civil wars": "حروب التيموريين الأهلية",
    "Timurid wars of succession": "حروب التيموريين الأهلية",
    "Tourist attractions in Payne County, Oklahoma": "مواقع جذب سياحي في مقاطعة بايين (أوكلاهوما)",
    "Towns in Payne County, Oklahoma": "بلدات في مقاطعة بايين (أوكلاهوما)",
    "Trinitarian Order": "الآباء الثالوثيين",
    "Tunisia at the African Nations Championship": "تونس في بطولة أمم إفريقيا للمحليين",
    "Tunisia men's A' international footballers": "لاعبو منتخب تونس لكرة القدم للرجال للمحليين",
    "U.S. Air Force Test Pilot School alumni": "خريجو كلية تدريب الطيارين الاختباريين الأمريكية",
    "UNRWA": "وكالة الأمم المتحدة لإغاثة وتشغيل اللاجئين الفلسطينيين",
    "UNRWA officials": "موظفو وكالة الأمم المتحدة لإغاثة وتشغيل اللاجئين الفلسطينيين",
    "Uganda men's A' international footballers": "لاعبو منتخب أوغندا لكرة القدم للرجال للمحليين",
    "Ukrainian communities in the United States": "مجتمعات أوكرانيين في الولايات المتحدة",
    "Ukrainian-Jewish culture in the United States": "ثقافة اليهود الأوكرانيين في الولايات المتحدة",
    "Union of Democrats for republic politicians": "سياسيو اتحاد الديمقراطيين من أجل الجمهورية",
    "United Nations Security Council resolutions concerning appointment of the Secretary-General": "قرارات مجلس الأمن التابع للأمم المتحدة بشأن تعيين الأمين العام",
    "United Nations Security Council resolutions concerning the protection of civilians in armed conflict": "قرارات مجلس الأمن التابع للأمم المتحدة بشأن حماية المدنيين في النزاعات المسلحة",
    "United States Naval Test Pilot School alumni": "خريجو كلية الطيارين الاختباريين البحرية الأمريكية",
    "United States comics creator navigational boxes": "قوالب مبتكري قصص مصورة أمريكيين",
    "University of al-Qarawiyyin": "جامعة القرويين",
    "University of al-Qarawiyyin alumni": "خريجو جامعة القرويين",
    "Veterans' affairs": "قضايا قدماء المحاربين العسكريين",
    "Veterans' affairs in the United States": "قضايا قدماء المحاربين العسكريين في الولايات المتحدة",
    "Victims of anti-Christian violence": "ضحايا العنف ضد المسيحيين",
    "Video albums by Barbadian artists": "ألبومات فيديو لفنانين بربادوسيين",
    "Video game characters based on real people": "شخصيات ألعاب فيديو مستندة على أشخاص حقيقيين",
    "Video games about Nazis": "ألعاب فيديو عن نازيين",
    "Videographies of Lebanese artists": "فيديوغرافيات الفنانين اللبنانيين",
    "Vienne": "فيين (إقليم فرنسي)",
    "Vienne (department)": "فيين (إقليم فرنسي)",
    "Vigilantism against sex offenders": "مطبقو عدالة ذاتية على المعتدين الجنسيين",
    "Violence against Christians": "العنف ضد المسيحيين",
    "Violence against Christians in India": "العنف ضد المسيحيين في الهند",
    "Violence against LGBT people": "عنف ضد الأشخاص المثليين",
    "Violence against LGBT people in Asia": "العنف ضد الأشخاص المثليين في آسيا",
    "Violence against LGBT people in Europe": "العنف ضد الأشخاص المثليين في أوروبا",
    "Violence against LGBT people in the United Kingdom": "العنف ضد الأشخاص المثليين في المملكة المتحدة",
    "Violence against LGBT people in the United States": "العنف ضد الأشخاص المثليين في الولايات المتحدة",
    "Violence against LGBTQ people": "عنف ضد الأشخاص المثليين",
    "Violence against LGBTQ people in Asia": "العنف ضد الأشخاص المثليين في آسيا",
    "Violence against LGBTQ people in Europe": "العنف ضد الأشخاص المثليين في أوروبا",
    "Violence against LGBTQ people in the United Kingdom": "العنف ضد الأشخاص المثليين في المملكة المتحدة",
    "Violence against LGBTQ people in the United States": "العنف ضد الأشخاص المثليين في الولايات المتحدة",
    "Violence against journalists": "عنف ضد صحفيين",
    "Visigothic Kingdom": "مملكة القوط الغربيين",
    "Volleyball Olympic champions navigational boxes": "صناديق تصفح أبطال أولمبيين في كرة الطائرة",
    "Wars between the United States and Native Americans": "حروب بين الولايات المتحدة والأمريكيين الأصليين",
    "Wars involving the Ayyubid Sultanate": "حروب الأيوبيين",
    "Wars involving the Celts": "حروب تضمنت الكلتيين",
    "West Asian Jews": "يهود آسيويين غربيون",
    "West Francia": "مملكة الفرنجة الغربيين",
    "White nationalist symbols": "رموز القوميين البيض",
    "Wikipedia articles incorporating a citation from the DCBL": "مقالات ويكيبيديا تتضمن نصًا من قاموس السيرة والأدب المسيحيين حتى نهاية القرن السادس",
    "Wikipedia categories named after American actors": "تصنيفات سميت بأسماء ممثلين أمريكيين",
    "Wikipedia categories named after American astronauts": "تصنيفات سميت بأسماء رواد فضاء أمريكيين",
    "Wikipedia categories named after American composers": "تصنيفات سميت بأسماء ملحنين أمريكيين",
    "Wikipedia categories named after American filmmakers": "تصنيفات سميت بأسماء صانعي أفلام أمريكيين",
    "Wikipedia categories named after American military leaders": "تصنيفات سميت بأسماء قادة عسكريين أمريكيين",
    "Wikipedia categories named after American musicians": "تصنيفات بأسماء موسيقيين أمريكيين",
    "Wikipedia categories named after American politicians": "تصنيفات بأسماء سياسيين أمريكيين",
    "Wikipedia categories named after American scientists": "تصنيفات سميت بأسماء علماء أمريكيين",
    "Wikipedia categories named after American sports-people": "تصنيفات سميت بأسماء رياضيين أمريكيين",
    "Wikipedia categories named after Argentine people": "تصنيفات سميت بأسماء أرجنتينيين",
    "Wikipedia categories named after Argentine politicians": "تصنيفات سميت بأسماء سياسيين أرجنتينيين",
    "Wikipedia categories named after Argentine sports-people": "تصنيفات سميت بأسماء رياضيين أرجنتينيين",
    "Wikipedia categories named after Australian actors": "تصنيفات سميت بأسماء ممثلين أستراليين",
    "Wikipedia categories named after Australian musicians": "تصنيفات سميت بأسماء موسيقيين أستراليين",
    "Wikipedia categories named after Australian politicians": "تصنيفات سميت بأسماء سياسيين أستراليين",
    "Wikipedia categories named after Austrian composers": "تصنيفات سميت بأسماء ملحنين نمساويين",
    "Wikipedia categories named after Austrian filmmakers": "تصنيفات سميت بأسماء صانعي أفلام نمساويين",
    "Wikipedia categories named after Austrian musicians": "تصنيفات سميت بأسماء موسيقيين نمساويين",
    "Wikipedia categories named after Azerbaijani people": "تصنيفات سميت بأسماء أذربيجانيين",
    "Wikipedia categories named after Bangladeshi people": "تصنيفات سميت بأسماء بنجلاديشيين",
    "Wikipedia categories named after Barbadian people": "تصنيفات سميت بأسماء بربادوسيين",
    "Wikipedia categories named after Belarusian people": "تصنيفات سميت بأسماء بيلاروسيين",
    "Wikipedia categories named after Belgian musicians": "تصنيفات سميت بأسماء موسيقيين بلجيكيين",
    "Wikipedia categories named after Belgian people": "تصنيفات سميت بأسماء بلجيكيين",
    "Wikipedia categories named after Bolivian people": "تصنيفات سميت بأسماء بوليفيين",
    "Wikipedia categories named after Brazilian musicians": "تصنيفات سميت بأسماء موسيقيين برازيليين",
    "Wikipedia categories named after Brazilian politicians": "تصنيفات سميت بأسماء سياسيين برازيليين",
    "Wikipedia categories named after British actors": "تصنيفات سميت بأسماء ممثلين بريطانيين",
    "Wikipedia categories named after British artists": "تصنيفات سميت بأسماء فنانين بريطانيين",
    "Wikipedia categories named after British military leaders": "تصنيفات سميت بأسماء قادة عسكريين بريطانيين",
    "Wikipedia categories named after British musicians": "تصنيفات سميت بأسماء موسيقيين بريطانيين",
    "Wikipedia categories named after British philosophers": "تصنيفات سميت بأسماء فلاسفة بريطانيين",
    "Wikipedia categories named after British politicians": "تصنيفات سميت بأسماء سياسيين بريطانيين",
    "Wikipedia categories named after British scientists": "تصنيفات سميت بأسماء علماء بريطانيين",
    "Wikipedia categories named after Canadian actors": "تصنيفات سميت بأسماء ممثلين كنديين",
    "Wikipedia categories named after Canadian filmmakers": "تصنيفات سميت بأسماء صانعي أفلام كنديين",
    "Wikipedia categories named after Canadian musicians": "تصنيفات سميت بأسماء موسيقيين كنديين",
    "Wikipedia categories named after Canadian people": "تصنيفات سميت بأسماء كنديين",
    "Wikipedia categories named after Canadian politicians": "تصنيفات سميت بأسماء سياسيين كنديين",
    "Wikipedia categories named after Canadian sports-people": "تصنيفات سميت بأسماء رياضيين كنديين",
    "Wikipedia categories named after Chilean people": "تصنيفات سميت بأسماء تشيليين",
    "Wikipedia categories named after Chinese actors": "تصنيفات سميت بأسماء ممثلين صينيين",
    "Wikipedia categories named after Chinese military leaders": "تصنيفات سميت بأسماء قادة عسكريين صينيين",
    "Wikipedia categories named after Chinese musicians": "تصنيفات سميت بأسماء موسيقيين صينيين",
    "Wikipedia categories named after Chinese politicians": "تصنيفات سميت بأسماء سياسيين صينيين",
    "Wikipedia categories named after Christian figures": "تصنيفات سميت بأسماء أعلام مسيحيين",
    "Wikipedia categories named after Colombian musicians": "تصنيفات سميت بأسماء موسيقيين كولومبيين",
    "Wikipedia categories named after Cypriot people": "تصنيفات سميت بأسماء قبرصيين",
    "Wikipedia categories named after Czech filmmakers": "تصنيفات سميت بأسماء صانعي أفلام تشيكيين",
    "Wikipedia categories named after Czech military leaders": "تصنيفات سميت بأسماء أفراد عسكريين تشيكيين",
    "Wikipedia categories named after Czech people": "تصنيفات سميت بأسماء تشيكيين",
    "Wikipedia categories named after Czech politicians": "تصنيفات سميت بأسماء سياسيين تشيكيين",
    "Wikipedia categories named after Czech scientists": "تصنيفات سميت بأسماء علماء تشيكيين",
    "Wikipedia categories named after Czechoslovak people": "تصنيفات سميت بأسماء تشيكوسلوفاكيين",
    "Wikipedia categories named after Czechoslovak politicians": "تصنيفات سميت بأسماء سياسيين تشيكوسلوفاكيين",
    "Wikipedia categories named after Dutch artists": "تصنيفات سميت بأسماء فنانين هولنديين",
    "Wikipedia categories named after Dutch musicians": "تصنيفات سميت بأسماء موسيقيين هولنديين",
    "Wikipedia categories named after Dutch people": "تصنيفات سميت بأسماء هولنديين",
    "Wikipedia categories named after Egyptian people": "تصنيفات سميت بأسماء مصريين",
    "Wikipedia categories named after English military leaders": "تصنيفات سميت بأسماء قادة عسكريين إنجليز",
    "Wikipedia categories named after English musicians": "تصنيفات سميت بأسماء موسيقيين إنجليز",
    "Wikipedia categories named after Filipino people": "تصنيفات سميت بأسماء فلبينيين",
    "Wikipedia categories named after Finnish people": "تصنيفات سميت بأسماء فنلنديين",
    "Wikipedia categories named after French actors": "تصنيفات سميت بأسماء ممثلين فرنسيين",
    "Wikipedia categories named after French artists": "تصنيفات سميت بأسماء فنانين فرنسيين",
    "Wikipedia categories named after French composers": "تصنيفات سميت بأسماء ملحنين فرنسيين",
    "Wikipedia categories named after French military leaders": "تصنيفات سميت بأسماء قادة عسكريين فرنسيين",
    "Wikipedia categories named after French musicians": "تصنيفات سميت بأسماء موسيقيين فرنسيين",
    "Wikipedia categories named after French politicians": "تصنيفات سميت بأسماء سياسيين فرنسيين",
    "Wikipedia categories named after German military leaders": "تصنيفات سميت بأسماء قادة عسكريين ألمان",
    "Wikipedia categories named after German musicians": "تصنيفات سميت بأسماء موسيقيين ألمان",
    "Wikipedia categories named after German politicians": "تصنيفات سميت بأسماء سياسيين ألمان",
    "Wikipedia categories named after Greek artists": "تصنيفات سميت بأسماء فنانين يونانيين",
    "Wikipedia categories named after Greek musicians": "تصنيفات سميت بأسماء موسيقيين يونانيين",
    "Wikipedia categories named after Guatemalan musicians": "تصنيفات سميت بأسماء موسيقيين غواتيماليين",
    "Wikipedia categories named after Haitian people": "تصنيفات سميت بأسماء هايتيين",
    "Wikipedia categories named after Hindu religious leaders": "تصنيفات سميت بأسماء قادة دينيين هندوس",
    "Wikipedia categories named after Hungarian people": "تصنيفات سميت بأسماء مجريين",
    "Wikipedia categories named after Hungarian politicians": "تصنيفات سميت بأسماء سياسيين مجريين",
    "Wikipedia categories named after Icelandic musicians": "تصنيفات سميت بأسماء موسيقيين آيسلنديين",
    "Wikipedia categories named after Icelandic people": "تصنيفات سميت بأسماء آيسلنديين",
    "Wikipedia categories named after Indian musicians": "تصنيفات سميت بأسماء موسيقيين هنود",
    "Wikipedia categories named after Indian politicians": "تصنيفات سميت بأسماء سياسيين هنود",
    "Wikipedia categories named after Indian sports-people": "تصنيفات سميت بأسماء رياضيين هنود",
    "Wikipedia categories named after Iranian people": "تصنيفات سميت بأسماء إيرانيين",
    "Wikipedia categories named after Iranian politicians": "تصنيفات سميت بأسماء سياسيين إيرانيين",
    "Wikipedia categories named after Iraqi people": "تصنيفات سميت بأسماء عراقيين",
    "Wikipedia categories named after Irish people": "تصنيفات سميت بأسماء أيرلنديين",
    "Wikipedia categories named after Irish politicians": "تصنيفات سميت بأسماء سياسيين أيرلنديين",
    "Wikipedia categories named after Italian artists": "تصنيفات سميت بأسماء فنانين إيطاليين",
    "Wikipedia categories named after Italian composers": "تصنيفات سميت بأسماء ملحنين إيطاليين",
    "Wikipedia categories named after Italian filmmakers": "تصنيفات سميت بأسماء صانعي أفلام إيطاليين",
    "Wikipedia categories named after Italian military leaders": "تصنيفات سميت بأسماء قادة عسكريين إيطاليين",
    "Wikipedia categories named after Italian musicians": "تصنيفات سميت بأسماء موسيقيين إيطاليين",
    "Wikipedia categories named after Italian people": "تصنيفات سميت بأسماء إيطاليين",
    "Wikipedia categories named after Italian politicians": "تصنيفات سميت بأسماء سياسيين إيطاليين",
    "Wikipedia categories named after Japanese musicians": "تصنيفات سميت بأسماء موسيقيين يابانيين",
    "Wikipedia categories named after Japanese people": "تصنيفات سميت بأسماء يابانيين",
    "Wikipedia categories named after Kenyan people": "تصنيفات سميت بأسماء كينيين",
    "Wikipedia categories named after Korean politicians": "تصنيفات بأسماء سياسيين كوريين",
    "Wikipedia categories named after Libyan people": "تصنيفات سميت بأسماء ليبيين",
    "Wikipedia categories named after Mexican musicians": "تصنيفات سميت بأسماء موسيقيين مكسيكيين",
    "Wikipedia categories named after Mexican people": "تصنيفات سميت بأسماء مكسيكيين",
    "Wikipedia categories named after Mongolian people": "تصنيفات سميت بأسماء منغوليين",
    "Wikipedia categories named after Nazis": "تصنيفات سميت بأسماء نازيين",
    "Wikipedia categories named after New Zealand politicians": "تصنيفات سميت بأسماء سياسيين نيوزيلنديين",
    "Wikipedia categories named after Nigerian politicians": "تصنيفات سميت بأسماء سياسيين نيجيريين",
    "Wikipedia categories named after North Korean politicians": "تصنيفات سميت بأسماء سياسيين كوريين شماليين",
    "Wikipedia categories named after Norwegian musicians": "تصنيفات سميت بأسماء موسيقيين نرويجيين",
    "Wikipedia categories named after Norwegian people": "تصنيفات سميت بأسماء نرويجيين",
    "Wikipedia categories named after Pakistani people": "تصنيفات سميت بأسماء باكستانيين",
    "Wikipedia categories named after Pakistani politicians": "تصنيفات سميت بأسماء سياسيين باكستانيين",
    "Wikipedia categories named after Paraguayan people": "تصنيفات سميت بأسماء باراغوايانيين",
    "Wikipedia categories named after Polish military leaders": "تصنيفات سميت بأسماء قادة عسكريين بولنديين",
    "Wikipedia categories named after Portuguese people": "تصنيفات سميت بأسماء برتغاليين",
    "Wikipedia categories named after Romanian musicians": "تصنيفات سميت بأسماء موسيقيين رومانيين",
    "Wikipedia categories named after Romanian people": "تصنيفات سميت بأسماء رومانيين",
    "Wikipedia categories named after Russian military leaders": "تصنيفات سميت بأسماء قادة عسكريين روس",
    "Wikipedia categories named after Russian musicians": "تصنيفات سميت بأسماء موسيقيين روس",
    "Wikipedia categories named after Russian politicians": "تصنيفات سميت بأسماء سياسيين روس",
    "Wikipedia categories named after Scottish actors": "تصنيفات سميت بأسماء ممثلين إسكتلنديين",
    "Wikipedia categories named after Scottish musicians": "تصنيفات سميت بأسماء موسيقيين إسكتلنديين",
    "Wikipedia categories named after Scottish scientists": "تصنيفات سميت بأسماء علماء إسكتلنديين",
    "Wikipedia categories named after South Korean musicians": "تصنيفات سميت بأسماء موسيقيين كوريين جنوبيين",
    "Wikipedia categories named after Spanish military leaders": "تصنيفات سميت بأسماء قادة عسكريين إسبان",
    "Wikipedia categories named after Spanish musicians": "تصنيفات سميت بأسماء موسيقيين إسبان",
    "Wikipedia categories named after Spanish sports-people": "تصنيفات سميت بأسماء رياضيين إسبان",
    "Wikipedia categories named after Sri Lankan people": "تصنيفات سميت بأسماء سريلانكيين",
    "Wikipedia categories named after Swedish military leaders": "تصنيفات سميت بأسماء قادة عسكريين سويديين",
    "Wikipedia categories named after Swedish musicians": "تصنيفات سميت بأسماء موسيقيين سويديين",
    "Wikipedia categories named after Swiss people": "تصنيفات سميت بأسماء سويسريين",
    "Wikipedia categories named after Taiwanese musicians": "تصنيفات سميت بأسماء موسيقيين تايوانيين",
    "Wikipedia categories named after Tanzanian people": "تصنيفات سميت بأسماء تنزانيين",
    "Wikipedia categories named after Thai people": "تصنيفات سميت بأسماء تايلنديين",
    "Wikipedia categories named after Trinidad and Tobago people": "تصنيفات سميت بأسماء ترنيداديين",
    "Wikipedia categories named after Turkish politicians": "تصنيفات سميت بأسماء سياسيين أتراك",
    "Wikipedia categories named after Ugandan people": "تصنيفات سميت بأسماء أوغنديين",
    "Wikipedia categories named after Ukrainian politicians": "تصنيفات سميت بأسماء سياسيين أوكرانيين",
    "Wikipedia categories named after Uruguayan politicians": "تصنيفات سميت بأسماء سياسيين أوروغويانيين",
    "Wikipedia categories named after Venezuelan people": "تصنيفات سميت بأسماء فنزويليين",
    "Wikipedia categories named after Welsh musicians": "تصنيفات سميت بأسماء موسيقيين ويلزيين",
    "Wikipedia categories named after Welsh people": "تصنيفات سميت بأسماء ويلزيين",
    "Wikipedia categories named after ancient Greek people": "تصنيفات سميت بأسماء يونانيين قدماء",
    "Wikipedia categories named after architects": "تصنيفات سميت بأسماء معماريين",
    "Wikipedia categories named after astronomers": "تصنيفات سميت بأسماء فلكيين",
    "Wikipedia categories named after economists": "تصنيفات سميت بأسماء اقتصاديين",
    "Wikipedia categories named after linguists": "تصنيفات سميت بأسماء لغويين",
    "Wikipedia categories named after military leaders": "تصنيفات بأسماء قادة عسكريين",
    "Wikipedia categories named after musicians": "تصنيفات سميت بأسماء موسيقيين",
    "Wikipedia categories named after musicians by nationality": "تصنيفات سميت بأسماء موسيقيين حسب الجنسية",
    "Wikipedia categories named after national legislatures": "تصانيف بأسماء مشرعين قوميين",
    "Wikipedia categories named after occultists": "تصنيفات سميت بأسماء غموضيين",
    "Wikipedia categories named after politicians": "تصنيفات بأسماء سياسيين",
    "Wikipedia categories named after sports-people": "تصنيفات سميت بأسماء رياضيين",
    "Wikipedians interested in LGBT issues": "مستخدمون يدعمون حقوق المثليين",
    "Wives of Abbasid caliphs": "زوجات الخلفاء العباسيين",
    "Works about African-Americans": "أعمال عن أمريكيين أفارقة",
    "Works about American military personnel": "أعمال عن أفراد عسكريين أمريكيين",
    "Works about American politicians": "أعمال عن سياسيين أمريكيين",
    "Works about Asian-Americans": "أعمال عن أمريكيون آسيويين",
    "Works about British politicians": "أعمال عن سياسيين بريطانيين",
    "Works about Chinese military personnel": "أعمال عن أفراد عسكريين صينيين",
    "Works about Irish Travellers": "أعمال عن رحل أيرلنديين",
    "Works about Native Americans": "أعمال عن السكان الأصليين فى الولايات المتحدة",
    "Works about Nazis": "أعمال عن نازيين",
    "Works about North Korean defectors": "أعمال عن كوريين شماليين منشقين",
    "Works about cocaine": "أعمال عن كوكايين",
    "Works about comedians": "أعمال عن كوميديين",
    "Works about diplomats": "أعمال عن دبلوماسيين",
    "Works about entertainers": "أعمال عن فنانين ترفيهيين",
    "Works about fictional serial killers": "أعمال عن قتلة متسلسلين خياليين",
    "Works about journalists": "أعمال عن صحفيين",
    "Works about mass media people": "أعمال عن إعلاميين",
    "Works about military leaders": "أعمال عن قادة عسكريين",
    "Works about military personnel": "أعمال عن أفراد عسكريين",
    "Works about music and musicians": "أعمال عن الموسيقى والموسيقيين",
    "Works about playwrights": "أعمال عن كتاب مسرحيين",
    "Works about politicians": "أعمال عن سياسيين",
    "Works about religious leaders": "أعمال عن قادة دينيين",
    "Works about revolutionaries": "أعمال عن الثوريين",
    "Works about sports-people": "أعمال عن رياضيين",
    "Works about war correspondents": "أعمال عن مراسلين حربيين",
    "Works by Algerian people": "أعمال جزائريين",
    "Works by American comedians": "أعمال كوميديين أمريكيين",
    "Works by American filmmakers": "أعمال صانعي أفلام أمريكيين",
    "Works by American people": "أعمال أمريكيين",
    "Works by Andorran people": "أعمال أندوريين",
    "Works by Angolan people": "أعمال أنغوليين",
    "Works by Argentine people": "أعمال أرجنتينيين",
    "Works by Armenian people": "أعمال أرمينيين",
    "Works by Australian filmmakers": "أعمال صانعي أفلام أستراليين",
    "Works by Australian people": "أعمال أستراليين",
    "Works by Austrian filmmakers": "أعمال صانعي أفلام نمساويين",
    "Works by Austrian people": "أعمال نمساويين",
    "Works by Azerbaijani people": "أعمال أذربيجانيين",
    "Works by Bahamian people": "أعمال بهاميين",
    "Works by Bahraini people": "أعمال بحرينيين",
    "Works by Bangladeshi people": "أعمال بنغلاديشيين",
    "Works by Barbadian people": "أعمال بربادوسيين",
    "Works by Belarusian people": "أعمال بيلاروسيين",
    "Works by Belgian people": "أعمال بلجيكيين",
    "Works by Belizean people": "أعمال بليزيين",
    "Works by Beninese people": "أعمال بنينيين",
    "Works by Bhutanese people": "أعمال بوتانيين",
    "Works by Bissau-Guinean people": "أعمال غينيين بيساويين",
    "Works by Bolivian people": "أعمال بوليفيين",
    "Works by Bosnia and Herzegovina people": "أعمال بوسنيين",
    "Works by Botswana people": "أعمال بوتسوانيين",
    "Works by Brazilian people": "أعمال برازيليين",
    "Works by British filmmakers": "أعمال صانعي أفلام بريطانيين",
    "Works by British people": "أعمال بريطانيين",
    "Works by Bulgarian people": "أعمال بلغاريين",
    "Works by Burkinabe people": "أعمال بوركينابيين",
    "Works by Burmese people": "أعمال بورميين",
    "Works by Burundian people": "أعمال بورونديين",
    "Works by Cambodian people": "أعمال كمبوديين",
    "Works by Cameroonian people": "أعمال كاميرونيين",
    "Works by Canadian people": "أعمال كنديين",
    "Works by Cape Verdean people": "أعمال أخضريين",
    "Works by Chadian people": "أعمال تشاديين",
    "Works by Chilean people": "أعمال تشيليين",
    "Works by Chinese filmmakers": "أعمال صانعي أفلام صينيين",
    "Works by Chinese people": "أعمال صينيين",
    "Works by Colombian people": "أعمال كولومبيين",
    "Works by Comorian people": "أعمال قمريين",
    "Works by Costa Rican people": "أعمال كوستاريكيين",
    "Works by Croatian people": "أعمال كرواتيين",
    "Works by Cuban people": "أعمال كوبيين",
    "Works by Cypriot people": "أعمال قبرصيين",
    "Works by Czech people": "أعمال تشيكيين",
    "Works by Czechoslovak people": "أعمال تشيكوسلوفاكيين",
    "Works by Danish filmmakers": "أعمال صانعي أفلام دنماركيين",
    "Works by Danish people": "أعمال دنماركيين",
    "Works by Dominican Republic people": "أعمال دومينيكانيين",
    "Works by Dutch people": "أعمال هولنديين",
    "Works by East German people": "أعمال ألمانيين شرقيين",
    "Works by Ecuadorian people": "أعمال إكوادوريين",
    "Works by Egyptian people": "أعمال مصريين",
    "Works by Emirati people": "أعمال إماراتيين",
    "Works by Equatoguinean people": "أعمال غينيين استوائيين",
    "Works by Estonian people": "أعمال إستونيين",
    "Works by Ethiopian people": "أعمال إثيوبيين",
    "Works by Filipino people": "أعمال فلبينيين",
    "Works by Finnish people": "أعمال فنلنديين",
    "Works by French filmmakers": "أعمال صانعي أفلام فرنسيين",
    "Works by French people": "أعمال فرنسيين",
    "Works by Gabonese people": "أعمال غابونيين",
    "Works by Ghanaian people": "أعمال غانيين",
    "Works by Gibraltarian people": "أعمال جبل طارقيين",
    "Works by Greek people": "أعمال يونانيين",
    "Works by Guatemalan people": "أعمال غواتيماليين",
    "Works by Guinean people": "أعمال غينيين",
    "Works by Guyanese people": "أعمال غيانيين",
    "Works by Haitian people": "أعمال هايتيين",
    "Works by Honduran people": "أعمال هندوراسيين",
    "Works by Hong Kong people": "أعمال هونغ كونغيين",
    "Works by Hungarian people": "أعمال مجريين",
    "Works by Icelandic people": "أعمال آيسلنديين",
    "Works by Indonesian people": "أعمال إندونيسيين",
    "Works by Iranian people": "أعمال إيرانيين",
    "Works by Iraqi people": "أعمال عراقيين",
    "Works by Irish people": "أعمال أيرلنديين",
    "Works by Israeli people": "أعمال إسرائيليين",
    "Works by Italian filmmakers": "أعمال صانعي أفلام إيطاليين",
    "Works by Ivorian people": "أعمال إيفواريين",
    "Works by Jamaican people": "أعمال جامايكيين",
    "Works by Japanese filmmakers": "أعمال صانعي أفلام يابانيين",
    "Works by Japanese people": "أعمال يابانيين",
    "Works by Jordanian people": "أعمال أردنيين",
    "Works by Kazakhstani people": "أعمال كازاخستانيين",
    "Works by Kenyan people": "أعمال كينيين",
    "Works by Korean people": "أعمال كوريين",
    "Works by Kosovan people": "أعمال كوسوفيين",
    "Works by Kuwaiti people": "أعمال كويتيين",
    "Works by Laotian people": "أعمال لاوسيين",
    "Works by Latvian people": "أعمال لاتفيين",
    "Works by Lebanese people": "أعمال لبنانيين",
    "Works by Lesotho people": "أعمال ليسوثويين",
    "Works by Liberian people": "أعمال ليبيريين",
    "Works by Libyan people": "أعمال ليبيين",
    "Works by Lithuanian people": "أعمال ليتوانيين",
    "Works by Luxembourgian people": "أعمال لوكسمبورغيين",
    "Works by Macedonian people": "أعمال مقدونيين",
    "Works by Malagasy people": "أعمال مدغشقريين",
    "Works by Malawian people": "أعمال ملاويون",
    "Works by Malaysian people": "أعمال ماليزيين",
    "Works by Maldivian people": "أعمال مالديفيين",
    "Works by Malian people": "أعمال ماليين",
    "Works by Maltese people": "أعمال مالطيين",
    "Works by Mauritanian people": "أعمال موريتانيين",
    "Works by Mauritian people": "أعمال موريشيوسيين",
    "Works by Mexican filmmakers": "أعمال صانعي أفلام مكسيكيين",
    "Works by Mexican people": "أعمال مكسيكيين",
    "Works by Moldovan people": "أعمال مولدوفيين",
    "Works by Monegasque people": "أعمال موناكيين",
    "Works by Mongolian people": "أعمال منغوليين",
    "Works by Moroccan people": "أعمال مغربيين",
    "Works by Mozambican people": "أعمال موزمبيقيين",
    "Works by Namibian people": "أعمال ناميبيين",
    "Works by Nepalese people": "أعمال نيباليين",
    "Works by New Zealand people": "أعمال نيوزيلنديين",
    "Works by Nicaraguan people": "أعمال نيكاراغويين",
    "Works by Nigerian people": "أعمال نيجيريين",
    "Works by North Korean people": "أعمال كوريين شماليين",
    "Works by Norwegian filmmakers": "أعمال صانعي أفلام نرويجيين",
    "Works by Norwegian people": "أعمال نرويجيين",
    "Works by Pakistani people": "أعمال باكستانيين",
    "Works by Palestinian people": "أعمال فلسطينيين",
    "Works by Panamanian people": "أعمال بنميين",
    "Works by Paraguayan people": "أعمال باراغوايانيين",
    "Works by Peruvian people": "أعمال بيرويين",
    "Works by Polish filmmakers": "أعمال صانعي أفلام بولنديين",
    "Works by Polish people": "أعمال بولنديين",
    "Works by Portuguese filmmakers": "أعمال صانعي أفلام برتغاليين",
    "Works by Portuguese people": "أعمال برتغاليين",
    "Works by Puerto Rican people": "أعمال بورتوريكيين",
    "Works by Qatari people": "أعمال قطريين",
    "Works by republic of congo people": "أعمال كونغويين",
    "Works by Romanian filmmakers": "أعمال صانعي أفلام رومانيين",
    "Works by Romanian people": "أعمال رومانيين",
    "Works by Russian people": "أعمال روسيين",
    "Works by Rwandan people": "أعمال روانديين",
    "Works by Salvadoran people": "أعمال سلفادوريين",
    "Works by Saudi Arabian people": "أعمال سعوديين",
    "Works by Scottish filmmakers": "أعمال صانعي أفلام إسكتلنديين",
    "Works by Scottish people": "أعمال إسكتلنديين",
    "Works by Senegalese people": "أعمال سنغاليين",
    "Works by Seychellois people": "أعمال سيشليين",
    "Works by Singaporean people": "أعمال سنغافوريين",
    "Works by Slovak filmmakers": "أعمال صانعي أفلام سلوفاكيين",
    "Works by Slovak people": "أعمال سلوفاكيين",
    "Works by Slovenian people": "أعمال سلوفينيين",
    "Works by Somalian people": "أعمال صوماليين",
    "Works by South Korean filmmakers": "أعمال صانعي أفلام كوريين جنوبيين",
    "Works by South Korean people": "أعمال كوريين جنوبيين",
    "Works by South Sudanese people": "أعمال جنوبيين سودانيين",
    "Works by Sri Lankan people": "أعمال سريلانكيين",
    "Works by Sudanese people": "أعمال سودانيين",
    "Works by Surinamese people": "أعمال سوريناميين",
    "Works by Swazi people": "أعمال سوازيلنديين",
    "Works by Swedish filmmakers": "أعمال صانعي أفلام سويديين",
    "Works by Swedish people": "أعمال سويديين",
    "Works by Swiss people": "أعمال سويسريين",
    "Works by Syrian people": "أعمال سوريين",
    "Works by Taiwanese people": "أعمال تايوانيين",
    "Works by Tanzanian people": "أعمال تنزانيين",
    "Works by Thai people": "أعمال تايلنديين",
    "Works by Togolese people": "أعمال توغويين",
    "Works by Trinidad and Tobago people": "أعمال ترنيداديين",
    "Works by Tunisian people": "أعمال تونسيين",
    "Works by Ugandan people": "أعمال أوغنديين",
    "Works by Ukrainian people": "أعمال أوكرانيين",
    "Works by Uruguayan people": "أعمال أوروغويانيين",
    "Works by Uzbekistani people": "أعمال أوزبكستانيين",
    "Works by Venezuelan people": "أعمال فنزويليين",
    "Works by Vietnamese people": "أعمال فيتناميين",
    "Works by Welsh people": "أعمال ويلزيين",
    "Works by Yemeni people": "أعمال يمنيين",
    "Works by Yugoslav people": "أعمال يوغسلافيين",
    "Works by Zambian people": "أعمال زامبيين",
    "Works by Zimbabwean people": "أعمال زيمبابويين",
    "Works by ancient Roman people": "أعمال رومانيين قدماء",
    "Works by musician": "أعمال حسب الموسيقيين",
    "World Athletics Championships athletes for Sudan": "بطولة العالم لألعاب القوى للرياضيين من السودان",
    "World music albums by Egyptian artists": "ألبومات موسيقى العالم لفنانين مصريين",
    "World music albums by Indonesian artists": "ألبومات موسيقى العالم لفنانين إندونيسيين",
    "World music albums by Lebanese artists": "ألبومات موسيقى العالم لفنانين لبنانيين",
    "YMCA": "جمعية الشبان المسيحيين",
    "Yazidi communities": "المناطق المأهولة باليزيديين",
    "Yemeni refugees": "اللاجئين اليمنيين",
    "Yemenite Association politicians": "حزب السياسيين اليمنيين",
    "Zambia men's A' international footballers": "لاعبو منتخب زامبيا لكرة القدم للرجال للمحليين",
    "Zimbabwe men's A' international footballers": "لاعبو منتخب زيمبابوي لكرة القدم للرجال للمحليين",
}

data2 = {
    "Adaptations of works by American writers": "أعمال مقتبسة عن أعمال كتاب أمريكيين",
    "Adaptations of works by Argentine writers": "تكييفات أعمال كتاب أرجنتينيين",
    "Adaptations of works by Austrian writers": "تكييفات أعمال كتاب نمساويين",
    "Adaptations of works by Canadian writers": "تكييفات أعمال كتاب كنديين",
    "Adaptations of works by Chinese writers": "تكييفات أعمال كتاب صينيين",
    "Adaptations of works by Czech writers": "تكييفات أعمال كتاب تشيكيين",
    "Adaptations of works by Danish writers": "أعمال مقتبسة عن أعمال كتاب دنماركيين",
    "Adaptations of works by French writers": "أعمال مقتبسة عن أعمال كتاب فرنسيين",
    "Adaptations of works by Greek writers": "أعمال مقتبسة عن أعمال كتاب يونانيين",
    "Adaptations of works by Irish writers": "أعمال مقتبسة عن أعمال كتاب أيرلنديين",
    "Adaptations of works by Italian writers": "أعمال مقتبسة عن أعمال كتاب إيطاليين",
    "Adaptations of works by Japanese writers": "أعمال مقتبسة عن أعمال كتاب يابانيين",
    "Adaptations of works by Korean writers": "تكييفات أعمال كتاب كوريين",
    "Adaptations of works by New Zealand writers": "تكييفات أعمال كتاب نيوزيلنديين",
    "Adaptations of works by Norwegian writers": "أعمال مقتبسة عن أعمال كتاب نرويجيين",
    "Adaptations of works by Polish writers": "تكييفات أعمال كتاب بولنديين",
    "Adaptations of works by Scottish writers": "اقتباسات لأعمال كتاب إسكتلنديين",
    "Adaptations of works by South Korean writers": "تكييفات أعمال كتاب كوريين جنوبيين",
    "Adaptations of works by Swedish writers": "تكييفات أعمال كتاب سويديين",
    "Adaptations of works by Venezuelan writers": "تكييفات أعمال كتاب فنزويليين",
    "Adaptations of works by ancient Greek writers": "أعمال مقتبسة عن أعمال كتاب يونانيين قدماء",
    "American writers' organizations": "منظمات الكتاب الأمريكيين",
    "Asian writers by nationality": "كتاب آسيويين حسب الجنسية",
    "Asian writers in French": "كتاب آسيويين في الفرنسية",
    "Bibliographies of British writers": "قوائم مؤلفات كتاب بريطانيين",
    "Bibliographies of Czech writers": "قوائم مؤلفات كتاب تشيكيين",
    "Bibliographies of Irish writers": "قوائم مؤلفات كتاب أيرلنديين",
    "Bibliographies of Swiss writers": "قوائم مؤلفات كتاب سويسريين",
    "Films based on works by American writers": "أفلام مبنية على أعمال كتاب أمريكيين",
    "Films based on works by British writers": "أفلام مقتبسة من أعمال كتاب بريطانيين",
    "Films based on works by Canadian writers": "أفلام مبنية على أعمال كتاب كنديين",
    "Films based on works by Czech writers": "أفلام مبنية على أعمال كتاب تشيكيين",
    "Films based on works by Dutch writers": "أفلام مبنية على أعمال كتاب هولنديين",
    "Films based on works by Japanese writers": "أفلام مبنية على أعمال كتاب يابانيين",
    "Films based on works by Korean writers": "أفلام مبنية على أعمال كتاب كوريين",
    "Films based on works by Polish writers": "أفلام مبنية على أعمال كتاب بولنديين",
    "Films based on works by Scottish writers": "أعمال مستندة إلى أعمال كتاب إسكتلنديين",
    "Films based on works by South Korean writers": "أفلام مبنية على أعمال كتاب كوريين جنوبيين",
    "Films based on works by Venezuelan writers": "أفلام مبنية على أعمال كتاب فنزويليين",
    "Lists of British writers": "قوائم كتاب بريطانيين",
    "Video games based on works by Canadian writers": "ألعاب فيديو مبنية على أعمال كتاب كنديين",
    "Video games based on works by New Zealand writers": "ألعاب فيديو مبنية على أعمال كتاب نيوزيلنديين",
    "Works by American writers": "أعمال كتاب أمريكيين",
    "Works by Argentine writers": "أعمال كتاب أرجنتينيين",
    "Works by Australian writers": "أعمال كتاب أستراليين",
    "Works by Austrian writers": "أعمال كتاب نمساويين",
    "Works by Belgian writers": "أعمال كتاب بلجيكيين",
    "Works by British writers": "أعمال كتاب بريطانيين",
    "Works by Canadian writers": "أعمال كتاب كنديين",
    "Works by Chinese writers": "أعمال كتاب صينيين",
    "Works by Colombian writers": "أعمال كتاب كولومبيين",
    "Works by Czech writers": "أعمال كتاب تشيكيين",
    "Works by Danish writers": "أعمال كتاب دنماركيين",
    "Works by Dutch writers": "أعمال كتاب هولنديين",
    "Works by Egyptian writers": "أعمال كتاب مصريين",
    "Works by French writers": "أعمال كتاب فرنسيين",
    "Works by Greek writers": "أعمال كتاب يونانيين",
    "Works by Hungarian writers": "أعمال كتاب مجريين",
    "Works by Iranian writers": "أعمال كتاب إيرانيين",
    "Works by Irish writers": "أعمال كتاب أيرلنديين",
    "Works by Italian writers": "أعمال كتاب إيطاليين",
    "Works by Japanese writers": "أعمال كتاب يابانيين",
    "Works by Libyan writers": "أعمال كتاب ليبيين",
    "Works by Malaysian writers": "أعمال كتاب ماليزيين",
    "Works by Mexican writers": "أعمال كتاب مكسيكيين",
    "Works by North Korean writers": "أعمال كتاب كوريين شماليين",
    "Works by Norwegian writers": "أعمال كتاب نرويجيين",
    "Works by Polish writers": "أعمال كتاب بولنديين",
    "Works by Saudi Arabian writers": "أعمال كتاب سعوديين",
    "Works by Scottish writers": "أعمال كتاب إسكتلنديين",
    "Works by South Korean writers": "أعمال كتاب كوريين جنوبيين",
    "Works by Swedish writers": "أعمال كتاب سويديين",
    "Works by Swiss writers": "أعمال كتاب سويسريين",
    "Works by Ukrainian writers": "أعمال كتاب أوكرانيين",
    "Works by Yemeni writers": "أعمال كتاب يمنيين",
    "Works by ancient Greek writers": "أعمال كتاب يونانيين قدماء",
}

to_test = [
    ("text_to_fix_1", data1),
    ("text_to_fix_2", data2),
]


test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=True)
